using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using CMS.GlobalHelper;
using CMS.Forums;
using CMS.CMSHelper;
using CMS.SiteProvider;

/// <summary>
/// Summary description for ForumProperties
/// </summary>
public class ForumProperties
{

    private bool mUseFlatView = true;
    private string mGroupName = "";
    private bool mExpandTree = false;
    private bool mSelectOnlyApproved = true;
    private int mMaxRelativeLevel = -1;
    private string mPostPath = "/%";
    private string mWhereCondition = "";

    private ShowModeEnum mShowMode = ShowModeEnum.TreeMode;
    private bool mStopProcessing = false;
    private int mPageSize = 10;
    private bool mEnablePaging = true;
    private bool mAdHoc = false;
    private int mForumID = 0;
    private int mPostReplyId = 0;
    private int mPostId = 0;

    private int mSelected = 0;
    private bool mShowApprovePics = false;
    private bool mAdministrationMode = false;
    private bool mCheckPermissions = true;
    private int mGroupId = 0;

    private bool mDisplayOnlyOpen = true;
    private string mQueryString = "ForumID";
    private string mThreadQueryString = "Thread";
    private bool mUseAlternatingStyle = false;
    private bool mNoAuthenticatedRead = true;
    private bool mEnableSubscription = true;
    private FlatModeEnum mMode = FlatModeEnum.Threaded;
    private bool mIsSearchResult = false;

    private bool mEnablePicture = false;
    private int mMaxPictureWidth = 50;
    private int mMaxPictureHeight = 60;
    private bool mEnableSignature = false;



    #region "Public properties"

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mEnablePicture; }
        set { mEnablePicture = value; }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mMaxPictureWidth; }
        set { mMaxPictureWidth = value; }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mMaxPictureHeight; }
        set { mMaxPictureHeight = value; }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mEnableSignature; }
        set { mEnableSignature = value; }
    }

    /// <summary>
    /// Is search result
    /// </summary>
    public bool IsSearchResult
    {
        get { return ValidationHelper.GetBoolean(mIsSearchResult, false); }
        set { mIsSearchResult = value; }
    }

    /// <summary>
    ///  flat view mode
    /// </summary>
    public FlatModeEnum FlatMode
    {
        get { return mMode; }
        set { mMode = value; }
    }

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get { return ValidationHelper.GetBoolean(mEnableSubscription, true); }
        set { mEnableSubscription = value; }
    }

    /// <summary>
    /// If set public user can read, no insert new post
    /// </summary>
    public bool NoAuthenticatedRead
    {
        get { return ValidationHelper.GetBoolean(mNoAuthenticatedRead, true); }
        set { mNoAuthenticatedRead = value; }
    }

    /// <summary>
    /// Alternating style
    /// </summary>
    public bool UseAlternatingStyle
    {
        get { return ValidationHelper.GetBoolean(mUseAlternatingStyle, false); }
        set { mUseAlternatingStyle = value; }
    }

    /// <summary>
    /// Query string represent Forum
    /// </summary>
    public string QueryStringForumID
    {
        get { return DataHelper.GetNotEmpty(mQueryString, "ForumID"); }
        set { mQueryString = value; }
    }

    /// <summary>
    /// Query string represent thread
    /// </summary>
    public string QueryStringThread
    {
        get { return DataHelper.GetNotEmpty(mThreadQueryString, "Thread"); }
        set { mThreadQueryString = value; }
    }

    /// <summary>
    /// GroupId
    /// </summary>
    public int GroupID
    {
        get { return mGroupId; }
        set { mGroupId = value; }
    }

    /// <summary>
    /// DisplayOnlyOpen
    /// </summary>
    public bool DisplayOnlyOpen
    {
        get { return ValidationHelper.GetBoolean(mDisplayOnlyOpen, true); }
        set { mDisplayOnlyOpen = value; }
    }

    /// <summary>
    /// CheckPermissions
    /// </summary>
    public bool CheckPermissions
    {
        get { return ValidationHelper.GetBoolean(mCheckPermissions, true); }
        set { mCheckPermissions = value; }
    }

    /// <summary> AdministrationMode </summary>
    public bool AdministrationMode
    {
        get { return mAdministrationMode; }
        set { mAdministrationMode = value; }
    }

    /// <summary>
    /// Show approved pictures in tree.
    /// </summary>
    public bool ShowApprovePics
    {
        get { return mShowApprovePics; }
        set { mShowApprovePics = value; }
    }

    /// <summary>
    /// Selected path.
    /// </summary>
    public int Selected
    {
        get { return ValidationHelper.GetInteger(mSelected, 0); }
        set { mSelected = value; }
    }

    /// <summary>
    /// AdHoc forum
    /// </summary>
    public bool AdHocForum
    {
        get { return mAdHoc; }
        set { mAdHoc = value; }
    }

    /// <summary>
    /// Forum Id
    /// </summary>
    public int ForumID
    {
        get { return mForumID; }
        set { mForumID = value; }
    }


    /// <summary>
    /// Post reply id
    /// </summary>
    public int PostReplyId
    {
        get { return mPostReplyId; }
        set { mPostReplyId = value; }
    }

    /// <summary>
    /// Post id
    /// </summary>
    public int PostId
    {
        get { return mPostId; }
        set { mPostId = value; }
    }

    /// <summary>Enable paging</summary>
    public bool EnablePaging
    {
        get { return mEnablePaging; }
        set { mEnablePaging = value; }
    }

    /// <summary>Page size</summary>
    public int PageSize
    {
        get { return mPageSize; }
        set { mPageSize = value; }
    }

    /// <summary> Stop processing </summary>
    public bool StopProcessing
    {
        get { return mStopProcessing; }
        set { mStopProcessing = value; }
    }


    /// <summary> ShowMode </summary>
    public ShowModeEnum ShowMode
    {
        get { return mShowMode; }
        set { mShowMode = value; }
    }


    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get { return mWhereCondition; }
        set { mWhereCondition = value; }
    }


    /// <summary>
    /// Path
    /// </summary>
    public string PostPath
    {
        get { return mPostPath; }
        set { mPostPath = value; }
    }


    /// <summary>
    /// Max relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get { return mMaxRelativeLevel; }
        set { mMaxRelativeLevel = value; }
    }


    /// <summary>
    /// Select only approved
    /// </summary>
    public bool SelectOnlyApproved
    {
        get { return mSelectOnlyApproved; }
        set { mSelectOnlyApproved = value; }
    }


    /// <summary>
    /// Expand tree
    /// </summary>
    public bool ExpandTree
    {
        get { return mExpandTree; }
        set { mExpandTree = value; }
    }

    /// <summary>
    /// Use flat view
    /// </summary>
    public bool UseFlatView
    {
        get { return mUseFlatView; }
        set { mUseFlatView = value; }
    }

    /// <summary>
    /// name of group
    /// </summary>
    public string GroupName
    {
        get { return ValidationHelper.GetString(mGroupName, ""); }
        set { mGroupName = value; }
    }

    #endregion

    /// <summary>
    /// Constructor
    /// </summary>
    public ForumProperties()
    {
    }

    /// <summary>
    /// Check if in QueryString is parameter "Unsubscribe" and make action
    /// </summary>
    public void CheckUnsubscribe()
    {
        if ((HttpContext.Current != null) && (ValidationHelper.GetString(HttpContext.Current.Request.QueryString["Unsubscribe"], "").Trim() != ""))
        {
            int subId = ValidationHelper.GetInteger(HttpContext.Current.Request.QueryString["Unsubscribe"], 0);

            if (ValidationHelper.GetString(HttpContext.Current.Request.QueryString["ForumID"], "").Trim() != "")
            {

                int forId = ValidationHelper.GetInteger(HttpContext.Current.Request.QueryString["ForumID"], 0);

                ForumSubscriptionInfo fsi = ForumSubscriptionInfoProvider.GetForumSubscriptionInfo(subId);
                if (fsi != null)
                {
                    if (fsi.SubscriptionForumID == forId)
                    {
                        //ForumSubscriptionInfoProvider.DeleteForumSubscriptionInfo(subId);

                        string link = HttpContext.Current.Request.RawUrl;

                        if (link.IndexOf('?') >= 0)
                        {
                            link = link.Remove(link.IndexOf('?'));
                        }
                    }
                    else
                    {
                        subId = 0;
                    }
                }
                else
                {
                    subId = 0;
                }
            }
            HttpContext.Current.Response.Redirect("~/CMSPages/unsubscribe.aspx?subId=" + subId.ToString());
        }
    }

    /// <summary>
    /// Return true if have permissions
    /// </summary>
    /// <returns></returns>
    public bool CheckPermission(int forumId)
    {

        if ((!this.CheckPermissions) || (CMSContext.CurrentUser.IsGlobalAdministrator))
        {
            return true;
        }

        // Ad-Hoc forum permission is true
        if (forumId == 0) return true;

        bool toReturn = false;

        ForumInfo fi = ForumInfoProvider.GetForumInfo(forumId);

        if (fi != null)
        {

            // No control access
            if (fi.ForumAccess == 0)
            {
                toReturn = true;
            }

            // Authenticated user
            if ((fi.ForumAccess == 1) && (!CMSContext.CurrentUser.IsPublic()))
            {
                toReturn = true;
            }


            //Roles
            if ((fi.ForumAccess == 2) && (CMSContext.CurrentUser != null))
            {
                string roleNames = ForumInfoProvider.GetRoleNamesForForum(forumId);
                string[] splitedRoles = null;

                if (roleNames != null)
                {
                    splitedRoles = roleNames.Split(';');

                    if (splitedRoles != null)
                    {

                        DataTable mRoles = UserInfoProvider.GetUserRoles(CMSContext.CurrentUser.UserID);

                        for (int i = 0; i < splitedRoles.GetUpperBound(0); i++)
                        {
                            if (splitedRoles[i] != null && splitedRoles[i] != "")
                            {
                                foreach (DataRow dr in mRoles.Rows)
                                {
                                    if (splitedRoles[i].ToLower() == ValidationHelper.GetString(dr["RoleName"], "").ToLower())
                                    {
                                        toReturn = true;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        return toReturn;
    }

    /// <summary>
    /// Encode HTML tags in text depends on forum settings, and disable javascripts
    /// </summary>
    /// <param name="forumID">Forum ID</param>
    /// <param name="inputText">Input text</param>
    /// <returns>Return encoded text</returns>
    public string ForumHtmlEncode(string inputText, int forumID)
    {
        string toReturn = "";

        // Get forum info
        ForumInfo fi = ForumInfoProvider.GetForumInfo(forumID);
        if (fi != null)
        {
            // If forum doesn't support HTML code, encode it
            if (!fi.ForumHTMLEditor)
            {
                toReturn = HttpUtility.HtmlDecode(inputText).Replace("\r\n", "<br />"); 
            }
            else
            {
                // try to find javascript -- too easy????
                inputText = inputText.Replace("<script", "<xscript");
                toReturn = inputText;
            }
        }
        return toReturn;
    }

}
