using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.FileManager;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.DataEngine;
using CMS.SettingsProvider;
using CMS.FormEngine;

public partial class CMSDesk_Content_NewFile : CMSDeskPage
{
    int nodeId = 0;
    bool isDialog = false;

    protected void Page_Load(object sender, EventArgs e)
    {        
        // Indicates wheather new file is added from the dialog window (FCKEditor->InsertImage->BrowseServer->Upload)
        isDialog = (ValidationHelper.GetString(Request.QueryString["dialog"], "") == "1");

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        lblFileDescription.Text = ResHelper.GetString("NewFile.FileDescription");
        lblUploadFile.Text = ResHelper.GetString("NewFile.UploadFile");

        ltlScript.Text = ScriptHelper.GetScript("function SaveDocument(nodeId, createAnother) { document.getElementById('hidAnother').value = createAnother; " + ClientScript.GetPostBackEventReference(this.btnOk, null) + "; }");
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        CMS.TreeEngine.TreeNode node = null;
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);

        if (!FileUpload.HasFile)
        {
            lblError.Text = ResHelper.GetString("NewFile.ErrorEmpty");
        }
        else
        {
            // get file extension
            string fileExtension = Path.GetExtension(FileUpload.FileName).TrimStart('.');

            // check file extension
            if (isExtensionAllowed(fileExtension))
            {

                try
                {
                    // Create new document
                    string fileName = Path.GetFileNameWithoutExtension(FileUpload.FileName);

                    node = new CMS.TreeEngine.TreeNode("CMS.File", tree);
                    node.DocumentCulture = CMSContext.CurrentUser.PreferredCultureCode;
                    node.DocumentName = fileName;

                    node.SetValue("FileDescription", txtFileDescription.Text);
                    node.SetValue("FileName", fileName);

                    // Insert the document
                    DocumentHelper.InsertDocument(node, nodeId, tree);

                    // Add the file
                    DocumentHelper.AddAttachment(node, "FileAttachment", FileUpload.PostedFile, tree);

                    // Update the document
                    DocumentHelper.UpdateDocument(node, tree);

                    bool createAnother = ValidationHelper.GetBoolean(Request.Params["hidAnother"], false);

                    // Added from CMSDesk->Content
                    if (!isDialog)
                    {

                        if (createAnother)
                        {
                            ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + node.NodeParentID + ", " + node.NodeParentID + "); CreateAnother();");
                        }
                        else
                        {
                            ltlScript.Text += ScriptHelper.GetScript(
                                "   RefreshNode(" + node.NodeID + ", " + node.NodeID + "); SelectNode(" + node.NodeID + "); \n"
                            );
                        }
                    }
                    // Added from dialog window
                    else
                    {
                        if (createAnother)
                        {
                            ltlScript.Text += ScriptHelper.GetScript("FileCreated(" + node.NodeID + ", " + node.NodeParentID + ", false);");
                        }
                        else
                        {
                            ltlScript.Text += ScriptHelper.GetScript("FileCreated(" + node.NodeID + ", " + node.NodeParentID + ", true);");
                        }
                    }
                }
                catch (Exception ex)
                {
                    if ((node != null) && (node.DocumentID > 0))
                    {
                        DocumentHelper.DeleteDocument(node, tree, false, true);
                    }
                    lblError.Text = ResHelper.GetString("NewFile.Failed") + ": " + ex.Message;
                }
            }
            else
            {
                lblError.Text = String.Format(ResHelper.GetString("NewFile.ExtensionNotAllowed"), fileExtension);
            }
        }
    }


    /// <summary>
    /// Determines whether file with specified extension can be uploaded.
    /// </summary>
    /// <param name="extension">File extension to check.</param>
    /// <returns></returns>
    protected bool isExtensionAllowed(string extension)
    {
        string doctypeExtensions = "";
        string globalExtensions = "";
        string allExtensions;
        string currentSite = "";
        bool isAllowed = false;

        if (CMSContext.CurrentSite != null)
        {
            currentSite = CMSContext.CurrentSite.SiteName + ".";
        }

        // Get global settings
        globalExtensions = SettingsKeyProvider.GetStringValue(currentSite + "CMSUploadExtensions").TrimEnd(';').ToLower();

        // Get document type ('cms.file') settings
        DataClassInfo dci = DataClassInfoProvider.GetDataClass("cms.file");
        if (dci != null)
        {
            // load xml definition
            string def = dci.ClassFormDefinition;
            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(def);

            // get valid extensions
            FormFieldInfo ffi = fi.GetFormField("FileAttachment");
            if (ffi != null)
            {
                doctypeExtensions = ffi.FileExtensions.TrimEnd(';').ToLower();
            }
        }

        // Get all allowed extensions
        allExtensions = (globalExtensions + ";" + doctypeExtensions).TrimEnd(';');

        if (allExtensions == "")
        {            
            isAllowed = true;
        }
        else
        {
            // remove starting dot from tested extension
            extension = extension.TrimStart('.').ToLower();

            allExtensions = ";" + allExtensions + ";";
            isAllowed = allExtensions.Contains(";" + extension + ";");            
        }

        // TODO: petrvo - check files with no extension

        return isAllowed;
    }
}
