using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.ExtendedControls;
using CMS.WorkflowEngine;
using CMS.PortalEngine;

public partial class CMSDesk_Content_Properties_metadata : CMSDeskPage
{
    int nodeId = 0;
    CMS.TreeEngine.TreeNode node = null;
    TreeProvider tree = null;
    protected bool hasModifyPermission = true;

    protected void Page_Load(object sender, EventArgs e)
    {
        this.PreRender += new EventHandler(Page_PreRender);

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Get the document
        tree = new TreeProvider(CMSContext.CurrentUser);
        node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

        if (!IsPostBack)
        {
            ReloadData();
        }

        ltlScript.Text = "";

        lblPageDescription.Text = ResHelper.GetString("PageProperties.Decription");
        lblPageKeywords.Text = ResHelper.GetString("PageProperties.Keywords");
        lblPageTitle.Text = ResHelper.GetString("PageProperties.Title");
        lblCssStyle.Text = ResHelper.GetString("PageProperties.CssStyle");

        chkCssStyle.Text = ResHelper.GetString("Metadata.Inherit");
        chkDescription.Text = ResHelper.GetString("Metadata.Inherit");
        chkKeyWords.Text = ResHelper.GetString("Metadata.Inherit");
        chkTitle.Text = ResHelper.GetString("Metadata.Inherit");

        btnOK.Text = ResHelper.GetString("PageProperties.OK");

        SetCheckBoxes();

    }

    protected void SetCheckBoxes()
    {
        if (IsPostBack)
        {
            return;
        }

        CMS.TreeEngine.TreeNode mNode = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

        if (mNode.NodeAliasPath == "/")
        {
            chkCssStyle.Visible = false;
            chkDescription.Visible = false;
            chkKeyWords.Visible = false;
            chkTitle.Visible = false;
        }

    }


    protected void Page_PreRender(object sender, EventArgs e)
    {
        if (hasModifyPermission)
        {
            this.pnlForm.Enabled = this.menuElem.AllowEdit;
        }
        this.lblWorkflowInfo.Text = this.menuElem.WorkflowInfo;
        this.lblWorkflowInfo.Visible = (this.lblWorkflowInfo.Text != "");
    }


    private void ReloadData()
    {
        if (node != null)
        {
            bool isRoot = (node.NodeAliasPath == "/");

            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            // Check modify permissions
            else if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
            {
                hasModifyPermission = false;
                this.pnlForm.Enabled = false;
                this.lblWorkflowInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
            }

            if (node.GetValue("DocumentPageTitle") != null)
            {
                this.txtTitle.Text = node.GetValue("DocumentPageTitle").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtTitle.Enabled = false;
                    chkTitle.Checked = true;
                    txtTitle.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageTitle IS NOT NULL", "DocumentPageTitle");
                }

            }

            if (node.GetValue("DocumentPageKeyWords") != null)
            {
                this.txtKeywords.Text = node.GetValue("DocumentPageKeyWords").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtKeywords.Enabled = false;
                    chkKeyWords.Checked = true;
                    txtKeywords.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageKeyWords IS NOT NULL", "DocumentPageKeyWords");
                }
            }

            if (node.GetValue("DocumentPageDescription") != null)
            {
                this.txtDescription.Text = node.GetValue("DocumentPageDescription").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtDescription.Enabled = false;
                    chkDescription.Checked = true;
                    txtDescription.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageDescription IS NOT NULL", "DocumentPageDescription");
                }
            }

            // fill drop down list
            DataSet ds = CssStylesheetInfoProvider.GetAllCssStylesheets();
            if ((ds != null) && (ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
            {
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    CssStylesheetInfo cs = new CssStylesheetInfo(dr);
                    if (cs.IsInSite(node.NodeSiteID))
                    {
                        ListItem li = new ListItem();
                        li.Text = dr["StylesheetDisplayName"].ToString();
                        li.Value = dr["StylesheetID"].ToString();
                        drpCssStyle.Items.Add(li);
                    }
                }
            }

            if (node.GetValue("DocumentStylesheetID") == null)
            {
                drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
            }
            else
            {
                if (ValidationHelper.GetInteger(node.GetValue("DocumentStylesheetID"), 0) == -1)
                {
                    if (!isRoot)
                    {
                        drpCssStyle.Enabled = false;
                        chkCssStyle.Checked = true;
                        string value = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentStylesheetID <> -1", "DocumentStylesheetID");

                        if (value == "")
                        {
                            drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
                        }
                        else
                        {
                            try
                            {
                                drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(value));
                            }
                            catch
                            {
                            }
                        }
                    }
                }
                else
                {
                    drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(node.GetValue("DocumentStylesheetID").ToString()));
                }
            }
        }
    }


    /// <summary>
    /// Updates node properties in database
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            VersionManager vm = null;
            bool useWorkflow = false;
            WorkflowManager workflowMan = new WorkflowManager();

            // Get the document
            node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

            //test if the document uses workflow
            if (workflowMan.GetNodeWorkflowScope(node) != null)
            {
                useWorkflow = true;
            }

            // If not using check-in/check-out, check out automatically
            if (autoCheck & useWorkflow)
            {
                if (node != null)
                {
                    // Check out
                    vm = new VersionManager(tree);
                    vm.CheckOut(node);

                }
            }

            // Update the data
            node.SetValue("DocumentPageTitle", null);
            if (!chkTitle.Checked)
            {
                node.SetValue("DocumentPageTitle", this.txtTitle.Text);
            }


            node.SetValue("DocumentPageKeyWords", null);
            if (!chkKeyWords.Checked)
            {
                node.SetValue("DocumentPageKeyWords", this.txtKeywords.Text);
            }

            node.SetValue("DocumentPageDescription", null);
            if (!chkDescription.Checked)
            {
                node.SetValue("DocumentPageDescription", this.txtDescription.Text);
            }

            node.SetValue("DocumentStylesheetID", -1);
            if (!chkCssStyle.Checked)
            {
                if (drpCssStyle.SelectedItem.Text == "(default)" && drpCssStyle.SelectedItem.Value == Convert.ToString(-1))
                {
                    node.SetValue("DocumentStylesheetID", null);
                }
                else
                {
                    node.SetValue("DocumentStylesheetID", drpCssStyle.SelectedValue);
                }
            }
            DocumentHelper.UpdateDocument(node, tree);

            // Check in the document
            if (autoCheck & useWorkflow)
            {
                vm.CheckIn(node, null, null);
            }

            this.menuElem.ReloadMenu();

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
        }
    }

    protected void chkTitle_CheckedChanged(object sender, EventArgs e)
    {
        if (chkTitle.Checked)
        {
            txtTitle.Enabled = false;
            txtTitle.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageTitle IS NOT NULL", "DocumentPageTitle");
        }
        else
        {
            txtTitle.Enabled = true;
        }
    }

    protected void chkDescription_CheckedChanged(object sender, EventArgs e)
    {
        if (chkDescription.Checked)
        {
            txtDescription.Enabled = false;
            txtDescription.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageDescription IS NOT NULL", "DocumentPageDescription");
        }
        else
        {
            txtDescription.Enabled = true;
        }
    }

    protected void chkKeyWords_CheckedChanged(object sender, EventArgs e)
    {
        if (chkKeyWords.Checked)
        {
            txtKeywords.Enabled = false;
            txtKeywords.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentPageKeyWords IS NOT NULL", "DocumentPageKeyWords");
        }
        else
        {
            txtKeywords.Enabled = true;
        }
    }

    protected void chkCssStyle_CheckedChanged(object sender, EventArgs e)
    {
        if (chkCssStyle.Checked)
        {

            drpCssStyle.Enabled = false;
            string value = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.DocumentNamePath, "DocumentStylesheetID <> -1", "DocumentStylesheetID");

            if (value == "")
            {
                drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
            }
            else
            {
                try
                {
                    drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(value));
                }
                catch
                {
                }
            }
        }
        else
        {
            drpCssStyle.Enabled = true;
        }
    }
}
