using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.DataEngine;

public partial class CMSDesk_Content_Properties_versions : CMSDeskPage
{
    CMS.TreeEngine.TreeNode node = null;
    WorkflowInfo wi = null;
    int nodeId = 0;
    bool mCanDestroy = false;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Current Node ID
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.ltlScript.Text += ScriptHelper.GetScript(
            "var varConfirmDestroy='" + ResHelper.GetString("VersionProperties.ConfirmDestroy") + "'; \n"
        );

        this.gridHistory.GridView.GridLines = GridLines.Horizontal;
        this.gridHistory.OnAction += new OnActionEventHandler(gridHistory_OnAction);    
        this.lblComment.Text = ResHelper.GetString("VersionsProperties.Comment");
        this.lblHistory.Text = ResHelper.GetString("VersionsProperties.History");
        this.lblVersion.Text = ResHelper.GetString("VersionsProperties.Version");

        this.btnCheckin.Text = ResHelper.GetString("VersionsProperties.btnCheckin");
        this.btnCheckout.Text = ResHelper.GetString("VersionsProperties.btnCheckout");
        this.btnUndoCheckout.Text = ResHelper.GetString("VersionsProperties.btnUndoCheckout");
        this.btnDestroy.Text = ResHelper.GetString("VersionsProperties.Destroy");

        // Get the node
        TreeProvider tree = new TreeProvider();
        node = tree.SelectSingleNode(nodeId);

        if (node != null)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }

            mCanDestroy = ((CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "Destroy") && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) != AuthorizationResultEnum.Denied))||((!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "Destroy")) && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) == AuthorizationResultEnum.Allowed)));
            this.btnDestroy.Enabled = mCanDestroy;

            WorkflowManager wm = new WorkflowManager();
            wi = wm.GetNodeWorkflow(node);

            // If no workflow set for node, hide the data  
            if (wi == null)
            {
                this.lblInfo.Text = ResHelper.GetString("VersionsProperties.ScopeNotSet");
                DisableForm();
                this.pnlVersions.Visible = false;
            }

            // Prepare the query parameters
            object[,] parameters = new object[1, 3];
            parameters[0, 0] = "@DocumentID";
            parameters[0, 1] = node.DocumentID;

            gridHistory.QueryParameters = parameters;
            gridHistory.OnExternalDataBound += new OnExternalDataBoundEventHandler(gridHistory_OnExternalDataBound);

            ReloadData();
        }
    }


    object gridHistory_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            case "allowdestroy":
                ((Control)sender).Visible = mCanDestroy;
                break;
        }
        return parameter;
    }


    void gridHistory_OnAction(string actionName, object actionArgument)
    {
        int versionHistoryId = ValidationHelper.GetInteger(actionArgument, 0);
        switch (actionName.ToLower())
        {
            case "rollback":
                if (versionHistoryId > 0)
                {
                    int checkedOutByUserId = ValidationHelper.GetInteger(node.GetValue("DocumentCheckedOutByUserId"), 0);
                    if (checkedOutByUserId > 0)
                    {
                        // Document is checked out
                        this.lblError.Text += ResHelper.GetString("VersionProperties.CannotRollbackCheckedOut");
                    }
                    else
                    {
                        // Rollback version
                        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                        VersionManager verMan = new VersionManager(tree);

                        try
                        {
                            verMan.RollbackVersion(versionHistoryId);
                            this.lblInfo.Text = ResHelper.GetString("VersionProperties.RollbackOK");
                        }
                        catch (Exception ex)
                        {
                            this.lblError.Text += ex.Message;
                        }
                    }
                    //this.ltlScript.Text += ScriptHelper.GetAlertScript("xxx" + versionHistoryId.ToString());
                }
                break;

            case "destroy":
                if (versionHistoryId > 0)
                {
                    if (node != null)
                    {
                        // Check permissions
                        if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node.NodeID, NodePermissionsEnum.Destroy) != AuthorizationResultEnum.Allowed)
                        {
                            lblError.Text = ResHelper.GetString("History.ErrorNotAllowedToDestroy");
                            return;
                        }

                        // Destroy version
                        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                        VersionManager verMan = new VersionManager(tree);

                        verMan.DestroyDocumentVersion(versionHistoryId);
                        this.lblInfo.Text = ResHelper.GetString("VersionProperties.DestroyOK");
                    }
                }
                break;
        }
    }


    /// <summary>
    /// Reloads the page data
    /// </summary>
    private void ReloadData()
    {
        mCanDestroy = ((CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "Destroy") && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) != AuthorizationResultEnum.Denied)) || ((!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "Destroy")) && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) == AuthorizationResultEnum.Allowed)));
        this.btnDestroy.Enabled = mCanDestroy;

        // Check modify permissions
        if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
        {
            DisableForm();
            this.lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
            this.gridHistory.GridView.Enabled = false;
        }
        else if (VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName))
        {
            this.btnCheckout.Visible = false;
            this.btnCheckout.Enabled = true;
            this.btnCheckin.Visible = false;
            this.btnCheckin.Enabled = true;
            this.btnUndoCheckout.Visible = false;
            this.btnUndoCheckout.Enabled = true;
            this.txtComment.Enabled = true;
            this.txtVersion.Enabled = true;
            this.lblComment.Enabled = true;
            this.lblVersion.Enabled = true;
            // Check whether to check out or in
            if (wi == null)
            {
                this.btnCheckout.Visible = true;
                this.lblCheckInfo.Text = ResHelper.GetString("VersionsProperties.CheckOut");
                this.lblInfo.Text = ResHelper.GetString("VersionsProperties.NotSupportWorkflow");
                DisableForm();
            }
            else if (node.GetValue("DocumentCheckedOutByUserID") == null)
            {
                this.lblCheckInfo.Text = ResHelper.GetString("VersionsProperties.CheckOut");
                this.lblInfo.Text = ResHelper.GetString("VersionsProperties.InfoCheckedIn");
                DisableForm();
                this.btnCheckout.Visible = true;
                this.btnCheckout.Enabled = true;
            }
            else
            {
                int checkedOutBy = ValidationHelper.GetInteger(node.GetValue("DocumentCheckedOutByUserID"), 0);
                // If checked out by current user, allow to check-in
                if (checkedOutBy == CMSContext.CurrentUser.UserID)
                {
                    this.btnCheckin.Visible = true;
                    this.btnUndoCheckout.Visible = true;
                    this.lblCheckInfo.Text = ResHelper.GetString("VersionsProperties.CheckIn");
                    this.lblInfo.Text = ResHelper.GetString("VersionsProperties.InfoCheckedOut");
                }
                else
                {
                    // Else checked out by somebody else
                    this.btnCheckout.Visible = true;
                    this.btnCheckin.Visible = true;
                    this.btnCheckout.Visible = false;
                    this.lblInfo.Text = ResHelper.GetString("VersionsProperties.IsCheckedOut");
                    this.lblCheckInfo.Text = ResHelper.GetString("VersionsProperties.CheckOut");
                    DisableForm();

                    bool canCheckIn = CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "CheckInAll");

                    this.btnUndoCheckout.Visible = canCheckIn;
                    this.btnUndoCheckout.Enabled = canCheckIn;
                    this.btnCheckin.Enabled = canCheckIn;
                }
            }
        }
        else
        {
            this.plcForm.Visible = false;
        }
    }


    /// <summary>
    /// Disables the editing form
    /// </summary>
    private void DisableForm()
    {
        this.txtComment.Enabled = false;
        this.txtVersion.Enabled = false;

        this.btnCheckin.Enabled = false;
        this.btnCheckout.Enabled = false;
        this.btnUndoCheckout.Enabled = false;
    }


    protected void btnCheckout_Click(object sender, EventArgs e)
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        VersionManager verMan = new VersionManager(tree);

        verMan.EnsureVersion(node);

        // Check out the document
        verMan.CheckOut(node);

        ReloadData();
        gridHistory.ReloadData();
    }


    protected void btnCheckin_Click(object sender, EventArgs e)
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        VersionManager verMan = new VersionManager(tree);

        // Check in the document        
        string version = null;
        if (this.txtVersion.Text.Trim() != "")
        {
            version = this.txtVersion.Text.Trim();
        }
        string comment = null;
        if (this.txtComment.Text.Trim() != "")
        {
            comment = this.txtComment.Text.Trim();
        }

        verMan.CheckIn(node, version, comment);

        this.txtComment.Text = "";
        this.txtVersion.Text = "";

        ReloadData();
        gridHistory.ReloadData();
    }


    protected void btnUndoCheckout_Click(object sender, EventArgs e)
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        VersionManager verMan = new VersionManager(tree);

        // Undo check out
        verMan.UndoCheckOut(node);

        ReloadData();
        gridHistory.ReloadData();
    }


    protected void btnDestroy_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            // Check permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node.NodeID, NodePermissionsEnum.Destroy) != AuthorizationResultEnum.Allowed)
            {
                lblError.Text = ResHelper.GetString("History.ErrorNotAllowedToDestroy");
                return;
            }

            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            VersionManager verMan = new VersionManager(tree);

            verMan.DestroyDocumentHistory(node.DocumentID);

            ReloadData();
            gridHistory.ReloadData();
        }
    }

}

