using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.FileManager;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.SettingsProvider;

public partial class CMSDesk_Content_SelectImageDialog_Content : CMSModalPage
{
    protected int nodeId = 0;
    protected string returnvalue = "url";
    protected string select = "image";

    protected void Page_Load(object sender, EventArgs e)
    {
        // Process the URL values
        returnvalue = ValidationHelper.GetString(Request.QueryString["returnvalue"], "url").ToLower();
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        select = ValidationHelper.GetString(Request.QueryString["select"], "image");


        if (nodeId > 0)
        {
            // get selected node
            TreeProvider tree = new TreeProvider();
            //CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            CMS.TreeEngine.TreeNode node = DocumentHelper.GetDocument(nodeId, TreeProvider.ALL_CULTURES, tree);

            if (node != null)
            {
                // get selected node site info
                SiteInfo si = SiteInfoProvider.GetSiteInfo(node.NodeSiteID);
                if (si != null)
                {
                    // Detail view 
                    if (node.NodeClassName.ToLower() == "cms.file")
                    {
                        // Display detail view
                        pnlDetailView.Visible = true;

                        // initialize labels
                        lblFileName.Text = ResHelper.GetString("SelectImageDialog.AttachmentNameLabel");
                        lblFilePath.Text = ResHelper.GetString("SelectImageDialog.AttachmentPathLabel");
                        lblFileSize.Text = ResHelper.GetString("SelectImageDialog.AttachmentSizeLabel");
                        //lblFileView.Text = ResHelper.GetString("SelectImageDialog.AttachmentViewLabel");

                        // get attachment info and initialize displayed attachment properties
                        AttachmentManager atManager = new AttachmentManager();
                        Guid attachmentGUID = ValidationHelper.GetGuid(node.GetValue("FileAttachment"), Guid.Empty);

                        if (attachmentGUID != Guid.Empty)
                        {
                            int maxSideSize = 400;

                            // Get the attachment
                            AttachmentInfo atInfo = DocumentHelper.GetAttachment(node, attachmentGUID, tree);
                            if (atInfo != null)
                            {
                                // set 'get file path'
                                string fileUrl = null;
                                if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSUsePermanentURLs"))
                                {
                                    if (CMSContext.CurrentSite.SiteID != si.SiteID)
                                    {
                                        fileUrl = AttachmentManager.GetPermanentAttachmentUrl(si.SiteName, node.NodeGUID, node.NodeAlias);
                                    }
                                    else
                                    {
                                        fileUrl = ResolveUrl(AttachmentManager.GetPermanentAttachmentUrl(node.NodeGUID, node.NodeAlias));
                                    }
                                }
                                else
                                {
                                    fileUrl = CMSContext.GetUrl(node.NodeAliasPath, node.DocumentUrlPath);
                                }

                                lblFileNameValue.Text = atInfo.AttachmentName;
                                lblFileSizeValue.Text = atInfo.AttachmentSize.ToString();
                                lblFilePathValue.Text = fileUrl;

                                // Get the data
                                string extension = atInfo.AttachmentExtension;
                                string nodeAlias = node.NodeAlias;

                                this.plcPaste.Visible = true;

                                lnkPaste.NavigateUrl = "#";

                                switch (returnvalue)
                                {
                                    case "url":
                                        // get attachment url
                                        string attachmentUrl = fileUrl;

                                        if (ImageHelper.IsFlash(extension))
                                        {
                                            attachmentUrl += "?ext=.swf";
                                            lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteFlash");
                                        }
                                        else
                                            if (ImageHelper.IsImage(extension))
                                            {
                                                lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteImage");
                                            }
                                            else
                                            {
                                                lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteFile");
                                            }



                                        lnkPaste.Attributes.Add("onclick", "SetUrl('" + ResolveUrl(attachmentUrl) + "', '" + Request.QueryString["selectorId"] + "'); return false;");
                                        break;

                                    case "nodeguid":
                                        Guid nodeGuid = node.NodeGUID;
                                        lnkPaste.Attributes.Add("onclick", "SetValue('" + nodeGuid.ToString() + "', '" + Request.QueryString["selectorId"] + "'); return false;");
                                        if (ImageHelper.IsImage(extension))
                                        {
                                            lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteImage");
                                        }
                                        else
                                        {
                                            lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteFile");
                                        }
                                        break;

                                    default:
                                        lnkPaste.Visible = false;
                                        break;
                                }

                                if (ImageHelper.IsImage(extension))
                                {
                                    string maxSideSizeString = null;
                                    // set max side size
                                    if (maxSideSize > 0)
                                    {
                                        maxSideSizeString = "?maxsidesize=" + maxSideSize;
                                    }
                                    imgPreview.ImageUrl = fileUrl + maxSideSizeString;
                                }
                                else
                                {
                                    lnkPreview.Text = ResHelper.GetString("SelectImageDialog.OpenDocument");
                                }

                                lnkPreview.NavigateUrl = fileUrl;

                            }
                        }
                    }
                    // list view
                    //-----------------------------------
                    else
                    {
                        gridDocuments.Visible = true;

                        gridDocuments.Columns[0].HeaderText = ResHelper.GetString("SelectImageDialog.AttachmentName");
                        gridDocuments.Columns[1].HeaderText = ResHelper.GetString("SelectImageDialog.AttachmentSize");

                        // get files
                        tree.SelectQueryName = "selectattachments";
                        DataSet nodes = tree.SelectNodes(si.SiteName, node.NodeAliasPath.TrimEnd('/') + "/%", CMSContext.CurrentUser.PreferredCultureCode, false, "cms.file", "NodeAliasPath <> '/'", "NodeOrder ASC, NodeName ASC, NodeAlias ASC", 1, false);

                        if (!DataHelper.DataSourceIsEmpty(nodes))
                        {
                            gridDocuments.DataSource = nodes;
                            gridDocuments.DataBind();
                        }
                    }
                }

            }
        }

    }


    protected void gridDocuments_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        int maxSideSize = 50;

        if (e.Row.DataItem != null)
        {
            // Get the data
            string extension = Convert.ToString(((DataRowView)(e.Row.DataItem))["AttachmentExtension"]);
            //Guid guid = (Guid)(((DataRowView)(e.Row.DataItem))["AttachmentGuid"]);
            Guid nodeGuid = (Guid)(((DataRowView)(e.Row.DataItem))["NodeGuid"]);
            string nodeAlias = Convert.ToString(((DataRowView)(e.Row.DataItem))["NodeAlias"]);
            int siteId = ValidationHelper.GetInteger(((DataRowView)(e.Row.DataItem))["NodeSiteID"], 0);
            string siteName = ValidationHelper.GetString(((DataRowView)(e.Row.DataItem))["SiteName"], "");

            // Get permanent URL
            string fileUrl = null;
            if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSUsePermanentURLs"))
            {
                if (CMSContext.CurrentSite.SiteID != siteId)
                {
                    fileUrl = AttachmentManager.GetPermanentAttachmentUrl(siteName, nodeGuid, nodeAlias);
                }
                else
                {
                    fileUrl = ResolveUrl(AttachmentManager.GetPermanentAttachmentUrl(nodeGuid, nodeAlias));
                }
            }
            else
            {
                string nodeAliasPath = Convert.ToString(((DataRowView)(e.Row.DataItem))["NodeAliasPath"]);
                string documentUrlPath = Convert.ToString(((DataRowView)(e.Row.DataItem))["DocumentUrlPath"]);
                fileUrl = CMSContext.GetUrl(nodeAliasPath, documentUrlPath);
            }

            // If image - display paste image, if flash  - display paste flash
            if ((ImageHelper.IsImage(extension) && (select.ToLower() == "image")) ||
                (ImageHelper.IsFlash(extension) && (select.ToLower() == "flash")))
            {
                // Paste link
                HyperLink lnkPaste = (HyperLink)e.Row.FindControl("lnkPaste");
                if (lnkPaste != null)
                {
                    lnkPaste.NavigateUrl = "#";
                    switch (returnvalue)
                    {
                        case "url":
                            // Get attachment url
                            string attachmentUrl = fileUrl;
                            if (ImageHelper.IsFlash(extension))
                            {
                                attachmentUrl += "?ext=.swf";
                                lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteFlash");
                            }
                            else
                            {
                                lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteImage");
                            }

                            lnkPaste.Attributes.Add("onclick", "SetUrl('" + ResolveUrl(attachmentUrl) + "', '" + Request.QueryString["selectorId"] + "'); return false;");
                            break;

                        case "nodeguid":
                            lnkPaste.Attributes.Add("onclick", "SetValue('" + nodeGuid.ToString() + "', '" + Request.QueryString["selectorId"] + "'); return false;");
                            lnkPaste.Text = ResHelper.GetString("SelectImageDialog.PasteImage");
                            break;

                        default:
                            lnkPaste.Visible = false;
                            break;
                    }
                }
            }

            // Preview image
            Image imgPreview = (Image)e.Row.FindControl("imgPreview");
            HyperLink lnkPreview = (HyperLink)e.Row.FindControl("lnkPreview");
            if (imgPreview != null)
            {
                string maxSideSizeString = null;
                // set max side size
                if (maxSideSize > 0)
                {
                    maxSideSizeString = "?maxsidesize=" + maxSideSize;
                }

                // set displayed text/image
                if (ImageHelper.IsImage(extension))
                {
                    imgPreview.ImageUrl = fileUrl + maxSideSizeString;
                }
                else
                {
                    lnkPreview.Text = ResHelper.GetString("SelectImageDialog.OpenDocument");
                }

                lnkPreview.NavigateUrl = fileUrl;
            }
        }

    }
}
