using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.WorkflowEngine;
using CMS.SiteProvider;
using CMS.EventLog;
using CMS.SettingsProvider;

/// <summary>
/// Page to process the Content data requests
/// </summary>
public partial class CMSDesk_Content_request : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // indicates whether user is authorized to copy/move document
        bool isAuthorized = false;

        // If action not specified, do nothing
        if (Request.QueryString["action"] == null)
        {
            return;
        }

        // Current Node ID
        int nodeId = 0;
        if (Request.QueryString["nodeid"] != null)
        {
            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        }
        // Target node ID (for copy, move operations)
        int targetId = 0;
        if (Request.QueryString["targetid"] != null)
        {
            targetId = ValidationHelper.GetInteger(Request.QueryString["targetid"], 0);
        }
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        EventLogProvider log = new EventLogProvider(tree.Connection);
        string documentName = "";
        // Process the request
        switch ((string)Request.QueryString["action"].ToLower())
        {
            case "copy":
                // Copy the document to the specified location
                try
                {
                    int oldNodeId = 0;
                    int oldNodeParenId = 0;
                    int oldSiteId = 0;

                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                        return;
                    }

                    if (targetId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingTarget"));
                        return;
                    }

                    // Get the document to copy
                    CMS.TreeEngine.TreeNode node = DocumentHelper.GetDocument(nodeId, TreeProvider.ALL_CULTURES, tree);

                    oldNodeId = node.NodeID;
                    oldNodeParenId = node.NodeParentID;
                    oldSiteId = node.NodeSiteID;

                    // check copy permission
                    if (node != null)
                    {
                        documentName = node.DocumentName;
                        isAuthorized = IsUserAuthorizedToCopy(nodeId, targetId, node.NodeClassName);
                    }

                    // (isAuthorized == true) -> copy is allowed
                    // (node == null) -> copy is allowed, DocumentHelper.CopyDocument() throws exception: "Missing document node"
                    if ((isAuthorized) || (node == null))
                    {
                        // Check if allow child type
                        CMS.TreeEngine.TreeNode targetNode = tree.SelectSingleNode(targetId);
                        if (targetNode == null)
                        {
                            AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingTarget"));
                            break;
                        }
                        int targetClassId = ValidationHelper.GetInteger(targetNode.GetValue("NodeClassID"), 0);
                        int nodeClassId = ValidationHelper.GetInteger(node.GetValue("NodeClassID"), 0);
                        if ( !DataClassInfoProvider.IsChildClassAllowed(targetClassId, nodeClassId))
                        {
                            AddAlert(ResHelper.GetString("ContentRequest.ErrorChildClassNotAllowed"));
                            break;
                        }

                        // Copy the document
                        node = DocumentHelper.CopyDocument(node, targetId, true, tree);


                        // Set moved document in current site or parent node if copy to other site
                        if (oldSiteId == node.NodeSiteID)
                        {
                            // Process result
                            if (node != null)
                            {
                                AddScript("SelectNode(" + node.NodeID + "); RefreshNode(" + targetId + ", " + node.NodeID + ");\n");
                            }
                            else
                            {
                                AddAlert(ResHelper.GetString("ContentRequest.CopyFailed"));
                            }
                        }

                    }
                    // user is not authorized to copy
                    else
                    {
                        AddAlert(ResHelper.GetString("CMSDesk.NotAuthorizedToCopyDocument"));
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "COPYDOC", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.CopyFailed") + " : " + ex.Message + " : " + ex.StackTrace);
                }
                break;

            case "move":
                // Move the document to the new location
                try
                {

                    int oldSiteId = 0;
                    int parentId = 0;

                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                        return;
                    }
                    if (targetId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingTarget"));
                        return;
                    }

                    // Get the document
                    CMS.TreeEngine.TreeNode node = DocumentHelper.GetDocument(nodeId, TreeProvider.ALL_CULTURES, tree);

                    oldSiteId = node.NodeSiteID;
                    parentId = node.NodeParentID;

                    // check copy permission
                    if (node != null)
                    {
                        documentName = node.DocumentName;
                        isAuthorized = IsUserAuthorizedToMove(nodeId, targetId, node.NodeClassName);
                    }

                    // (isAuthorized == true) -> move is allowed
                    // (node == null) -> move is allowed, DocumentHelper.MoveDocument() throws exception: "Missing document node"
                    if ((isAuthorized) || (node == null))
                    {
                        // Check if allow child type
                        CMS.TreeEngine.TreeNode targetNode = tree.SelectSingleNode(targetId);
                        if (targetNode == null)
                        {
                            AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingTarget"));
                            break;
                        }
                        int targetClassId = ValidationHelper.GetInteger(targetNode.GetValue("NodeClassID"), 0);
                        int nodeClassId = ValidationHelper.GetInteger(node.GetValue("NodeClassID"), 0);
                        if (!DataClassInfoProvider.IsChildClassAllowed(targetClassId, nodeClassId))
                        {
                            AddAlert(ResHelper.GetString("ContentRequest.ErrorChildClassNotAllowed"));
                            break;
                        }

                        // Move the document
                        DocumentHelper.MoveDocument(node, targetId, tree);


                        // Set moved document in current site or parent node if copy to other site
                        if (oldSiteId == node.NodeSiteID)
                        {
                            // Process result
                            if (node != null)
                            {
                                AddScript("RefreshNode(" + targetId + ");\n");
                            }
                            else
                            {
                                AddAlert(ResHelper.GetString("ContentRequest.MoveFailed"));
                            }
                        }
                        else
                        {
                            if (node != null)
                            {
                                AddScript("RefreshNode(" + parentId + ", " + parentId + ");");
                                AddScript("SelectNode(" + parentId + ");");
                            }
                            else
                            {
                                AddAlert(ResHelper.GetString("ContentRequest.MoveFailed"));
                            }
                        }

                    }
                    // user is not authorized to move
                    else
                    {
                        AddAlert(ResHelper.GetString("CMSDesk.NotAuthorizedToMoveDocument"));
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "MOVEDOC", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.MoveFailed") + " : " + ex.Message);
                }
                break;
            case "moveup":
                // Move the document up (document order)
                try
                {
                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                        return;
                    }
                    CMS.TreeEngine.TreeNode node = tree.MoveNodeUp(nodeId);
                    // Move the node
                    if (node != null)
                    {
                        documentName = node.DocumentName;
                        AddScript("     RefreshNode(" + node.NodeParentID + ");");
                    }
                    else
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.MoveFailed"));
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "MOVEUP", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.MoveFailed") + " : " + ex.Message);
                }
                break;
            case "movedown":
                // Move the document down (document order)
                try
                {
                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                        return;
                    }
                    CMS.TreeEngine.TreeNode node = tree.MoveNodeDown(nodeId);
                    // Move the node
                    if (node != null)
                    {
                        documentName = node.DocumentName;
                        AddScript("     RefreshNode(" + node.NodeParentID + ");");
                    }
                    else
                    {
                        AddAlert(ResHelper.GetString("ContentRequest.MoveFailed"));
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "MOVEDOWN", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.MoveFailed") + " : " + ex.Message);
                }
                break;

            // Sets the menu item page mode
            case "setmenuitemmode":
            case "setdocumentmode":
                try
                {
                    string mode = "";
                    if (Request.QueryString["mode"] != null)
                    {
                        mode = Request.QueryString["mode"].ToLower();
                    }
                    // Get the new mode
                    ViewModeEnum newMode = ViewModeEnum.Edit;
                    switch (mode)
                    {
                        case "editform":
                            newMode = ViewModeEnum.EditForm;
                            AddScript("     RefreshDocument();");
                            break;
                        case "edit":
                            newMode = ViewModeEnum.Edit;
                            AddScript("     RefreshDocument();");
                            break;
                        case "design":
                            newMode = ViewModeEnum.Design;
                            AddScript("     RefreshDocument();");
                            break;
                        case "livesite":
                            newMode = ViewModeEnum.LiveSite;
                            AddScript("     RefreshDocument();");
                            break;
                        case "preview":
                            newMode = ViewModeEnum.Preview;
                            AddScript("     RefreshDocument();");
                            break;
                        default:
                            AddAlert(ResHelper.GetString("ContentRequest.ErrorUnknownMode"));
                            AddScript("     RefreshDocument();");
                            return;
                    }
                    // Set the mode
                    if ((string)Request.QueryString["action"].ToLower() == "setdocumentmode")
                    {
                        CMSContext.CurrentUser.ViewMode = newMode;
                    }
                    else
                    {
                        CMSContext.CurrentUser.MenuItemViewMode = newMode;
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "SETMODE", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.ErrorUnknownMode") + " : " + ex.Message);
                }
                break;

            case "setculture":
                // Set the preferred culture code
                try
                {
                    // Set the culture code
                    if ((Request.QueryString["culturecode"] != null) && (Request.QueryString["culturecode"] != ""))
                    {
                        CMSContext.CurrentUser.PreferredCultureCode = Request.QueryString["culturecode"];
                    }
                    // Refresh the document
                    if (nodeId > 0)
                    {
                        AddScript("     RefreshNode(" + nodeId + ");");
                        AddScript("     SelectNode(" + nodeId + ");");
                    }
                }
                catch (Exception ex)
                {
                    log.LogEvent("E", DateTime.Now, "Content", "SETCULTURE", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, nodeId, documentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                    AddAlert(ResHelper.GetString("ContentRequest.ErrorChangeLanguage"));
                }
                break;
        }

    }

    /// <summary>
    /// Determines whether current user is authorized to copy document.
    /// </summary>
    /// <param name="sourceNodeId">Source node id.</param>
    /// <param name="targetNodeId">Target node class name.</param>
    /// <param name="sourceNodeClassName">Source node class name.</param>
    /// <returns></returns>
    private bool IsUserAuthorizedToCopy(int sourceNodeId, int targetNodeId, string sourceNodeClassName)
    {
        bool isAuthorized = false;

        // check 'read permission' to source document
        if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(sourceNodeId, NodePermissionsEnum.Read) != AuthorizationResultEnum.Denied)
        {
            // check 'create permission'
            if (CMSContext.CurrentUser.IsAuthorizedToCreateNewDocument(targetNodeId, sourceNodeClassName))
            {
                isAuthorized = true;
            }
        }

        return isAuthorized;
    }


    /// <summary>
    /// Determines whether current user is authorized to move document.
    /// </summary>
    /// <param name="sourceNodeId">Source node id.</param>
    /// <param name="targetNodeId">Target node class name.</param>
    /// <param name="sourceNodeClassName">Source node class name.</param>
    /// <returns></returns>
    private bool IsUserAuthorizedToMove(int sourceNodeId, int targetNodeId, string sourceNodeClassName)
    {
        bool isAuthorized = false;

        // check 'modify permission' to source document
        if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(sourceNodeId, NodePermissionsEnum.Modify) != AuthorizationResultEnum.Denied)
        {
            // check 'create permission'
            if (CMSContext.CurrentUser.IsAuthorizedToCreateNewDocument(targetNodeId, sourceNodeClassName))
            {
                isAuthorized = true;
            }
        }

        return isAuthorized;
    }



    /// <summary>
    /// Adds the alert message to the output request window
    /// </summary>
    /// <param name="message">Message to display</param>
    private void AddAlert(string message)
    {
        this.ltlScript.Text += ScriptHelper.GetAlertScript(message);
    }


    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }
}
