using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;

public partial class CMSDesk_Content_search : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        this.lblSearch.Text = ResHelper.GetString("Search.lblSearch");
        this.btnSearch.Text = ResHelper.GetString("Search.btnSearch");     
    }

    protected void btnSearch_Click(object sender, EventArgs e)
    {
        DisplaySearchResults();
    }

    /// <summary>
    /// Item data bound event handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void RowDataBound(object sender, GridViewRowEventArgs e)         
    {
        if (e.Row.DataItem != null)
        {
            int nodeId = 0;
            string nodeClassName = "";
            string imageUrl = "";
            string navigetUrl = "";
            string linkText = "";

            // set navigate url
            nodeId = Convert.ToInt32(((DataRowView)(e.Row.DataItem))["NodeId"]);
            navigetUrl = "javascript:SelectItem(" + Convert.ToString(nodeId) + ")";

            // set image url
            nodeClassName = Convert.ToString(((DataRowView)(e.Row.DataItem))["ClassName"]);
            imageUrl = "~/App_Themes/" + this.Page.Theme + "/Images/CMSDesk/Icons/" + nodeClassName.Replace(".", "_") + ".gif";                

            // set link text
            linkText = Convert.ToString(((DataRowView)(e.Row.DataItem))["DocumentName"]); 


            HyperLink lnkDocumentIcon = (HyperLink)e.Row.FindControl("lnkDocumentIcon");
            if (lnkDocumentIcon != null)
            {
                lnkDocumentIcon.ImageUrl = imageUrl;
                lnkDocumentIcon.NavigateUrl = navigetUrl;
            }

            HyperLink lnkDocumentName = (HyperLink)e.Row.FindControl("lnkDocumentName");
            if (lnkDocumentName != null)
            {
                lnkDocumentName.Text = linkText;
                lnkDocumentName.NavigateUrl = navigetUrl;
            }
        }
    }

    /// <summary>
    /// Page index changing event handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void gridSearchResults_PageIndexChanging(object sender, GridViewPageEventArgs e)
    {
        // Set page index
        gridSearchResults.PageIndex = e.NewPageIndex;

        DisplaySearchResults();
    }


    /// <summary>
    /// Displays search results.
    /// </summary>
    protected void DisplaySearchResults()
    {
        TreeProvider tp = new TreeProvider();
        string currentSite = "";
        string currentCulture = "";
        string searchExpr = txtSearch.Text;
        DataSet dsSearchResult = null;

        if (CMSContext.CurrentSite != null)
        {
            currentSite = CMSContext.CurrentSite.SiteName;

            if (CMSContext.CurrentUser != null)
            {
                currentCulture = CMSContext.CurrentUser.PreferredCultureCode;

                // get seach result
                tp.UserInfo = CMSContext.CurrentUser;
                dsSearchResult = tp.Search(currentSite, "/%", currentCulture, searchExpr, CMS.ISearchEngine.SearchModeEnum.AnyWord, true, null, true, false, null, null);

                // no results found
                if (DataHelper.DataSourceIsEmpty(dsSearchResult))
                {
                    lblSearchInfo.Visible = true;
                    lblSearchInfo.Text = ResHelper.GetString("Content_Search.NoResultsFound");
                }
                // display found results
                else
                {
                    lblSearchInfo.Visible = false;
                    dsSearchResult.Tables[0].DefaultView.Sort = "DocumentName";
                    gridSearchResults.DataSource = dsSearchResult.Tables[0];
                    gridSearchResults.DataBind();
                }
            }
        }
    }
}
