using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;

public partial class CMSDesk_Header : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        lnkSiteManager.Visible = false;
        if (CMSContext.CurrentUser.IsGlobalAdministrator == true)
        {
            lnkSiteManager.Visible = true;
        }

        this.pnlSignOut.BackImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/signout_empty.gif";
        this.lblSignOut.Text = ResHelper.GetString("signoutbutton.signout");
        
        this.lblUser.Text = ResHelper.GetString("Header.User");
        this.lblUserInfo.Text = CMSContext.CurrentUser.FullName;
        this.lblSite.Text = ResHelper.GetString("Header.Site");
        // Fill label or dropdownlist with user's site names.
        if (!Page.IsPostBack) SetUserSiteLayout();
        // Register 
        drpSite.Attributes.Add("OnChange", "SiteRedirect()");
        this.lnkSiteManager.Text = ResHelper.GetString("Header.SiteManager");
        this.lnkSiteManager.NavigateUrl = "~/CMSSiteManager";
        this.lnkSiteManager.Target = "_parent";
               
        ArrayList tabList = new ArrayList();                
        TreeProvider tree = new TreeProvider();
        bool userHasExploreTreePermission = false;
   
        if (IsUserAuthorizedPerContent())
        {
            tabList.Add("content");
        }

        tabList.Add("mydesk");

        if (CMSContext.CurrentUser.IsAuthorizedPerResource("cms.tools", "Open"))
        {
            tabList.Add("tools");
        }

        if (CMSContext.CurrentUser.IsAuthorizedPerResource("cms.administration", "Read"))
        {
            tabList.Add("administration");
        }

        string[,] tabs = new string[tabList.Count, 4];
        int activePageIndex = 0;

        string section = ValidationHelper.GetString(Request.QueryString["section"], "").ToLower();

        if (section == "")
        {
            activePageIndex = 0;
        }

        for (int i = 0; i < tabList.Count; i++)
        {
            if (tabList[i].ToString() == section)
            {
                activePageIndex = i;
            }

            if (tabList[i].ToString() == "content")
            {
                tabs[i, 0] = ResHelper.GetString("Header.Content");
                tabs[i, 2] = "content/default.aspx";
            }

            if (tabList[i].ToString() == "mydesk")
            {
                tabs[i, 0] = ResHelper.GetString("Header.MyDesk");
                tabs[i, 2] = "mydesk/default.aspx";
            }

            if (tabList[i].ToString() == "tools")
            {
                tabs[i, 0] = ResHelper.GetString("Header.Tools");
                tabs[i, 2] = "tools/default.aspx";
            }

            if (tabList[i].ToString() == "administration")
            {
                tabs[i, 0] = ResHelper.GetString("Header.Administration");
                tabs[i, 2] = "administration/default.aspx";
            }
        }

        BasicTabControlHeader.Tabs = tabs;
        BasicTabControlHeader.SelectedTab = activePageIndex;
        BasicTabControlHeader.UrlTarget = "cmsdesktop";
    }


    /// <summary>
    /// Fill dropdownlist with site names if user has access to multiple sites
    /// or set label text if user can access only single site.
    /// </summary>
    protected void SetUserSiteLayout()
    {
        DataTable sites = null;

        // If actual user is global administrator, get all sites
        if (CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            DataSet ds = SiteInfoProvider.GetAllSites();
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                sites = ds.Tables[0];
            }
        }
        // Else get only user's sites.
        else
        {
            sites = UserInfoProvider.GetUserSites(CMSContext.CurrentUser.UserID);
        }
        // Fill dropdownlist.
        if (sites != null)
        {
            // Sort sites by their names.
            DataRow[] sortedSites = sites.Select(null, "SiteDisplayName");

            ListItem li = null;
            int index = 0;
            foreach (DataRow row in sortedSites)
            {
                // Only runnig sites are added.
                if (row["SiteStatus"].ToString() == "RUNNING")
                {
                    // Make url for each site in form 'http(s)://sitedomain/application/cmsdesk'.
                    string sitedomain = row["SiteDomainName"].ToString();
                    // application includes string '/cmsdesk'.
                    string application = ResolveUrl("~/cmsdesk");
                    string url = Request.Url.Scheme + "://" + sitedomain + application;
                    // Create list item and add it to the dropdownlist.
                    li = new ListItem(row["SiteDisplayName"].ToString(), url);
                    this.drpSite.Items.Add(li);
                    if (row["SiteName"].ToString() == CMSContext.CurrentSite.SiteName)
                    {
                        // Select current site in dropdownlist.
                        this.drpSite.SelectedIndex = index;
                    }
                    index++;
                }
            }

            this.lblSiteInfo.Visible = false;
            this.drpSite.Visible = true;
        }
        // Put current site name to label text.
        else
        {
            this.lblSiteInfo.Text = CMSContext.CurrentSite.DisplayName;

            this.lblSiteInfo.Visible = true;
            this.drpSite.Visible = false;
        }
    }


    protected void btnSignOut_Click(object sender, EventArgs e)
    {
        this.SignOut();
        LiteralScript.Text = "<script language=\"javascript\" type=\"text/javascript\">parent.location.href= '../default.aspx';</script> ";
    }

}
