using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.FormEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.SettingsProvider;

public partial class CMSDesk_PortalEngine_code : CMSModalPage
{
    protected string mAliasPath = null;
    protected string mZoneId = null;
    protected string mWebpartId = null;

    /// <summary>
    /// Page alias path
    /// </summary>
    public string AliasPath
    {
        get
        {
            return mAliasPath;
        }
        set
        {
            mAliasPath = value;
        }
    }


    /// <summary>
    /// Zone ID
    /// </summary>
    public string ZoneId
    {
        get
        {
            return mZoneId;
        }
        set
        {
            mZoneId = value;
        }
    }


    /// <summary>
    /// Web part ID
    /// </summary>
    public string WebpartId
    {
        get
        {
            return mWebpartId;
        }
        set
        {
            mWebpartId = value;
        }
    }

    /// <summary>
    /// Current page info
    /// </summary>
    PageInfo pi = null;

    /// <summary>
    /// Current zone
    /// </summary>
    WebPartZoneInstance zone = null;

    /// <summary>
    /// Current web part
    /// </summary>
    WebPartInstance webPart = null;

    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);
        AliasPath = Convert.ToString(Request.QueryString["aliaspath"]);
        WebpartId = Convert.ToString(Request.QueryString["webpartid"]);
        ZoneId = Convert.ToString(Request.QueryString["zoneid"]);

        if ((WebpartId != "") && (ZoneId != "") && (AliasPath != ""))
        {
            // get pageinfo
            pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, AliasPath, CMSContext.CurrentUser.PreferredCultureCode, null, CMSContext.CurrentSite.CombineWithDefaultCulture);
            // get zone instance
            zone = pi.PageTemplateInfo.GetZone(ZoneId);
            // get webpart
            webPart = zone.GetWebPart(WebpartId);
            txtCode.Text = Convert.ToString(webPart.GetValue("WebPartCode"));
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        if (!SettingsKeyProvider.UsingVirtualPathProvider)
        {
            this.lblInfo.Text = ResHelper.GetString("WebPartCode.ProviderNotRunning");
            this.txtCode.Enabled = false;
        }
        else
        {
            this.lblInfo.Text = ResHelper.GetString("WebPartCode.Info");
            btnOnOK.Click += new EventHandler(btnOnOK_Click);
            btnOnApply.Click += new EventHandler(btnOnApply_Click);

            Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ApplyButton", ScriptHelper.GetScript("function OnApplyButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnApply, "") + "}"
                                                                                                         + "function OnOKButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnOK, "") + "}"));
        }
    }


    /// <summary>
    /// Saves webpart properties.
    /// </summary>
    public void Save()
    {
        webPart.SetValue("WebPartCode", txtCode.Text);
        // Update page template
        PageTemplateInfoProvider.SetPageTemplateInfo(pi.PageTemplateInfo);

        string parameters = this.AliasPath + "/" + this.ZoneId + "/" + this.WebpartId;
        string cacheName = "CMSVirtualWebParts|" + parameters.ToLower().TrimStart('/');
        HttpContext.Current.Cache.Remove(cacheName);
    }


    /// <summary>
    /// Saves the webpart properties and closes the window.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOnOK_Click(object sender, EventArgs e)
    {
        // Save webpart properties
        Save();

        // Close the window
        ltlScript.Text += ScriptHelper.GetScript("top.window.close();");
    }


    /// <summary>
    /// Saves the webpart properties
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOnApply_Click(object sender, EventArgs e)
    {
        Save();
    }
}
