using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.FormEngine;
using CMS.DataEngine;
using CMS.CMSHelper;
using CMS.ZipUtilities;
using CMS.DirectoryUtilities;

public partial class CMSDesk_Tools_BizForms_BizForm_Edit_Export : CMSDeskPage
{
    protected bool office2007 = false;
    protected int formId = 0;

    protected string EXPORT_RELATIVE_PATH = "~/CMSSiteUtils/";

    protected string subPath = "\\BizFormExportTMP\\";

    protected void Page_Load(object sender, EventArgs e)
    {
        if (ValidationHelper.GetString(Request.QueryString["office"], "") != "")
        {
            office2007 = true;
        }

        string content = "";

        // check 'ReadData' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadData"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "ReadData");
        }

        FormFieldInfo ffi = null;
        BizFormInfo bfi = null;
        DataSet dsFormData = null;
        DataClassInfo dci = null;
        GeneralConnection genConn = null;
        BoundColumn column = null;
        string className = "";
        string classFormDefinition = "";
        string formName = "";
        string[] displayedFields = null;


        // get form id from url
        formId = ValidationHelper.GetInteger(Request.QueryString["formid"], 0);

        bfi = BizFormInfoProvider.GetBizFormInfo(formId);

        if (bfi != null)
        {
            // set form name
            formName = bfi.FormName;

            dci = DataClassInfoProvider.GetDataClass(bfi.FormClassID);
            if (dci != null)
            {
                // set form class name
                className = dci.ClassName;
                // set class form definition
                classFormDefinition = dci.ClassFormDefinition;
            }

            // get all form data
            genConn = ConnectionHelper.GetConnection();
            dsFormData = genConn.ExecuteQuery(className + ".selectall", null, null, null);


            // load form definition
            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(classFormDefinition);

            int mColumns = 0;

            string reportFields = "";

            // Get all column names
            string[] columnNames = fi.GetColumnNames();

           Hashtable displColumns = new Hashtable();
           
            if (columnNames != null)
            {
                // add displayed columns
                if ((bfi.FormReportFields != null) && (bfi.FormReportFields != ""))
                {
                    reportFields = ";" + bfi.FormReportFields.ToLower().Trim(';') + ";";

                    // get displayed columns
                    displayedFields = bfi.FormReportFields.Split(';');

                    
                    // add all selected columns to the datagrid
                    foreach (string columnName in columnNames)
                    {
                        if ((dsFormData.Tables.Count > 0) && (dsFormData.Tables[0].Columns.Contains(columnName)) && (reportFields.Contains(";" + columnName.ToLower() + ";")))
                        {
                            // get form field info
                            ffi = fi.GetFormField(columnName);
                            content += "<si><t>" + ffi.Name + "</t></si>";
                            displColumns[mColumns] = columnName;
                            mColumns++;

                            // set column datafield and caption
                            column = new BoundColumn();
                            column.DataField = columnName;
                            column.HeaderText = GetFieldCaption(ffi, columnName);

                            // add column to datagrid
                            gridData.Columns.Add(column);
                        }
                    }
                }
                // add all columns by default
                else
                {
                    foreach (string columnName in columnNames)
                    {
                        // get form field info
                        ffi = fi.GetFormField(columnName);

                        // set column datafield and caption
                        column = new BoundColumn();
                        column.DataField = columnName;
                        column.HeaderText = GetFieldCaption(ffi, columnName);

                        content += "<si><t>" + ffi.Name + "</t></si>";
                        displColumns[mColumns] = columnName;
                        mColumns++;
                        
                        // add column to datagrid
                        gridData.Columns.Add(column);

                        reportFields += columnName + ";";
                    }

                    reportFields = reportFields.TrimEnd(';');
                }
            }


            gridData.DataSource = dsFormData;
            gridData.DataBind();

            if (office2007)
            {
                try
                {
                    TextHelper th = new TextHelper();
                    
                    string data = "<sheetData>";
                    int mRow = 1;
                    string bottomRight = "A1";

                    char columnCh = 'A';

                    // Header
                    data += "<row r=\"" + mRow.ToString() + "\" spans=\"1:"+mColumns.ToString()+"\">";
                    
                    foreach (string columnName in columnNames)
                    {
                        if ((dsFormData.Tables.Count > 0) && (dsFormData.Tables[0].Columns.Contains(columnName)) && (reportFields.Contains(";" + columnName.ToLower() + ";")))
                        {
      
                            // get form field info
                            ffi = fi.GetFormField(columnName);
                            data += "<c r=\"" + columnCh.ToString() + mRow.ToString() + "\" t=\"inlineStr\"><is><t>" + th.RemoveDiacritics(ffi.Name) + "</t></is></c>";
                            columnCh++;
                        }
                    }
                    data += "</row>";
                    mRow++;

                 

                    // Data
                    if (!DataHelper.DataSourceIsEmpty(dsFormData))
                    {
                        foreach (DataRow dr in dsFormData.Tables[0].Rows)
                        {
                            columnCh = 'A';

                            data += "<row r=\"" + mRow.ToString() + "\" spans=\"1:"+mColumns.ToString()+"\">";
                            for (int g = 0; g < mColumns; g++)
                            {
                                string jRow = ValidationHelper.GetString(displColumns[g], "");
                                if ((dsFormData.Tables.Count > 0) && (dsFormData.Tables[0].Columns.Contains(jRow)))
                                {
                                    string type = " t=\"inlineStr\"";

                                    data += "<c r=\"" + columnCh.ToString() + mRow.ToString() + "\"" + type + "><is><t>" + th.RemoveDiacritics(ValidationHelper.GetString(dr[jRow], "")) + "</t></is></c>";
                                    bottomRight = columnCh.ToString() + mRow.ToString();
                                    columnCh++;
                                }
                            }
                            data += "</row>";

                            mRow++;
                        }
                    }

                    data += "</sheetData>";


                   // string sharedString = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n<sst xmlns=\"http://schemas.openxmlformats.org/spreadsheetml/2006/main\" count=\"##COUNT_MACRO##\" uniqueCount=\"##COUNT_MACRO##\">##CONTENT_MACRO##</sst>";
                    string worksheet1 = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\r\n<worksheet xmlns=\"http://schemas.openxmlformats.org/spreadsheetml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\">##DIMENSION_MACRO##<sheetViews><sheetView tabSelected=\"1\" workbookViewId=\"0\"/></sheetViews><sheetFormatPr defaultRowHeight=\"15\"/>##DATA_MACRO##<pageMargins left=\"0.7\" right=\"0.7\" top=\"0.75\" bottom=\"0.75\" header=\"0.3\" footer=\"0.3\"/></worksheet>";

                    //sharedString = sharedString.Replace("##CONTENT_MACRO##", content);
                    // sharedString = sharedString.Replace("##COUNT_MACRO##", displayedFields.Length.ToString());
                    worksheet1 = worksheet1.Replace("##DIMENSION_MACRO##", "<dimension ref=\"A1:" + bottomRight + "\"/>");
                    worksheet1 = worksheet1.Replace("##DATA_MACRO##", data);


                    string path = HttpContext.Current.Server.MapPath(EXPORT_RELATIVE_PATH);

                    try
                    {
                        if (Directory.Exists(path + subPath))
                        {
                            DirectoryHelper.DeleteDirectory(path + subPath, true);
                        }
                    }
                    catch
                    {
                    }

                    if (!Directory.Exists(path + subPath))
                    {
                        DirectoryHelper.CreateDirectory(path + subPath);
                    }

                    ZipProvider zp = ZipProvider.Read(HttpContext.Current.Server.MapPath("~/CMSDesk/Tools/BizForms/") + "\\template.zip");
                    zp.ExtractAll(path + subPath);

                    zp.Dispose();

                    FileStream fs = new FileStream(path + subPath + "\\xl\\worksheets\\sheet1.xml", FileMode.Create);
                    fs.Write(System.Text.Encoding.UTF8.GetBytes(worksheet1), 0, worksheet1.Length);
                    fs.Dispose();
                    fs.Close();

                    string oldCurrentDir = Directory.GetCurrentDirectory();
                    Directory.SetCurrentDirectory(path + subPath);

                    string guidName = Guid.NewGuid().ToString();

                    ZipProvider zipProvider = new ZipProvider(path + subPath + guidName);
                    string[] subDirs = Directory.GetDirectories(path + subPath);

                    FileStream mfs = new FileStream(path + subPath + "[Content_Types].xml", FileMode.Open);
                    zipProvider.AddFileFromStream("[Content_Types].xml", mfs);

                    // Add each directory to the Zip archive
                    foreach (string subDir in subDirs)
                        zipProvider.AddDirectory(subDir.Substring(subDir.LastIndexOf('\\') + 1));
                    zipProvider.Save();


                    mfs.Dispose();
                    mfs.Close();


                    // Send
                    Response.Clear();
                    Response.AddHeader("content-disposition", "attachment;filename=" + formName + "_data.xlsx");
                    Response.ContentEncoding = System.Text.Encoding.UTF7;
                    // Response.Cache.SetCacheability(HttpCacheability.NoCache)
                    Response.ContentType = "application/vnd.xlsx";


                    FileStream jfs = new FileStream(path + subPath + guidName, FileMode.Open);
                    if (jfs != null)
                    {
                        StreamReader sr = new StreamReader(jfs);
                        if (jfs.Length > 0)
                        {
                            byte[] jdata = new byte[jfs.Length];
                            jfs.Read(jdata, 0, jdata.Length);
                            Response.ClearContent();
                            // Add the file data
                            Response.OutputStream.Write(jdata, 0, jdata.Length);
                            Response.OutputStream.Close();
                        }

                        sr.Dispose();
                        sr.Close();
                        jfs.Dispose();
                        jfs.Close();
                    }
                    Response.End();

                    Directory.SetCurrentDirectory(oldCurrentDir);

                    /* if (Directory.Exists(path))
                     {
                         DirectoryHelper.DeleteDirectory(path + subPath, true);
                     }*/
                }
                catch(Exception ex)
                {
                    throw new Exception("[Export to Excel 2007]: Error:" + ex.Message);
                }

            }
            else
            {
                // export to excel
                Response.Clear();
                Response.AddHeader("content-disposition", "attachment;filename=" + formName + "_data.xls");
                Response.ContentEncoding = System.Text.Encoding.UTF7;
                // Response.Cache.SetCacheability(HttpCacheability.NoCache)
                Response.ContentType = "application/vnd.xls";
                StringWriter stringWrite = new StringWriter();
                HtmlTextWriter htmlWrite = new HtmlTextWriter(stringWrite);
                string strStyle = @"<style>.text { mso-number-format:\@; } </style>";
                gridData.RenderControl(htmlWrite);
                Response.Write(stringWrite.ToString());
                Response.Write(strStyle);
                Response.End();
            }
        }
    }
       

    /// <summary>
    /// Returtns field caption of the specified column.
    /// </summary>
    /// <param name="ffi">Form field info.</param>
    /// <param name="columnName">Column name.</param>
    /// <returns></returns>
    protected string GetFieldCaption(FormFieldInfo ffi, string columnName)
    {
        string fieldCaption = "";

        // get field caption        
        if ((ffi == null) || (ffi.Caption == ""))
        {
            fieldCaption = columnName;
        }
        else
        {
            if (ffi.Caption == "")
            {
                fieldCaption = columnName;
            }
            else
            {
                fieldCaption = ffi.Caption;
            }
        }

        return fieldCaption;
    }

}
