using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_ExchangeTable_Edit : CMSDeskPage
{
    protected int exchangeid = 0;
    private Hashtable mTextBoxs = new Hashtable();
    private Hashtable mData = new Hashtable();

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        editGrid.RowDataBound += new GridViewRowEventHandler(editGrid_RowDataBound);


        rfvDsiplayName.ErrorMessage = ResHelper.GetString("ExchangeTable_Edit.errorDisplay");

        // control initializations				
        lblExchangeTableValidFrom.Text = ResHelper.GetString("ExchangeTable_Edit.ExchangeTableValidFromLabel");
        lblExchangeTableDisplayName.Text = ResHelper.GetString("ExchangeTable_Edit.ExchangeTableDisplayNameLabel");
        lblExchangeTableValidTo.Text = ResHelper.GetString("ExchangeTable_Edit.ExchangeTableValidToLabel");
        
        lblRates.Text = ResHelper.GetString("ExchangeTable_Edit.ExchangeRates");

        btnOK.Text = ResHelper.GetString("General.OK");
        dtPickerExchangeTableValidFrom.SupportFolder = "~/CMSAdminControls/Calendar";
        dtPickerExchangeTableValidTo.SupportFolder = "~/CMSAdminControls/Calendar";

        string currentExchangeTable = ResHelper.GetString("ExchangeTable_Edit.NewItemCaption");

        // get exchangeTable id from querystring		
        exchangeid = ValidationHelper.GetInteger(Request.QueryString["exchangeid"], 0);
        if (exchangeid > 0)
        {
            ExchangeTableInfo exchangeTableObj = ExchangeTableInfoProvider.GetExchangeTableInfo(exchangeid);
            if (exchangeTableObj != null)
            {
                currentExchangeTable = exchangeTableObj.ExchangeTableDisplayName;

                LoadData(exchangeTableObj);

                // fill editing form
                if (!IsPostBack)
                {
                    // show that the exchangeTable was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }
        }
        else
        {
            if (!IsPostBack)
            {
                ExchangeTableInfo tableInfo = ExchangeTableInfoProvider.GetLastValidExchangeTableInfo();
                

                if (tableInfo != null)
                {
                    dtPickerExchangeTableValidFrom.SelectedDateTime = tableInfo.ExchangeTableValidTo;
                }                
            }
            plcGrid.Visible = false;
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("ExchangeTable_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Ecommerce/Configuration/ExchangeRates/ExchangeTable_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentExchangeTable;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("ExchangeTable_Edit.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/ExchangeRates/exchangetable.gif";
    }


    void editGrid_RowDataBound(object sender, GridViewRowEventArgs e)
    {

        if (e.Row.DataItemIndex >= 0)
        {
            TextBox txt = new TextBox();
            txt.SkinID = "ShortTextBox";
            txt.TextChanged += new EventHandler(txt_TextChanged);
            txt.MaxLength = 10;

            int mCurId = ValidationHelper.GetInteger(((DataRowView)e.Row.DataItem)["CurrencyID"], 0);
            string mRateValue = "";

            DataSet mDs = ExchangeTableInfoProvider.GetRatesByTableID(exchangeid);

            if (!DataHelper.DataSourceIsEmpty(mDs))
            {
                foreach (DataRow dr in mDs.Tables[0].Rows)
                {
                    if (ValidationHelper.GetInteger(dr["ExchangeRateToCurrencyID"], -1) == mCurId)
                    {
                        mRateValue = ValidationHelper.GetDouble(dr["ExchangeRateValue"], -1).ToString();
                    }
                }
            }

            txt.Text = mRateValue;

            e.Row.Cells[1].Controls.Add(txt);

            mData[txt.ClientID] = e.Row.DataItem;
        }
    }


    void txt_TextChanged(object sender, EventArgs e)
    {
        mTextBoxs[((TextBox)sender).ClientID] = sender;
    }



    /// <summary>
    /// Load data of editing exchangeTable.
    /// </summary>
    /// <param name="exchangeTableObj">ExchangeTable object.</param>
    protected void LoadData(ExchangeTableInfo exchangeTableObj)
    {

        editGrid.Columns[0].HeaderText = ResHelper.GetString("ExchangeTable_Edit.ToCurrency");
        editGrid.Columns[1].HeaderText = ResHelper.GetString("ExchangeTable_Edit.RateValue");

        CurrencyInfo ci = CurrencyInfoProvider.GetMainCurrency();
        DataSet dsCurrency = CurrencyInfoProvider.GetAllCurrencies();
        int toRemove = -1;
        int i = 0;



        if (!DataHelper.DataSourceIsEmpty(dsCurrency))
        {
            if (ci != null)
            {
                foreach (DataRow dr in dsCurrency.Tables[0].Rows)
                {
                    if (ValidationHelper.GetInteger(dr["CurrencyID"], -1) == ci.CurrencyID)
                    {
                        toRemove = i;
                    }
                    i++;
                }
            }

            if (toRemove != -1)
            {
                dsCurrency.Tables[0].Rows[toRemove].Delete();
                dsCurrency.AcceptChanges();
            }

            editGrid.DataSource = dsCurrency;
            editGrid.DataBind();
        }

        if (!IsPostBack)
        {
            dtPickerExchangeTableValidFrom.SelectedDateTime = exchangeTableObj.ExchangeTableValidFrom;
            txtExchangeTableDisplayName.Text = exchangeTableObj.ExchangeTableDisplayName;
            dtPickerExchangeTableValidTo.SelectedDateTime = exchangeTableObj.ExchangeTableValidTo;
        }

    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        string errorMessage = new Validator().NotEmpty(txtExchangeTableDisplayName.Text, ResHelper.GetString("ExchangeTable_Edit.errorDisplay")).Result;

        if (errorMessage == "")
        {
            ExchangeTableInfo exchangeTableObj = ExchangeTableInfoProvider.GetExchangeTableInfo(txtExchangeTableDisplayName.Text.Trim());

            // if currencyName value is unique														
            if ((exchangeTableObj == null) || (exchangeTableObj.ExchangeTableID == exchangeid))
            {
                // if currencyName value is unique -> determine whether it is update or insert 
                if ((exchangeTableObj == null))
                {
                    // get CurrencyInfo object by primary key
                    exchangeTableObj = ExchangeTableInfoProvider.GetExchangeTableInfo(exchangeid);
                    if (exchangeTableObj == null)
                    {
                        // create new item -> insert
                        exchangeTableObj = new ExchangeTableInfo();

                    }
                }

                exchangeTableObj.ExchangeTableValidFrom = dtPickerExchangeTableValidFrom.SelectedDateTime;
                exchangeTableObj.ExchangeTableDisplayName = txtExchangeTableDisplayName.Text.Trim();
                exchangeTableObj.ExchangeTableValidTo = dtPickerExchangeTableValidTo.SelectedDateTime;

                ExchangeTableInfoProvider.SetExchangeTableInfo(exchangeTableObj);

                // Save rates on edit
                if (exchangeid > 0)
                {
                    DataSet mDs = ExchangeTableInfoProvider.GetRatesByTableID(exchangeid);

                    foreach (TextBox txt in mTextBoxs.Values)
                    {
                        bool isAffected = false;

                        if (mData[txt.ClientID] != null)
                        {
                            int mCurId = ValidationHelper.GetInteger(((DataRowView)mData[txt.ClientID])["CurrencyID"], 0);

                            if (!DataHelper.DataSourceIsEmpty(mDs))
                            {
                                foreach (DataRow dr in mDs.Tables[0].Rows)
                                {
                                    if (ValidationHelper.GetInteger(dr["ExchangeRateToCurrencyID"], -1) == mCurId)
                                    {

                                        if (ValidationHelper.IsPositiveNumber(txt.Text))
                                        {
                                            ExchangeTableInfoProvider.SetRateByRateId(ValidationHelper.GetInteger(dr["ExchagneRateID"], 0), mCurId, Convert.ToDouble(txt.Text), exchangeid);

                                        }
                                        else
                                        {
                                            lblError.Visible = true;
                                            lblError.Text = ResHelper.GetString("ExchangeTable_Edit.errorRate");
                                        }

                                        isAffected = true;
                                    }
                                }
                            }

                            // Insert
                            if (!isAffected)
                            {
                                ExchangeTableInfoProvider.SetRateByRateId(0, mCurId, Convert.ToDouble(txt.Text), exchangeid);
                            }

                        }
                    }
                }

                Response.Redirect("ExchangeTable_Edit.aspx?exchangeid=" + Convert.ToString(exchangeTableObj.ExchangeTableID) + "&saved=1");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ExchangeTable_Edit.CurrencyNameExists");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }

}