using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.Forums;
using CMS.LicenseProvider;

public partial class CMSDesk_Tools_Forums_Forums_Forum_Security : CMSDeskPage
{
    protected int forumId = 0;
    protected ForumInfo forum = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        forumId = ValidationHelper.GetInteger(Request.QueryString["forumid"], 0);
        if (forumId == 0)
        {
            return;
        }
        lblAllUsers.Text = ResHelper.GetString("Forum_Security.AllUsers");
        lblOnlyRoles.Text = ResHelper.GetString("Forum_Security.OnlyRoles");
        lblOnlyUsers.Text = ResHelper.GetString("Forum_Security.OnlyUsers");
        btnAddRole.Text = ResHelper.GetString("Forum_Security.Add");
        btnRemoveRole.Text = ResHelper.GetString("Forum_Security.Remove");
        lblTitle.Text = ResHelper.GetString("Forum_Security.Title");
        btnOk.Text = ResHelper.GetString("General.Ok");
        lblChangeName.Text = ResHelper.GetString("Forum_Security.ChangeName");


        // Register dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.ltlScript.Text = ScriptHelper.GetScript("function UpdateForm(){ " + ClientScript.GetPostBackEventReference(btnUpdate, "") + "; } \n");

        btnAddRole.Attributes.Add("onclick", "AddOperator(" + forumId + "); return false;");

        forum = ForumInfoProvider.GetForumInfo(forumId);
        if (forum == null)
        {
            throw new Exception("Forum with given ID not found!");
        }

        if (!IsPostBack)
        {


            //if acces is enabled for all users
            if (forum.ForumAccess == 0)
            {
                radAllUsers.Checked = true;
                btnAddRole.Enabled = false;
                btnRemoveRole.Enabled = false;
                lstRoles.Enabled = false;
            }

            //if acces is enabled for authenticated users only
            else if (forum.ForumAccess == 1)
            {
                radOnlyUsers.Checked = true;
                btnAddRole.Enabled = false;
                btnRemoveRole.Enabled = false;
                lstRoles.Enabled = false;
            }

            //acces is enabled for users in authorized roles only
            else
            {
                radOnlyRoles.Checked = true;
                radOnlyRoles_CheckedChanged(null, null);

                LoadRoles();
            }

            SetChanges();
        }
    }

    /// <summary>
    /// Set changes
    /// </summary>
    protected void SetChanges()
    {
        if (!radAllUsers.Checked)
        {
            chkChangeName.Checked = forum.ForumAllowChangeName;
        }

        if (radAllUsers.Checked)
        {
            chkChangeName.Enabled = false;
            chkChangeName.Checked = true;
        }
        else
        {
            chkChangeName.Enabled = true;
        }
    }

    /// <summary>
    /// Loades list of roles authorized for forum access into lstRoles control.
    /// </summary>
    protected void LoadRoles()
    {
        if (CMSContext.CurrentSite != null)
        {
            DataSet roles = RoleInfoProvider.GetAllRoles(CMSContext.CurrentSite.SiteID);
            if (!DataHelper.DataSourceIsEmpty(roles))
            {
                lstRoles.Items.Clear();
                int roleId = 0;
                string roleDisplayName = "";
                ListItem roleItem = null;
                for (int i = 0; i < roles.Tables[0].Rows.Count; i++)
                {
                    roleId = Convert.ToInt32(roles.Tables[0].Rows[i]["RoleID"]);
                    roleDisplayName = roles.Tables[0].Rows[i]["RoleDisplayName"].ToString();
                    if (ForumInfoProvider.IsRoleAllowedForForum(roleId, forumId))
                    {
                        roleItem = new ListItem(roleDisplayName, roleId.ToString());
                        lstRoles.Items.Add(roleItem);
                    }
                }
            }
        }
    }

    /// <summary>
    /// Enables access for all users.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radAllUsers_CheckedChanged(object sender, EventArgs e)
    {

        if (radAllUsers.Checked)
        {
            btnAddRole.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;

            /* forum.ForumAccess = 0;
             ForumInfoProvider.SetForumInfo(forum);*/

        }

        SetChanges();
    }

    /// <summary>
    /// Enables access for authenticated users only.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radOnlyUsers_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyUsers.Checked)
        {
            btnRemoveRole.Enabled = false;
            btnAddRole.Enabled = false;
            lstRoles.Enabled = false;
        }

        SetChanges();
    }

    /// <summary>
    /// Enables access for users in authorized roles only.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radOnlyRoles_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyRoles.Checked)
        {
            btnAddRole.Enabled = true;
            btnRemoveRole.Enabled = true;
            lstRoles.Enabled = true;
        }

        SetChanges();
    }

    /// <summary>
    /// Removes role from the list of authorized roles.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnRemoveRole_Click(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        int roleId = 0;
        foreach (ListItem item in lstRoles.Items)
        {
            if (item.Selected)
            {
                roleId = Convert.ToInt32(item.Value);
                if (ForumInfoProvider.IsRoleAllowedForForum(roleId, forumId))
                {
                    ForumInfoProvider.RemoveRoleFromForum(roleId, forumId);
                }
            }
        }
        LoadRoles();

        SetChanges();
    }

    /// <summary>
    /// This function is executed by callback iniciated by 'Select roles' dialog after its closing
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnUpdate_Click(object sender, EventArgs e)
    {
        LoadRoles();
        SetChanges();
    }

    /// <summary>
    /// Ok click handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOk_Click(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        forum.ForumAllowChangeName = chkChangeName.Checked;

        if (radOnlyUsers.Checked)
        {
            forum.ForumAccess = 1;
            ForumInfoProvider.SetForumInfo(forum);
        }

        if (radAllUsers.Checked)
        {
            forum.ForumAccess = 0;
            ForumInfoProvider.SetForumInfo(forum);
        }

        if (radOnlyRoles.Checked)
        {
            forum.ForumAccess = 2;
            ForumInfoProvider.SetForumInfo(forum);
        }

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.Changessaved");

        SetChanges();
    }
}
