using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Xml;
using System.Text;

using CMS.Newsletter;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Controls;
using CMS.CMSHelper;


public partial class CMSDesk_Tools_Newsletters_Newsletters_Newsletter_ContentEditor : System.Web.UI.UserControl
{
    private int mIssueID = 0;
    private int mNewsletterID = 0;
    private int templateId = 0;
    private ArrayList regionList = new ArrayList();
    private Hashtable regionsContents = new Hashtable();
    Issue issue = null;

    /// <summary>
    /// Issue ID
    /// </summary>
    public int IssueID
    {
        get
        {
            return mIssueID;
        }
        set
        {
            mIssueID = value;
        }
    }


    /// <summary>
    /// Newsletter ID
    /// </summary>
    public int NewsletterID
    {
        get
        {
            return mNewsletterID;
        }
        set
        {
            mNewsletterID = value;
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        if (IssueID > 0)
        {
            issue = IssueProvider.GetIssue(IssueID);
            if (issue != null)
            {
                templateId = issue.IssueTemplateID;
            }
        }
        else if (NewsletterID > 0)
        {
            Newsletter newsletter = NewsletterProvider.GetNewsletter(NewsletterID);
            if (newsletter != null)
            {
                templateId = newsletter.NewsletterTemplateID;
            }
        }

        if (templateId > 0)
        {
            LoadContent();
        }
        LoadRegionList();
    }


    private void LoadContent()
    {
        EmailTemplate emailTemplate = EmailTemplateProvider.GetEmailTemplate(templateId);
        if (emailTemplate == null)
        {
            return;
        }
        string templateText = emailTemplate.TemplateBody;
        LiteralControl before = new LiteralControl();
        CMSPageManager pageManager = new CMSPageManager();
        pageManager.ViewMode = ViewModeEnum.Edit;
        CMSEditableRegion editableRegion = new CMSEditableRegion(pageManager);

        if (!IsPostBack && (issue != null))
        {
            LoadRegionsContents();
        }

        int count = 0;
        int textStart = 0;
        int editRegStart = templateText.IndexOf("$$", textStart);

        while (editRegStart >= 0)
        {
            count++;

            before = new LiteralControl();
            before.Text = UrlHelper.MakeLinksAbsolute(templateText.Substring(textStart, (editRegStart - textStart)));
            plcContent.Controls.Add(before);

            // End of region
            editRegStart += 2;
            textStart = editRegStart;
            if (editRegStart < templateText.Length - 1)
            {
                int editRegEnd = templateText.IndexOf("$$", editRegStart);
                if (editRegEnd >= 0)
                {
                    string region = templateText.Substring(editRegStart, editRegEnd - editRegStart);
                    string[] parts = (region + ":" + ":").Split(':');

                    try
                    {
                        string name = parts[0];
                        if (name.Trim() != "")
                        {

                            int width = ValidationHelper.GetInteger(parts[1], 0);
                            int height = ValidationHelper.GetInteger(parts[2], 0);

                            editableRegion = new CMSEditableRegion(pageManager);
                            editableRegion.ID = name;
                            editableRegion.RegionType = CMSEditableRegionTypeEnum.HtmlEditor;

                            editableRegion.DialogHeight = height;
                            editableRegion.DialogWidth = width;

                            editableRegion.WordWrap = false;
                            editableRegion.HtmlAreaToolbarLocation = "Out:FCKEditorToolbar";
                            editableRegion.UseStylesheet = false;
                            editableRegion.RegionTitle = name;

                            editableRegion.LoadContent(ValidationHelper.GetString(regionsContents[name.ToLower()], ""));

                            plcContent.Controls.Add(editableRegion);

                            textStart = editRegEnd + 2;
                        }
                    }
                    catch
                    {
                    }
                }
            }
            editRegStart = templateText.IndexOf("$$", textStart);
        }

        before = new LiteralControl();
        before.Text = UrlHelper.MakeLinksAbsolute(templateText.Substring(textStart));

        plcContent.Controls.Add(before);
    }


    protected void LoadRegionsContents()
    {
        regionsContents.Clear();
        string contentXml = issue.IssueText;
        if (contentXml != "")
        {
            XmlDocument xml = new XmlDocument();
            xml.LoadXml(contentXml);
            XmlNode docElem = xml.DocumentElement;

            // Load editable regions
            XmlNodeList regions = docElem.SelectNodes("region");
            if (regions != null)
            {
                foreach (XmlNode region in regions)
                {
                    string id = region.Attributes["id"].Value;
                    string value = region.InnerText;
                    regionsContents[id.ToLower()] = value;
                }
            }
        }
    }


    /// <summary>
    /// Saves the content to the specified Issue
    /// </summary>
    /// <param name="issue">Issue data</param>
    public string SaveContent(Issue issue)
    {
        CMSEditableRegion editReg;
        XmlWriterSettings settings = new XmlWriterSettings();
        settings.Indent = true;
        settings.NewLineOnAttributes = false;
        //string xmlOutput = "";
        StringBuilder sb = new StringBuilder();
        using (XmlWriter writer = XmlWriter.Create(sb, settings))
        {
            writer.WriteStartDocument();
            writer.WriteStartElement("content");

            //regionList = CMSPageManager.CollectEditableRegions(plcContent);
            for (int i = 0; i < regionList.Count; i++)
            {
                editReg = (CMSEditableRegion)regionList[i];
                writer.WriteStartElement("region");
                writer.WriteStartAttribute("id");
                writer.WriteValue(editReg.ID);
                writer.WriteEndAttribute();
                writer.WriteString(editReg.GetContent());
                //writer.WriteString(editReg.content);
                writer.WriteEndElement(); //region
            }

            writer.WriteEndElement(); //content
            writer.WriteEndDocument();
        }

        issue.IssueText = sb.ToString();
        return "";
    }


    protected void LoadRegionList()
    {
        regionList = CMSPageManager.CollectEditableControls(plcContent);

        //create array of regions IDs in javascript. We will use it to find out the focused region
        string script = "var focusedRegionID = ''; \n var regions = new Array(" + regionList.Count.ToString() + "); \n ";
        for (int i = 0; i < regionList.Count; i++)
        {
            script += "regions[" + i.ToString() + "] = '" + ((CMSEditableRegion)regionList[i]).ClientID + "_fckValue'; \n ";
        }
        ltlScript.Text = ScriptHelper.GetScript(script);
    }
}
