using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Drawing;
using System.Drawing.Imaging;
using System.Drawing.Drawing2D;

using CMS.Forums;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;


public partial class CMSForum_ForumPost : ForumPostControl
{

    private bool mOpen = true;

    private string mInfoText = "";

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mForumProperties.EnablePicture; ; }
        set { mForumProperties.EnablePicture = value; }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mForumProperties.MaxPictureWidth; }
        set { mForumProperties.MaxPictureWidth = value; }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mForumProperties.MaxPictureHeight; }
        set { mForumProperties.MaxPictureHeight = value; }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mForumProperties.EnableSignature; }
        set { mForumProperties.EnableSignature = value; }
    }

    /// <summary>
    /// Info text
    /// </summary>
    public string InfoText
    {
        get { return mInfoText; }
        set { mInfoText = value; }

    }


    protected override void OnPreRender(EventArgs e)
    {
        ReloadData();

        base.OnPreRender(e);
    }



    /// <summary>
    /// Reload data
    /// </summary>
    public void ReloadData()
    {
        if ((InfoText != null) && (InfoText.Trim() != ""))
        {
            lblInfo.Visible = true;
            lblInfo.Text = InfoText;
        }

        lblActionSeparator.Text = "|";

        ForumPostInfo fpi = ForumPostInfoProvider.GetForumPostInfo(PostID);
        if (fpi != null)
        {
            ForumInfo fi = ForumInfoProvider.GetForumInfo(fpi.PostForumID);
            if (fi != null)
            {
                if (!fi.ForumOpen)
                {
                    AllowReply = false;
                    mOpen = false;
                }
            }

            if (this.EnableSignature)
            {
                if (fpi.PostUserSignature.Trim() != "")
                {
                    plcSignature.Visible = true;
                    ltrSignature.Text = Server.HtmlEncode(fpi.PostUserSignature).Replace("\r\n","").Replace("\n","");
                }
            }


            UserPicture1.DisplayPicture = this.EnablePicture;
            UserPicture1.Width = this.MaxPictureWidth;
            UserPicture1.Height = this.MaxPictureHeight;
            UserPicture1.UserID = fpi.PostUserID;
        }



        if (mPostSrcDataRow != null)
        {
            ForumInfo fi = null;

            if (!DataHelper.DataSourceIsEmpty(mPostSrcDataRow))
            {
                fi = ForumInfoProvider.GetForumInfo(ValidationHelper.GetInteger(mPostSrcDataRow["PostForumID"], 0));
                if (fi != null)
                {
                    if (!fi.ForumOpen)
                    {
                        AllowReply = false;
                    }
                }
            }

            isEmpty = false;

            lnkUserName.Text = Server.HtmlEncode(mPostSrcDataRow["PostUserName"].ToString());
            if (mPostSrcDataRow["PostUserMail"] != null && mPostSrcDataRow["PostUserMail"].ToString().Trim() != "")
            {
                lnkUserName.NavigateUrl = Server.HtmlEncode(DisplayEmail ? "mailto:" + mPostSrcDataRow["PostUserMail"].ToString() + "?subject=" + mPostSrcDataRow["PostSubject"].ToString() : "");
            }
            lblDate.Text = "(" + ((DateTime)mPostSrcDataRow["PostTime"]).ToShortDateString() + ", " + ((DateTime)mPostSrcDataRow["PostTime"]).ToShortTimeString() + ")";
            lblSubject.Text = Server.HtmlEncode(mPostSrcDataRow["PostSubject"].ToString());
            lblText.Text = mForumProperties.ForumHtmlEncode(mPostSrcDataRow["PostText"].ToString(), ValidationHelper.GetInteger(mPostSrcDataRow["PostForumID"], 0));
            
            lblSeparator.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.separator");



            if ((EnableSubscription) && (mOpen))
            {
                 lnkSubscribe.Visible = true;
                lnkSubscribe.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.Subscribe");
                lnkSubscribe.NavigateUrl = "javascript:NewSubscribe(" + Convert.ToInt32(mPostSrcDataRow["PostID"]) + ");";
            }
            else
            {
                lnkSubscribe.Visible = false;
            }

            if (AllowReply)
            {
                lnkReply.Visible = true;
                lnkReply.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.replyLinkText");

                lnkReply.NavigateUrl = "javascript:ReplyToPost(" + Convert.ToInt32(mPostSrcDataRow["PostID"]) + ");";
            }
            else
            {
                lnkReply.Visible = false;
            }
            ForumPostInfo fp = new ForumPostInfo(mPostSrcDataRow);
            if (fp != null)
            {
                if (this.EnableSignature)
                {
                    if (fp.PostUserSignature.Trim() != "")
                    {
                        plcSignature.Visible = true;
                        ltrSignature.Text = Server.HtmlEncode(fp.PostUserSignature);
                    }
                }

                UserPicture1.DisplayPicture = this.EnablePicture;
                UserPicture1.Width = this.MaxPictureWidth;
                UserPicture1.Height = this.MaxPictureHeight;
                UserPicture1.UserID = fp.PostUserID;
            }

        }
        else
        {
            //mPostID = this.PostID;

            ForumPostInfo fp = ForumPostInfoProvider.GetForumPostInfo(mPostID);
            if (fp != null)
            {

                if (this.EnableSignature)
                {
                    if (fp.PostUserSignature.Trim() != "")
                    {
                        plcSignature.Visible = true;
                        ltrSignature.Text = Server.HtmlEncode(fp.PostUserSignature);
                    }
                }


                UserPicture1.DisplayPicture = this.EnablePicture;
                UserPicture1.Width = this.MaxPictureWidth;
                UserPicture1.Height = this.MaxPictureHeight;
                UserPicture1.UserID = fp.PostUserID;

                isEmpty = false;

                lnkUserName.Text = Server.HtmlEncode(fp.PostUserName);
                if (fp.PostUserMail != null && fp.PostUserMail.Trim() != "")
                {
                    lnkUserName.NavigateUrl = Server.HtmlEncode(DisplayEmail ? "mailto:" + fp.PostUserMail + "?subject=" + fp.PostSubject : "");
                }
                lblDate.Text = "(" + fp.PostTime.ToShortDateString() + ", " + fp.PostTime.ToShortTimeString() + ")";
                lblSubject.Text = Server.HtmlEncode(fp.PostSubject);


                lblText.Text = mForumProperties.ForumHtmlEncode(fp.PostText, fp.PostForumID);
                
                lblSeparator.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.separator");

                if ((EnableSubscription) && (mOpen))
                {
                    lnkSubscribe.Visible = true;
                    lnkSubscribe.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.Subscribe");
                    lnkSubscribe.NavigateUrl = "javascript:NewSubscribe(" + fp.PostId + ");";
                }
                else
                {
                    lnkSubscribe.Visible = false;
                }

                if (AllowReply)
                {
                    lnkReply.Visible = true;
                    lnkReply.Text = ResHelper.GetString("Forums_WebInterface_ForumPost.replyLinkText");

                    lnkReply.NavigateUrl = "javascript:ReplyToPost(" + PostID + ");";
                }
                else
                {
                    lnkReply.Visible = false;
                }
            }
        }

        this.plcActions.Visible = (this.lnkReply.Visible || this.lnkSubscribe.Visible);
        if ((lnkSubscribe.Visible == false) || (lnkReply.Visible == false))
        {
            lblActionSeparator.Visible = false;
        }

    }

    /// <summary>
    /// Render
    /// </summary>
    /// <param name="writer"></param>
    protected override void Render(HtmlTextWriter writer)
    {
        if (!isEmpty)
        {
            base.Render(writer);
        }
    }
}
