using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Forums;
using CMS.CMSHelper;

public partial class CMSForum_ForumTreeView : System.Web.UI.UserControl
{
    /// <summary>Forum properties</summary>
    public ForumProperties mForumProperties = new ForumProperties();
    private bool isAuthenticated = false;
    private string SearchText = "";
    private bool mClosed = false;

    #region "Public properties"

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mForumProperties.EnablePicture; ; }
        set { mForumProperties.EnablePicture = value; }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mForumProperties.MaxPictureWidth; }
        set { mForumProperties.MaxPictureWidth = value; }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mForumProperties.MaxPictureHeight; }
        set { mForumProperties.MaxPictureHeight = value; }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mForumProperties.EnableSignature; }
        set { mForumProperties.EnableSignature = value; }
    }

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get { return mForumProperties.EnableSubscription; }
        set { mForumProperties.EnableSubscription = value; }
    }


    /// <summary>
    /// CheckPermissions
    /// </summary>
    public bool CheckPermissions
    {
        get { return mForumProperties.CheckPermissions; }
        set { mForumProperties.CheckPermissions = value; }
    }

    /// <summary>
    /// If set public user can read, no insert new post
    /// </summary>
    public bool NoAuthenticatedRead
    {
        get { return mForumProperties.NoAuthenticatedRead; }
        set { mForumProperties.NoAuthenticatedRead = value; }
    }

    /// <summary>
    /// AdHoc forum
    /// </summary>
    public bool AdHocForum
    {
        get { return mForumProperties.AdHocForum; }
        set { mForumProperties.AdHocForum = value; }
    }
    
    /// <summary>
    /// Forum Id
    /// </summary>
    public int ForumID
    {
        get { return mForumProperties.ForumID; }
        set { mForumProperties.ForumID = value; }
    }


    /// <summary>
    /// Post reply id
    /// </summary>
    public int PostReplyId
    {
        get { return mForumProperties.PostReplyId; }
        set { mForumProperties.PostReplyId = value; }
    }

    /// <summary>
    /// Post id
    /// </summary>
    public int PostId
    {
        get { return mForumProperties.PostId; }
        set { mForumProperties.PostId = value; }
    }



    /// <summary> Stop processing </summary>
    public bool StopProcessing
    {
        get { return mForumProperties.StopProcessing; }
        set { mForumProperties.StopProcessing = value; }
    }

    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get { return mForumProperties.WhereCondition; }
        set { mForumProperties.WhereCondition = value; }
    }


    /// <summary>
    /// Path
    /// </summary>
    public string PostPath
    {
        get { return mForumProperties.PostPath; }
        set { mForumProperties.PostPath = value; }
    }


    /// <summary>
    /// Max relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get { return mForumProperties.MaxRelativeLevel; }
        set { mForumProperties.MaxRelativeLevel = value; }
    }

    /// <summary>
    /// Select only approved
    /// </summary>
    public bool SelectOnlyApproved
    {
        get { return mForumProperties.SelectOnlyApproved; }
        set { mForumProperties.SelectOnlyApproved = value; }
    }

    /// <summary>
    /// Expand tree
    /// </summary>
    public bool ExpandTree
    {
        get { return mForumProperties.ExpandTree; }
        set { mForumProperties.ExpandTree = value; }
    }

    /// <summary> ShowMode </summary>
    public ShowModeEnum ShowMode
    {
        get { return mForumProperties.ShowMode; }
        set { mForumProperties.ShowMode = value; }
    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        ForumNewPost1.mForumProperties = this.mForumProperties;
        ForumPost1.mForumProperties = this.mForumProperties;

        //Check if isn't unsubscribe request
        mForumProperties.CheckUnsubscribe();

        if (Request.QueryString["SearchForum"] != null && ValidationHelper.GetString(Request.QueryString["SearchForum"], "") != "")
        {
            SearchText = ValidationHelper.GetString(Request.QueryString["SearchForum"], "");


            if (!mForumProperties.IsSearchResult)
            {
                StopProcessing = true;
                return;
            }
        }

        PostTree1.StopProcessing = this.StopProcessing;
        PostTree1.EnableSubscription = this.EnableSubscription;

        this.PostTree1.TreeView.LineImagesFolder = "~/App_Themes/Default/Images/Tree";
        if (CultureHelper.IsUICultureRTL())
        {
            this.PostTree1.TreeView.LineImagesFolder += "/RTL";
        }
        this.PostTree1.TreeView.ImageSet = TreeViewImageSet.Custom;

        ForumNewPost1.mForumProperties = this.mForumProperties;

        ReloadData();
    }

    /// <summary>
    /// Reload data
    /// </summary>
    public void ReloadData()
    {
        if (this.AdHocForum)
        {
            if (CMSContext.CurrentDocument != null)
            {
                int documentId = CMSContext.CurrentDocument.DocumentID;
                ForumInfo mFi = ForumInfoProvider.GetForumInfoByDocument(documentId);

                if (mFi != null)
                {
                    this.ForumID = mFi.ForumID;
                }
            }
        }

        isAuthenticated = mForumProperties.CheckPermission(this.ForumID);
        //Check permissions
        if (((!isAuthenticated) && (!NoAuthenticatedRead)) && (this.Visible))
        {
            StopProcessing = true;
            return;
        }

        if (this.StopProcessing) return;

        // Set forum header text
        ForumInfo fi = ForumInfoProvider.GetForumInfo(this.ForumID);

        ForumPost1.EnableSubscription = this.EnableSubscription;

       

        if (fi != null)
        {
            lblForumHeader.Text = fi.ForumDisplayName;
            lblForumHeaderDescription.Text = fi.ForumDescription;

            ForumPost1.DisplayEmail = fi.ForumDisplayEmails;

            if (!fi.ForumOpen)
            {
                mClosed = true;
            }
        }

        if (this.AdHocForum)
        {
            plcInfoArea.Visible = false;
        }

        //New thread and subscription link
        if (((this.AdHocForum) || (this.ForumID > 0))&&(!mClosed))
        {
            lnkNewThread.Visible = true;
            lnkNewThread.Text = ResHelper.GetString("Forums.Forum.lnkNewThread");
            lnkNewThread.NavigateUrl = "javascript:NewThread();";

            if (EnableSubscription)
            {
                lnkSubscription.Visible = true;
                lnkSubscription.Text = ResHelper.GetString("Forums.Forum.SubscribeForum");
                lnkSubscription.NavigateUrl = "javascript:NewSubscribe(0);";
            }
        }

        if ((!isAuthenticated) && (NoAuthenticatedRead))
        {
            lnkNewThread.Visible = false;
            ForumPost1.AllowReply = false;
            this.EnableSubscription = false;
            lnkSubscription.Visible = false;
            PostTree1.AllowReply = false;
            PostTree1.EnableSubscription = false;
        }

        //Hide new subscribe
        frmNewsubscribe.Visible = false;

        // Set data to forms
        frmNewsubscribe.ForumID = this.ForumID;
        frmNewsubscribe.PostID = ValidationHelper.GetInteger(this.hdnSubscribeId.Value, 0); 

        // Set javascript for selected mode
        string mJavaDynamicMode = "function SelectNode(nodeElem, selElem) { if (document.getElementById(nodeElem) != null) { document.getElementById(nodeElem).style.display = 'block';} " +
                                  "if (document.getElementById(selElem) != null) {document.getElementById(selElem).style.display = 'none';} return false;}\n ";

        string mJavaDefaultMode = "function SelectNode(nodeElem) { return false; }\n ";

        string mJavaOutput = mJavaDefaultMode;

        if (this.ShowMode == ShowModeEnum.DynamicDetailMode)
        {
            mJavaOutput = mJavaDynamicMode;
        }

        ForumNewPost1.ReplyToPostID = ValidationHelper.GetInteger(hdnPostId.Value, -1);


        // Hide lnk "NEW THREAD"
        if (ForumNewPost1.ReplyToPostID >= 0)
        {


            lnkNewThread.Visible = false;
            lnkSubscription.Visible = false;
            BreadCrumbs.Visible = false;
            lblSeparator.Visible = false;
        }


        // Add breadcrumbs
        if (ValidationHelper.GetString(Request.QueryString[mForumProperties.QueryStringForumID], "") != "")
        {

            string mGroupName = "";
            string mForumName = "";
            if (fi != null)
            {
                mForumName = fi.ForumDisplayName;
                ForumGroupInfo fgi = ForumGroupInfoProvider.GetForumGroupInfo(fi.ForumGroupID);
                if (fgi != null)
                {
                    mGroupName = fgi.GroupDisplayName;
                }
            }

            string query = HttpContext.Current.Request.Url.Query;
            string url = HttpContext.Current.Request.RawUrl;
            if (url.Contains("?"))
            {
                url = url.Remove(url.IndexOf('?'));
            }

            query = UrlHelper.RemoveUrlParameter(query, "AliasPath");

            string[,] pageTitleTabs = null;

            pageTitleTabs = new string[2, 3];

            pageTitleTabs[0, 0] = Server.HtmlEncode(mGroupName);
            pageTitleTabs[0, 1] = url + UrlHelper.RemoveUrlParameter(query, mForumProperties.QueryStringForumID);
            pageTitleTabs[0, 2] = "";
            pageTitleTabs[1, 0] = Server.HtmlEncode(mForumName);
            pageTitleTabs[1, 1] = "";
            pageTitleTabs[1, 2] = "";

            BreadCrumbs.Breadcrumbs = pageTitleTabs;
            BreadCrumbs.SeparatorText = " > ";

            lblSeparator.Text = " | ";
        }

        if (this.Visible)
        {
            // Register javascripts
            this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ForumScripts",
                       ScriptHelper.GetScript(
                       "function ReplyToPost(postId) { \n " +
                       "document.getElementById('" + hdnPostId.ClientID + "').value = postId; \n" +
                       this.Page.ClientScript.GetPostBackEventReference(this.btnPostb, null) +
                       "}\n" +

                       "function ShowPost(showId) { \n " +
                       "document.getElementById('" + hdnShowId.ClientID + "').value = showId; \n" +
                       this.Page.ClientScript.GetPostBackEventReference(this.btnPostb, null) +
                       "}\n" +

                          "function NewSubscribe(subscribeId) { \n " +
                       "document.getElementById('" + this.hdnSubscribeId.ClientID + "').value = subscribeId; \n" +
                       this.Page.ClientScript.GetPostBackEventReference(this.btnPostb, null) +
                       "}\n" +

                       "function NewThread() { \n " +
                       "document.getElementById('" + hdnPostId.ClientID + "').value = 0; \n" +
                       this.Page.ClientScript.GetPostBackEventReference(this.btnPostb, null) +
                       "}\n" + mJavaOutput ));
        }

        // Set Forum id
        PostTree1.mForumProperties = this.mForumProperties;
        
        // Hide New posst
        ForumNewPost1.Visible = false;
        ForumNewPost1.ForumID = this.ForumID;
        ForumNewPost1.AdHocForum = this.AdHocForum;

        if (this.PostReplyId == 0)
        {
            ForumPost1.PostID = this.PostId;
            ForumPost1.EnableSubscription = this.EnableSubscription;
        }   

        ForumNewPost1.OnInsertPost += new EventHandler(ForumNewPost1_OnInsertPost);
        ForumNewPost1.AllowRedirect = false;

        if (lnkNewThread.Visible && lnkSubscription.Visible)
        {
            lblLinkSeparator.Visible = true;
            lblLinkSeparator.Text = " | ";
        }

        if ((!lnkNewThread.Visible) && (!lnkSubscription.Visible))
        {
            lblSeparator.Visible = false;
        }

        if (this.ShowMode != ShowModeEnum.TreeMode)
        {
            ForumPost1.Visible = false;
        }
    }

    /// <summary>
    /// On insert new post
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void ForumNewPost1_OnInsertPost(object sender, EventArgs e)
    {
        ForumPost1.PostID = ((CMSForum_ForumNewPost)sender).PostID;
        this.ForumID = ((CMSForum_ForumNewPost)sender).ForumID;
        if (ForumPost1.PostID > 0)
        {
            PostTree1.Selected = ForumPost1.PostID;
            PostTree1.ForumID = this.ForumID;
            PostTree1.Visible = true;
            ForumPost1.Visible = true;
            ForumNewPost1.Visible = false;
            ForumNewPost1.ReplyToPostID = -1;
            hdnPostId.Value = "";

            ForumPostInfo mFpi = ForumPostInfoProvider.GetForumPostInfo( ForumPost1.PostID);
            if (mFpi != null)
            {
                ForumInfo mFi = ForumInfoProvider.GetForumInfo(this.ForumID);

                if ((mFi != null)&&(mFi.ForumModerated)&&(mFpi.PostApprovedByUserID == 0))
                {
                    ForumPost1.AllowReply = false;
                    ForumPost1.EnableSubscription = false;

                    ForumPost1.InfoText = ResHelper.GetString("Forums.ModeratedPostAdded");
                }
            }


            if (((this.AdHocForum) || (this.ForumID > 0)) && (!mClosed))
            {
                lnkNewThread.Visible = true;
                
                if (EnableSubscription)
                {
                    lnkSubscription.Visible = true;
                }
            }

            if (ValidationHelper.GetString(Request.QueryString[mForumProperties.QueryStringForumID], "") != "")
            {
                BreadCrumbs.Visible = true;
                lblSeparator.Visible = true;
            }

            if (lnkNewThread.Visible && lnkSubscription.Visible)
            {
                lblLinkSeparator.Visible = true;
                lblLinkSeparator.Text = " | ";
            }

            if ((!lnkNewThread.Visible) && (!lnkSubscription.Visible))
            {
                lblSeparator.Visible = false;
            }

            ForumNewPost1.ClearForm();

            if (this.ShowMode != ShowModeEnum.TreeMode)
            {
                ForumPost1.Visible = false;
            }
        }
    }

    /// <summary>
    /// Postback actions
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnPostb_Click(object sender, EventArgs e)
    {
        // Show post
        if ((isAuthenticated) || (NoAuthenticatedRead))
        {
            if (ValidationHelper.GetInteger(hdnShowId.Value, 0) != 0)
            {
                ForumPost1.Visible = true;
                ForumPost1.EnableSubscription = this.EnableSubscription;
                ForumNewPost1.Visible = false;
                ForumPost1.PostID = ValidationHelper.GetInteger(hdnShowId.Value, 0);
                PostTree1.Selected = ForumPost1.PostID;
                hdnShowId.Value = "";
                
                if (this.MaxRelativeLevel != -1)
                {
                    ForumPostInfo fpi = ForumPostInfoProvider.GetForumPostInfo(ForumPost1.PostID);
                    if (fpi != null)
                    {
                        if (fpi.PostLevel >= this.MaxRelativeLevel)
                        {
                            ForumPost1.EnableSubscription = false;
                            ForumPost1.AllowReply = false;
                        }
                    }
                }

                return;
            }
        }


        // Reply to post or New thread post
        if (isAuthenticated)
        {
            //Subscribe
            if (ValidationHelper.GetInteger(this.hdnSubscribeId.Value, -1) >= 0)
            {
                lnkNewThread.Visible = false;
                lnkSubscription.Visible = false;
                ForumPost1.Visible = false;
                ForumNewPost1.Visible = false;
                frmNewsubscribe.ForumID = this.ForumID;
                frmNewsubscribe.PostID = ValidationHelper.GetInteger(this.hdnSubscribeId.Value, 0);
                frmNewsubscribe.Visible = true;
                //hdnSubscribeId.Value = "";
                lblLinkSeparator.Visible = false;
                this.PostTree1.Visible = false;
                lblSeparator.Visible = false;
                BreadCrumbs.Visible = false;
                
            }
            else
            {

                if (ValidationHelper.GetInteger(hdnPostId.Value, -1) >= 0)
                {
                    ForumNewPost1.ClearForm();
                    ForumNewPost1.ReplyToPostID = ValidationHelper.GetInteger(hdnPostId.Value, 0);
                    ForumPost1.Visible = false;
                    ForumPost1.EnableSubscription = false;
                    ForumNewPost1.Visible = true;
                    PostTree1.Selected = ForumNewPost1.ReplyToPostID;
                    lblLinkSeparator.Visible = false;
                    this.PostTree1.Visible = false;
                    lblSeparator.Visible = false;
                    BreadCrumbs.Visible = false;
                    return;
                }
            }
        }
    }

    /// <summary> Render </summary>
    /// <param name="writer"></param>
    protected override void Render(HtmlTextWriter writer)
    {
        if (!this.StopProcessing)
        {
            base.Render(writer);
        }
    }
}
