using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Net;
using System.Net.Mail;
using System.IO;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.EmailEngine;
using CMS.DirectoryUtilities;
using CMS.SiteProvider;
using CMS.PortalEngine;

public partial class CMSSiteManager_Administration_System_System_Deployment : AdministrationPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        this.lblInfo.Text = ResHelper.GetString("Deployment.SaveAllInfo");
        this.btnSaveAll.Text = ResHelper.GetString("Deployment.SaveAll");
    }

    protected void btnSaveAll_Click(object sender, EventArgs e)
    {
        // Save all the document transformations
        DataSet ds = DataClassInfoProvider.GetAllDataClass();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                int classId = ValidationHelper.GetInteger(dr["ClassID"], 0);
                string className = ValidationHelper.GetString(dr["ClassName"], "");
                bool isDocumentType = ValidationHelper.GetBoolean(dr["ClassIsDocumentType"], false);

                if (isDocumentType)
                {
                    // Get the transformations
                    DataSet transformationsDS = TransformationInfoProvider.GetTransformations(classId);
                    if (!DataHelper.DataSourceIsEmpty(transformationsDS))
                    {
                        foreach (DataRow transformationRow in transformationsDS.Tables[0].Rows)
                        {
                            string transformationName = ValidationHelper.GetString(transformationRow["TransformationName"], "");
                            string transformationCode = ValidationHelper.GetString(transformationRow["TransformationCode"], "");

                            int checkedOutByUserId = ValidationHelper.GetInteger(transformationRow["TransformationCheckedOutByUserID"], 0);
                            string checkedOutMachineName = ValidationHelper.GetString(transformationRow["TransformationCheckedOutMachineName"], "");

                            if ((checkedOutByUserId < 0) || (checkedOutMachineName.ToLower() != HttpContext.Current.Server.MachineName.ToLower()))
                            {
                                string filename = TransformationInfoProvider.GetTransformationUrl(className + "." + transformationName, null);

                                SiteManagerFunctions.SaveCodeFile(filename, CMS.VirtualPathHelper.VirtualPathHelper.TransformationDirectives + transformationCode);
                            }
                        }
                    }
                }
            }
        }

        // Save all the layouts
        ds = LayoutInfoProvider.GetAllLayouts();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                string layoutName = ValidationHelper.GetString(dr["LayoutCodeName"], "");
                string layoutCode = ValidationHelper.GetString(dr["LayoutCode"], "");

                int checkedOutByUserId = ValidationHelper.GetInteger(dr["LayoutCheckedOutByUserID"], 0);
                string checkedOutMachineName = ValidationHelper.GetString(dr["LayoutCheckedOutMachineName"], "");

                if ((checkedOutByUserId < 0) || (checkedOutMachineName.ToLower() != HttpContext.Current.Server.MachineName.ToLower()))
                {
                    string filename = LayoutInfoProvider.GetLayoutUrl(layoutName, null);

                    SiteManagerFunctions.SaveCodeFile(filename, LayoutInfoProvider.GetLayoutDirectives() + layoutCode);
                }
            }
        }

        // Save all the page template layouts
        ds = PageTemplateInfoProvider.GetAllTemplates();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                string templateName = ValidationHelper.GetString(dr["PageTemplateCodeName"], "");
                string templateLayout = ValidationHelper.GetString(dr["PageTemplateLayout"], "");

                int checkedOutByUserId = ValidationHelper.GetInteger(dr["PageTemplateLayoutCheckedOutByUserID"], 0);
                string checkedOutMachineName = ValidationHelper.GetString(dr["PageTemplateLayoutCheckedOutMachineName"], "");

                if ( (templateLayout != "") && (checkedOutByUserId < 0) || (checkedOutMachineName.ToLower() != HttpContext.Current.Server.MachineName.ToLower()))
                {
                    string filename = PageTemplateInfoProvider.GetLayoutUrl(templateName, null);

                    SiteManagerFunctions.SaveCodeFile(filename, LayoutInfoProvider.GetLayoutDirectives() + templateLayout);
                }
            }
        }

        this.lblResult.Text = ResHelper.GetString("Deployment.ObjectsSaved");
    }
}
