using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Net;
using System.Net.Mail;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.EmailEngine;

public partial class CMSSiteManager_Administration_System_System_Email : AdministrationPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Initialize controls
        lblServer.Text = ResHelper.GetString("System_Email.SMTPServer");
        lblUserName.Text = ResHelper.GetString("System_Email.SMTPUserName");
        lblPassword.Text = ResHelper.GetString("System_Email.SMTPPassword");
        lblFrom.Text = ResHelper.GetString("System_Email.From");
        lblTo.Text = ResHelper.GetString("System_Email.To");
        lblSubject.Text = ResHelper.GetString("System_Email.Subject");
        lblText.Text = ResHelper.GetString("System_Email.Text");
        btnSend.Text = ResHelper.GetString("System_Email.Send");
        // Initialize required field validators
        rfvServer.ErrorMessage = ResHelper.GetString("System_Email.ErrorServer");
        revFrom.ErrorMessage = ResHelper.GetString("System_Email.ErrorEmail");
        rfvFrom.ErrorMessage = revFrom.ErrorMessage;
        revFrom.ValidationExpression = @"^[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)*@[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)+$";
        revTo.ErrorMessage = revFrom.ErrorMessage;
        rfvTo.ErrorMessage = revTo.ErrorMessage;
        revTo.ValidationExpression = @"^([A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)*@[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)+(;)?)+$";

        if (!IsPostBack)
        {
            // Fill SMTP fields
            if (CMSContext.CurrentSite != null)
            {
                string siteName = CMSContext.CurrentSite.SiteName;
                txtServer.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServer");
                txtUserName.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServerUser");
                txtPassword.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServerPassword");
            }
        }
    }


    /// <summary>
    /// On btnSend click.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSend_Click(object sender, EventArgs e)
    {
        string result = new Validator().NotEmpty(txtServer.Text, ResHelper.GetString("System_Email.ErrorServer")).NotEmpty(txtFrom.Text, ResHelper.GetString("System_Email.ErrorEmail")).NotEmpty(txtTo.Text, ResHelper.GetString("System_Email.ErrorEmail")).Result;

        if (result == "")
        {
            // Validate e-mail addresses
            if (ValidationHelper.IsEmail(txtFrom.Text) && ValidationHelper.AreEmails(txtTo.Text))
            {
                // Send the testing e-mail
                try
                {
                    SendEmail();

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("System_Email.EmailSent");
                }
                catch(Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message;
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("System_Email.ErrorEmail");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Send testing e-mail.
    /// </summary>
    protected void SendEmail()
    {
        MailMessage msg = new MailMessage();
        SmtpClient client = new SmtpClient();

        // Set from, to, subject and body.
        msg.From = new MailAddress(txtFrom.Text);

        string[] to = txtTo.Text.Split(';');
        foreach (string s in to)
        {
            msg.To.Add(new MailAddress(s));
        }

        msg.Subject = txtSubject.Text;
        msg.Body = txtText.Text;
        // Use HTML format
        msg.IsBodyHtml = true;
        // Set encoding
        string encoding = null;
        if (CMSContext.CurrentSite != null)
        {
            encoding = SettingsKeyProvider.GetStringValue(CMSContext.CurrentSite.SiteName + ".CMSEmailEncoding").ToLower();
        }
        else
        {
            encoding = SettingsKeyProvider.GetStringValue("CMSEmailEncoding").ToLower();
        }

        if (encoding != "")
        {
            msg.BodyEncoding = System.Text.Encoding.GetEncoding(encoding);
            msg.Headers.Add("Content-type", @"text/html; format=flowed; delsp=yes;  charset=""" + encoding + @"""");
            msg.SubjectEncoding = System.Text.Encoding.GetEncoding(encoding);
        }
        else
        {
            msg.BodyEncoding = System.Text.Encoding.UTF8;
            //Content-Type: text/plain; format=flowed; delsp=yes; charset=iso-8859-15
            msg.Headers.Add("Content-type", @"text/html; format=flowed; delsp=yes; charset=""" + encoding + @"""");
            msg.SubjectEncoding = System.Text.Encoding.UTF8;
        }

        // Setup the SMTP server
        string smtpServer = txtServer.Text;
        if (smtpServer != "")
        {
            // Try to parse with port
            int portIndex = smtpServer.LastIndexOf(":");
            int port = 0;
            if (portIndex >= 0)
            {
                string smtpPort = smtpServer.Substring(portIndex + 1);
                port = ValidationHelper.GetInteger(smtpPort, 0);
                if (port > 0)
                {
                    smtpServer = smtpServer.Substring(0, portIndex);
                    client.Port = port;
                }
            }

            client.Host = smtpServer;
        }
        else
        {
            client.Host = "localhost";
        }

        // SMTP user info
        string smtpUser = txtUserName.Text;
        string smtpPsswd = txtPassword.Text;
        if (smtpUser != "")
        {
            NetworkCredential credentials = new NetworkCredential(smtpUser, smtpPsswd);
            client.Credentials = credentials;
        }
        else
        {
            client.UseDefaultCredentials = true;
        }

        // Send e-mail
        client.Send(msg);
    }
}
