using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DirectoryUtilities;

public partial class CMSSiteManager_Development_CssStylesheets_CssStylesheet_General : SiteManagerPage
{
    protected string mSave = null;
    protected string mCheckIn = null;
    protected string mCheckOut = null;
    protected string mUndoCheckOut = null;

    protected int cssStylesheetId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        mCheckOut = ResHelper.GetString("CssStylesheet.CheckOut");
        mCheckIn = ResHelper.GetString("CssStylesheet.CheckIn");
        mUndoCheckOut = ResHelper.GetString("CssStylesheet.DiscardCheckOut");
        mSave = ResHelper.GetString("General.Save");
        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/";
        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        this.imgCheckIn.ImageUrl = imagesUrl + "checkin.gif";
        this.imgCheckOut.ImageUrl = imagesUrl + "checkout.gif";
        this.imgUndoCheckOut.ImageUrl = imagesUrl + "undocheckout.gif";
        this.btnUndoCheckOut.OnClientClick = "return confirm('" + ResHelper.GetString("General.ConfirmUndoCheckOut") + "');";

        lblCssStylesheetDisplayName.Text = ResHelper.GetString("CssStylesheet_General.DisplayName");
        lblCssStylesheetName.Text = ResHelper.GetString("CssStylesheet_General.Name");
        lblCssStylesheetText.Text = ResHelper.GetString("CssStylesheet_General.Text");

        rfvDisplayName.ErrorMessage = ResHelper.GetString("CssStylesheet_General.EmptyDisplayName");
        rfvName.ErrorMessage = ResHelper.GetString("CssStylesheet_General.EmptyName");
        rfvText.ErrorMessage = ResHelper.GetString("CssStylesheet_General.EmptyText");

        if (ValidationHelper.GetString(Request.QueryString["saved"], "") != "")
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
        }

        if ((Request.QueryString["cssstylesheetid"] != null) && (Request.QueryString["cssstylesheetid"].ToString() != ""))
        {
            cssStylesheetId = Convert.ToInt32(Request.QueryString["cssstylesheetid"]);
            if (!IsPostBack)
            {
                CssStylesheetInfo si = CssStylesheetInfoProvider.GetCssStylesheetInfo(cssStylesheetId);
                if (si != null)
                {
                    txtCssStylesheetDisplayName.Text = si.StylesheetDisplayName;
                    txtCssStylesheetName.Text = si.StylesheetName;
                    txtCssStylesheetText.Text = si.StylesheetText;

                    if (si.StylesheetCheckedOutByUserID > 0)
                    {
                        this.txtCssStylesheetText.ReadOnly = true;
                        string username = null;
                        UserInfo ui = UserInfoProvider.GetUserInfo(si.StylesheetCheckedOutByUserID);
                        if (ui != null)
                        {
                            username = ui.FullName;
                        }

                        // Checked out by current machine
                        if (si.StylesheetCheckedOutMachineName.ToLower() == HttpContext.Current.Server.MachineName.ToLower())
                        {
                            this.plcCheckIn.Visible = true;

                            this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("CssStylesheet.CheckedOut"), Server.MapPath(si.StylesheetCheckedOutFilename));
                        }
                        else
                        {
                            this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("CssStylesheet.CheckedOutOnAnotherMachine"), si.StylesheetCheckedOutMachineName, username);
                        }
                        //this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageStylesheet.CheckedOutOnAnotherMachine"), si.StylesheetCheckedOutMachineName, username);

                        if (CMSContext.CurrentUser.IsGlobalAdministrator)
                        {
                            this.plcUndoCheckOut.Visible = true;
                        }
                    }
                    else
                    {
                        this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("CssStylesheet.CheckOutInfo"), Server.MapPath(CssStylesheetInfoProvider.GetVirtualStylesheetUrl(si.StylesheetName, null)));

                        this.plcCheckOut.Visible = true;
                    }
                }
            }
        }
    }


    /// <summary>
    /// Saves the stylesheet, returns true if successful
    /// </summary>
    private bool SaveStylesheet()
    {
        string result = new Validator().NotEmpty(txtCssStylesheetDisplayName.Text, ResHelper.GetString("CssStylesheet_General.EmptyDisplayName")).NotEmpty(txtCssStylesheetName.Text, ResHelper.GetString("CssStylesheet_General.EmptyName")).NotEmpty(txtCssStylesheetText, ResHelper.GetString("CssStylesheet_General.EmptyText")).Result;

        if (result == "")
        {
            CssStylesheetInfo si = CssStylesheetInfoProvider.GetCssStylesheetInfo(cssStylesheetId);
            if (si != null)
            {
                si.StylesheetDisplayName = txtCssStylesheetDisplayName.Text;
                si.StylesheetName = txtCssStylesheetName.Text;
                si.StylesheetID = cssStylesheetId;

                if (si.StylesheetCheckedOutByUserID <= 0)
                {
                    si.StylesheetText = txtCssStylesheetText.Text;
                }

                try
                {
                    CssStylesheetInfoProvider.SetCssStylesheetInfo(si);
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message.Replace("%%name%%", txtCssStylesheetName.Text);
                    return false;
                }
                return true;
            }
            return false;
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
            return false;
        }
    }


    protected void btnSave_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty
        SaveStylesheet();
    }


    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        if (!SaveStylesheet())
        {
            return;
        }

        try
        {
            SiteManagerFunctions.CheckOutStylesheet(cssStylesheetId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("CssStylesheet.ErrorCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnUndoCheckOut_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.UndoCheckOutStylesheet(cssStylesheetId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("CssStylesheet.ErrorUndoCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.CheckInStylesheet(cssStylesheetId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("CssStylesheet.ErrorCheckin") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }
}
