using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Xml;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.DirectoryUtilities;

public partial class SiteManager_Development_DocumentTypes_DocumentType_Edit_Transformation_Edit : SiteManagerPage
{
    protected string mSave = null;
    protected string mCheckIn = null;
    protected string mCheckOut = null;
    protected string mUndoCheckOut = null;

    private int transformationId = 0;
    private string className = "";
    private TransformationInfo ti = new TransformationInfo();

    private bool onlyCodeEdit = false;

    protected void Page_Load(object sender, EventArgs e)
    {
        mCheckOut = ResHelper.GetString("Transformation.CheckOut");
        mCheckIn = ResHelper.GetString("Transformation.CheckIn");
        mUndoCheckOut = ResHelper.GetString("Transformation.DiscardCheckOut");
        mSave = ResHelper.GetString("General.Save");
        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/";
        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        this.imgCheckIn.ImageUrl = imagesUrl + "checkin.gif";
        this.imgCheckOut.ImageUrl = imagesUrl + "checkout.gif";
        this.imgUndoCheckOut.ImageUrl = imagesUrl + "undocheckout.gif";
        this.btnUndoCheckOut.OnClientClick = "return confirm('" + ResHelper.GetString("General.ConfirmUndoCheckOut") + "');";

        btnSave.PostBackUrl = "#";
        btnCheckIn.PostBackUrl = "#";
        btnCheckOut.PostBackUrl = "#";
        btnDefaultTransformation.PostBackUrl = "#";
        btnUndoCheckOut.PostBackUrl = "#";

        // initializes validator
        RequiredFieldValidatorTransformationName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.TransformationNameRequired");
        // initializes labels
        LabelInit();
        // displays helper table with transformation examples
        DisplayHelperTable();

        int classId = 0;
        string actualTransformName = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.NewTransformation");


        // Page has been opened in CMSDesk and only transformation code editing is allowed
        onlyCodeEdit = ValidationHelper.GetBoolean(Request.QueryString["editonlycode"], false);
        if (onlyCodeEdit)
        {
            // set page title
            PageTitle.TitleText = ResHelper.GetString("TransformationEdit.Title");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSWebParts/Designers/selecttransformation.gif";

            string transformationName = ValidationHelper.GetString(Request.QueryString["name"], "");

            if (transformationName != "")
            {
                // get transformation info
                ti = TransformationInfoProvider.GetTransformation(transformationName);
                if (ti != null)
                {
                    transformationId = ti.TransformationID;
                    className = DataClassInfoProvider.GetClassName(ti.TransformationClassID);
                    tbTransformationName.Enabled = false;
                }
                else
                {
                    // Hide panel Menu and write error message
                    pnlMenu.Visible = false;
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("formcontrols_selecttransformation.transofrmationnotexist").Replace("%%code%%", transformationName);
                }
            }
        }
        else
        {

            // gets classID from querystring, used when creating new transformation
            if (Request.QueryString["documenttypeid"] != null)
            {
                classId = Convert.ToInt32(Request.QueryString["documenttypeid"]);
                className = DataClassInfoProvider.GetClassName(classId);
            }

            // gets transformationID from querystring, used when editing transformation
            if ((Request.QueryString["transformationid"] != null) && (Request.QueryString["transformationid"] != ""))
            {
                transformationId = Convert.ToInt32(Request.QueryString["transformationid"]);
                string fullName = TransformationInfoProvider.GetTransformationFullName(transformationId);
                ti = TransformationInfoProvider.GetTransformation(fullName);
                actualTransformName = ti.TransformationName;

                className = DataClassInfoProvider.GetClassName(ti.TransformationClassID);
                classId = DataClassInfoProvider.GetDataClass(className).ClassID;

                if (!Page.IsPostBack)
                {
                    // shows that the new transformation was created or updated successfully
                    if (Request.QueryString["saved"] == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }

            //initializes PageTitle
            string transformations = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.Transformations");
            string[,] pageTitleTabs = new string[2, 3];

            pageTitleTabs[0, 0] = transformations;
            pageTitleTabs[0, 1] = "~/CMSSiteManager/Development/DocumentTypes/DocumentType_Edit_Transformation_List.aspx?documenttypeid=" + classId.ToString();
            pageTitleTabs[0, 2] = "";
            pageTitleTabs[1, 0] = actualTransformName;
            pageTitleTabs[1, 1] = "";
            pageTitleTabs[1, 2] = "";
            PageTitle.Breadcrumbs = pageTitleTabs;
        }

        if ((!IsPostBack) && (ti != null))
        {
            // fills form with transformation information
            drpTransformationType.SelectedValue = ti.TransformationType.ToString();
            tbTransformationName.Text = ti.TransformationName;
            tbTransformationText.Text = ti.TransformationCode;

            pnlCheckOutInfo.Visible = true;
            // hide or display directives
            ltlDirectives.Visible = (drpTransformationType.SelectedValue.ToLower() == "ascx");

            if (ti.TransformationCheckedOutByUserID > 0)
            {
                this.tbTransformationText.ReadOnly = true;
                string username = null;
                UserInfo ui = UserInfoProvider.GetUserInfo(ti.TransformationCheckedOutByUserID);
                if (ui != null)
                {
                    username = ui.FullName;
                }

                // Checked out by current machine
                if (ti.TransformationCheckedOutMachineName.ToLower() == HttpContext.Current.Server.MachineName.ToLower())
                {
                    this.plcCheckIn.Visible = true;

                    this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("Transformation.CheckedOut"), Server.MapPath(ti.TransformationCheckedOutFilename));
                }
                else
                {
                    this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("Transformation.CheckedOutOnAnotherMachine"), ti.TransformationCheckedOutMachineName, username);
                }

                if (CMSContext.CurrentUser.IsGlobalAdministrator)
                {
                    this.plcUndoCheckOut.Visible = true;
                }
            }
            else
            {
                this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("Transformation.CheckOutInfo"), Server.MapPath(TransformationInfoProvider.GetTransformationUrl(ti.TransformationFullName, null)));

                this.plcCheckOut.Visible = true;
            }
        }

    }


    /// <summary>
    /// Initializes labels
    /// </summary>
    private void LabelInit()
    {
        // initializes labels
        lblTransformationName.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.TransformName");
        lblTransformationType.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.TransformType");
        lblTransformationCode.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.TransformCode");
        btnDefaultTransformation.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.ButtonDefault");
        string lang = DataHelper.GetNotEmpty(System.Configuration.ConfigurationManager.AppSettings["CMSProgrammingLanguage"], "C#");
        ltlDirectives.Text = "&lt;%@ Control Language=\"" + lang + "\" AutoEventWireup=\"true\" Inherits=\"CMS.Controls.CMSAbstractTransformation\" %&gt;<br />&lt;%@ Register TagPrefix=\"cc1\" Namespace=\"CMS.Controls\" Assembly=\"CMS.Controls\" %&gt;";

    }


    /// <summary>
    /// Saves data of edited or new transformation into DB.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSave_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty or well filled
        string result = new Validator().NotEmpty(tbTransformationName.Text, ResHelper.GetString("DocumentType_Edit_Transformation_Edit.TransformationNameRequired")).Result;

        if (result == "")
        {
            if (drpTransformationType.SelectedValue.ToLower() == "xslt")
            {
                // validates XSLT transformatin text
                result = XMLValidator(tbTransformationText.Text);
            }
            if (result == "")
            {

                bool isSaved = false;
                TransformationInfo newTransformation = null;
                // gets full transformation name in the form - "ClassName.TransformationName"
                string fullTransformName;
                if (className != "")
                {
                    fullTransformName = className + "." + tbTransformationName.Text;
                }
                else
                {
                    fullTransformName = tbTransformationName.Text;
                }
                // finds whether new or edited transformation is unique in the document type
                try
                {
                    // throws exception if transformation of the given name doesn't exist
                    newTransformation = TransformationInfoProvider.GetTransformation(fullTransformName);

                    if (newTransformation.TransformationID == transformationId)
                    {
                        SaveTransformation();
                        isSaved = true;
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.UniqueTransformationName");
                    }
                }
                catch
                {
                    SaveTransformation();
                    isSaved = true;
                }
                if ((isSaved) && (!onlyCodeEdit))
                {
                    Response.Redirect("DocumentType_Edit_Transformation_Edit.aspx?transformationid=" + ti.TransformationID.ToString() + "&saved=1");
                }
                if ((isSaved) && (onlyCodeEdit))
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }

            }
            else
            {
                // XML validation error
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("DocumentType_Edit_Transformation_Edit.XSLTTransformationError") + "'" + result + "'";
            }
        }
        else
        {
            // required field validation error
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Checks whether XSLT transformation text is valid
    /// </summary>
    /// <param name="xmlText">XML text.</param>
    /// <returns>Error message.</returns>
    protected string XMLValidator(string xmlText)
    {
        // creates memory stream from transformation text
        Stream stream = new MemoryStream();
        StreamWriter writer = new StreamWriter(stream);
        writer.Write(xmlText);
        writer.Flush();
        stream.Seek(0, SeekOrigin.Begin);
        // new xml text reader from the stream
        XmlTextReader tr = new XmlTextReader(stream);
        try
        {
            // Need to read the data to validate
            while (tr.Read()) ;
        }
        catch (Exception ex)
        {
            return ex.Message;
        }

        return "";
    }


    /// <summary>
    /// Default Transformation Click event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnDefaultTransformation_Click(object sender, EventArgs e)
    {
        DefaultTransformation();
    }


    /// <summary>
    /// Generates transformation code depending on the transformation type (Xslt, Ascx)
    /// </summary>
    private void DefaultTransformation()
    {
        // gets Xml schema of the document type
        string formDef = DataClassInfoProvider.GetDataClass(className).ClassFormDefinition;

        // gets transformation type
        TransformationTypeEnum transformType = new TransformationTypeEnum();
        if (drpTransformationType.SelectedValue == "Ascx")
        {
            transformType = TransformationTypeEnum.Ascx;
        }
        else
        {
            transformType = TransformationTypeEnum.Xslt;
        }
        // writes the result to the text box
        tbTransformationText.Text = TransformationInfoProvider.GenerateTransformationCode(formDef, transformType, className);
    }


    /// <summary>
    /// Saves new or edited transformation of the given name and returns to the transformation list.
    /// </summary>
    private void SaveTransformation()
    {
        // sets transformation object's properties
        ti.TransformationName = tbTransformationName.Text;
        ti.TransformationClassID = DataClassInfoProvider.GetDataClass(className).ClassID;
        if (drpTransformationType.SelectedValue == "Ascx")
        {
            ti.TransformationType = TransformationTypeEnum.Ascx;
        }
        else
        {
            ti.TransformationType = TransformationTypeEnum.Xslt;
        }

        if (ti.TransformationCheckedOutByUserID <= 0)
        {
            ti.TransformationCode = tbTransformationText.Text;
        }

        TransformationInfoProvider.SetTransformation(ti);
    }


    /// <summary>
    /// Displays helper table with transformation examples.
    /// </summary>
    protected void DisplayHelperTable()
    {
        // 0 - left column (example), 1 - right column (explanation)
        string[,] tableColumns = new string[8, 2];

        //transformation expression examples
        tableColumns[0, 0] = "&lt;%# Eval(\"NewsTitle\") %&gt;";
        tableColumns[0, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_Eval");

        tableColumns[1, 0] = "&lt;%# GetDocumentUrl() %&gt;";
        tableColumns[1, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_GetDocumentUrl");

        tableColumns[2, 0] = "&lt;%# GetDocumentLink() %&gt;";
        tableColumns[2, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_GetDocumentLink");

        tableColumns[3, 0] = "&lt;%# GetFileUrl(\"ProductPhoto\") %&gt;";
        tableColumns[3, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_GetFileUrl");

        tableColumns[4, 0] = "&lt;%# GetImage(\"ProductPhoto\") %&gt;";
        tableColumns[4, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_GetImage");

        tableColumns[5, 0] = "&lt;%# GetDateTime(\"NewsReleaseDate\", \"d\") %&gt;";
        tableColumns[5, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_DateTime");

        tableColumns[6, 0] = "&lt;%# GetDateTime(\"NewsReleaseDate\") %&gt;";
        tableColumns[6, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_DateTime_DatePart");

        tableColumns[7, 0] = "&lt;%# IfEmpty(Eval(\"ProductPhoto\"), \"no image\", \"&lt;img src=\\\" + Eval(\"ProductPhoto\") + \" /&gt;\") %&gt;";
        tableColumns[7, 1] = ResHelper.GetString("DocumentType_Edit_Transformation.Help_IfEmpty");

        for (int i = 0; i < tableColumns.GetUpperBound(0) + 1; i++)
        {
            TableRow tRow = new TableRow();
            TableCell leftCell = new TableCell();
            TableCell rightCell = new TableCell();
            Label lblExample = new Label();
            Label lblExplanation = new Label();

            // init labels
            lblExample.Text = tableColumns[i, 0];
            lblExplanation.Text = tableColumns[i, 1];

            // add labels to the cells
            leftCell.Controls.Add(lblExample);
            rightCell.Controls.Add(lblExplanation);

            leftCell.Wrap = false;

            // add cells to the row
            tRow.Cells.Add(leftCell);
            tRow.Cells.Add(rightCell);

            // add row to the table
            tblHelp.Rows.Add(tRow);
        }

        lblHelpHeader.Text = ResHelper.GetString("DocumentType_Edit_Transformation.Help_Header");
    }


    protected void drpTransformationType_SelectedIndexChanged(object sender, EventArgs e)
    {
        // hide or display directives and examples
        if (drpTransformationType.SelectedValue.ToLower() == "ascx")
        {
            lblHelpHeader.Visible = true;
            ltlDirectives.Visible = true;
            tblHelp.Visible = true;
        }
        else
        {
            lblHelpHeader.Visible = false;
            ltlDirectives.Visible = false;
            tblHelp.Visible = false;
        }
    }


    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        SaveTransformation();
        try
        {
            SiteManagerFunctions.CheckOutTransformation(transformationId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Transformation.ErrorCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnUndoCheckOut_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.UndoCheckOutTransformation(transformationId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Transformation.ErrorUndoCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.CheckInTransformation(transformationId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Transformation.ErrorCheckin") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }
}
