using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.DirectoryUtilities;

public partial class SiteManager_Development_PageLayouts_PageLayout_Edit_General : SiteManagerPage
{
    protected string mSave = null;
    protected string mCheckIn = null;
    protected string mCheckOut = null;
    protected string mUndoCheckOut = null;

    protected int layoutId = 0;
    string[,] pageTitleTabs = new string[2, 3];

    protected void Page_Load(object sender, EventArgs e)
    {
        mCheckOut = ResHelper.GetString("PageLayout.CheckOut");
        mCheckIn = ResHelper.GetString("PageLayout.CheckIn");
        mUndoCheckOut = ResHelper.GetString("PageLayout.DiscardCheckOut");
        mSave = ResHelper.GetString("General.Save");
        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/";
        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        this.imgCheckIn.ImageUrl = imagesUrl + "checkin.gif";
        this.imgCheckOut.ImageUrl = imagesUrl + "checkout.gif";
        this.imgUndoCheckOut.ImageUrl = imagesUrl + "undocheckout.gif";
        this.btnUndoCheckOut.OnClientClick = "return confirm('" + ResHelper.GetString("General.ConfirmUndoCheckOut") + "');";

        lbCodeName.Text = ResHelper.GetString("Administration-PageLayout_New.LayoutCodeName");
        lbLayoutDisplayName.Text = ResHelper.GetString("Administration-PageLayout_New.LayoutDisplayName");
        lbLayoutDescription.Text = ResHelper.GetString("Administration-PageLayout_New.LayoutDescription");
        lbLayoutCode.Text = ResHelper.GetString("Administration-PageLayout_New.LayoutCode");
        rfvLayoutDisplayName.ErrorMessage = ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutDisplayName");
        rfvLayoutDescription.ErrorMessage = ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutDescription");
        rfvLayoutCode.ErrorMessage = ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutCode");
        rfvCodeName.ErrorMessage = ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutCodeName");
        string lang = DataHelper.GetNotEmpty(System.Configuration.ConfigurationManager.AppSettings["CMSProgrammingLanguage"], "C#");
        ltlDirectives.Text = "&lt;%@ Control Language=\"" + lang + "\" ClassName=\"Simple\" Inherits=\"CMS.PortalControls.CMSAbstractLayout\" %&gt;<br />&lt;%@ Register Assembly=\"CMS.PortalControls\" Namespace=\"CMS.PortalControls\" TagPrefix=\"cc1\" %&gt;";

        if ((Request.QueryString["layoutID"] != null) && (Request.QueryString["layoutID"] != ""))
        {
            layoutId = Convert.ToInt32(Request.QueryString["layoutID"]);

            if (!IsPostBack)
            {
                LoadData();
            }
        }
        else
        {
            if (tbCodeName.Text == "")
            {
                // default layout code content
                tbLayoutCode.Text = "<cc1:CMSWebPartZone ID=\"zoneCenter\" runat=\"server\" />";
            }
        }


        string layouts = ResHelper.GetString("Administration-PageLayout_New.NewLayout");
        string title = ResHelper.GetString("Administration-PageLayout_New.Title");
        string image = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/PageLayouts/newlayout.gif";
        // gets 'layoutid' from querystring
        string currentLayout = ResHelper.GetString("Administration-PageLayout_New.CurrentLayout");
        if (Request.QueryString["layoutid"] != null)
        {
            layoutId = Convert.ToInt32(Request.QueryString["layoutId"]);
            // gets page layout info of specified 'layoutid'
            LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(layoutId);
            currentLayout = li.LayoutDisplayName;
            title = ResHelper.GetString("Administration-PageLayout_New.EditLayout");
            image = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/PageLayouts/layout.gif";
        }

        if (Request.QueryString["saved"] != null && Request.QueryString["saved"] == "1")
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
        }

        pageTitleTabs[0, 0] = layouts;
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Development/PageLayouts/PageLayout_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentLayout;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = title;
        PageTitle.TitleImage = image;
    }


    /// <summary>
    /// Saves the layout
    /// </summary>
    /// <returns>Returns true if successful</returns>
    private bool SaveLayout()
    {
        // Find out whether required fields are not empty
        string result = new Validator().NotEmpty(tbCodeName.Text, ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutCodeName")).NotEmpty(tbLayoutDisplayName.Text, ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutDisplayName")).NotEmpty(tbLayoutDescription.Text, ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutDescription")).NotEmpty(tbLayoutCode.Text, ResHelper.GetString("Administration-PageLayout_New.ErrorEmptyLayoutCode")).Result;

        if (result == "")
        {
            LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(layoutId);
            if (li == null)
            {
                li = new LayoutInfo();
            }
            li.LayoutCodeName = tbCodeName.Text;
            li.LayoutDisplayName = tbLayoutDisplayName.Text;
            li.LayoutDescription = tbLayoutDescription.Text;
            if (li.LayoutCheckedOutByUserID <= 0)
            {
                li.LayoutCode = tbLayoutCode.Text;
            }

            try
            {
                LayoutInfoProvider.SetLayoutInfo(li);
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                pageTitleTabs[1, 0] = li.LayoutDisplayName;
            }
            catch (Exception ex)
            {
                lblInfo.Visible = false;
                lblError.Visible = true;
                lblError.Text = ex.Message.Replace("%%name%%", li.LayoutCodeName);
                return false;
            }
            layoutId = li.LayoutId;
            return true;
        }
        else
        {
            lblError.Text = result;
            lblError.Visible = true;
            return false;
        }
    }


    /// <summary>
    /// Handles btnOK's OnClick event - Update layout info
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSave_Click(object sender, EventArgs e)
    {
        if (SaveLayout())
        {
            Response.Redirect("PageLayout_Edit.aspx?layoutID=" + layoutId + "&saved=1");
            /*PageTitle.Breadcrumbs[1, 0] = tbLayoutDisplayName.Text;
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");*/

        }
    }


    /// <summary>
    /// Loads data of edited layout from DB into TextBoxes.
    /// </summary>
    protected void LoadData()
    {
        LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(layoutId);

        if (li != null)
        {
            this.pnlCheckOutInfo.Visible = true;
            tbLayoutDisplayName.Text = li.LayoutDisplayName;
            tbLayoutDescription.Text = li.LayoutDescription;
            tbLayoutCode.Text = li.LayoutCode;
            tbCodeName.Text = li.LayoutCodeName;

            if (li.LayoutCheckedOutByUserID > 0)
            {
                this.tbLayoutCode.ReadOnly = true;
                string username = null;
                UserInfo ui = UserInfoProvider.GetUserInfo(li.LayoutCheckedOutByUserID);
                if (ui != null)
                {
                    username = ui.FullName;
                }

                // Checked out by current machine
                if (li.LayoutCheckedOutMachineName.ToLower() == HttpContext.Current.Server.MachineName.ToLower())
                {
                    this.plcCheckIn.Visible = true;

                    this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOut"), Server.MapPath(li.LayoutCheckedOutFilename));
                }
                else
                {
                    this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOutOnAnotherMachine"), li.LayoutCheckedOutMachineName, username);
                }
                //this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOutOnAnotherMachine"), li.LayoutCheckedOutMachineName, username);

                if (CMSContext.CurrentUser.IsGlobalAdministrator)
                {
                    this.plcUndoCheckOut.Visible = true;
                }
            }
            else
            {
                this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckOutInfo"), Server.MapPath(LayoutInfoProvider.GetLayoutUrl(li.LayoutCodeName, null)));

                this.plcCheckOut.Visible = true;
            }

        }
    }


    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        // Save first
        if (!SaveLayout())
        {
            return;
        }

        try
        {
            SiteManagerFunctions.CheckOutLayout(layoutId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnUndoCheckOut_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.UndoCheckOutLayout(layoutId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorUndoCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.CheckInLayout(layoutId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorCheckin") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }
}
