using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.PortalEngine;
using CMS.CMSHelper;
using CMS.DirectoryUtilities;
using CMS.SettingsProvider;

public partial class CMSSiteManager_Development_PageTemplates_PageTemplate_Layouts : SiteManagerPage
{
    protected string mSave = null;
    protected string mCheckIn = null;
    protected string mCheckOut = null;
    protected string mUndoCheckOut = null;
    protected int templateId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!SettingsKeyProvider.UsingVirtualPathProvider)
        {
            this.lblVirtualInfo.Text = ResHelper.GetString("TemplateLayout.VirtualPathProviderNotRunning");
            this.pnlInfo.Visible = true;
            this.plcLayout.Visible = false;
            return;
        }

        templateId = ValidationHelper.GetInteger(Request.QueryString["TemplateId"], 0);

        mCheckOut = ResHelper.GetString("PageLayout.CheckOut");
        mCheckIn = ResHelper.GetString("PageLayout.CheckIn");
        mUndoCheckOut = ResHelper.GetString("PageLayout.DiscardCheckOut");
        mSave = ResHelper.GetString("General.Save");
        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/";
        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        this.imgCheckIn.ImageUrl = imagesUrl + "checkin.gif";
        this.imgCheckOut.ImageUrl = imagesUrl + "checkout.gif";
        this.imgUndoCheckOut.ImageUrl = imagesUrl + "undocheckout.gif";
        this.btnUndoCheckOut.OnClientClick = "return confirm('" + ResHelper.GetString("General.ConfirmUndoCheckOut") + "');";

        radCustom.Text = ResHelper.GetString("TemplateLayout.Custom");
        radShared.Text = ResHelper.GetString("TemplateLayout.Shared");

        if (!IsPostBack)
        {
            ReloadData();
        }
    }


    /// <summary>
    /// Reload data
    /// </summary>
    public void ReloadData()
    {
        if (templateId > 0)
        {
            PageTemplateInfo pti = PageTemplateInfoProvider.GetPageTemplateInfo(templateId);

            if (pti != null)
            {
                if (!pti.IsPortal)
                {
                    pnlCustomBody.Visible = false;
                    pnlMenu.Visible = false;
                    pnlCheckOutInfo.Visible = false;
                    lblAspxInfo.Text = ResHelper.GetString("TemplateLayout.ASPXtemplate");

                    return;
                }

                this.pnlCheckOutInfo.Visible = true;


                if (pti.PageTemplateLayoutCheckedOutByUserID > 0)
                {
                    this.txtCustom.ReadOnly = true;
                    string username = null;
                    UserInfo ui = UserInfoProvider.GetUserInfo(pti.PageTemplateLayoutCheckedOutByUserID);
                    if (ui != null)
                    {
                        username = ui.FullName;
                    }

                    // Checked out by current machine
                    if (pti.PageTemplateLayoutCheckedOutMachineName.ToLower() == HttpContext.Current.Server.MachineName.ToLower())
                    {
                        this.plcCheckIn.Visible = true;

                        this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOut"), Server.MapPath(pti.PageTemplateLayoutCheckedOutFileName));
                    }
                    else
                    {
                        this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOutOnAnotherMachine"), pti.PageTemplateLayoutCheckedOutFileName, username);
                    }
                    //this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckedOutOnAnotherMachine"), li.LayoutCheckedOutMachineName, username);

                    if (CMSContext.CurrentUser.IsGlobalAdministrator)
                    {
                        this.plcUndoCheckOut.Visible = true;
                    }
                }
                else
                {

                    this.lblCheckOutInfo.Text = String.Format(ResHelper.GetString("PageLayout.CheckOutInfo"), Server.MapPath(PageTemplateInfoProvider.GetLayoutUrl(pti.CodeName, null)));

                    this.plcCheckOut.Visible = true;
                }

                FillDropDownList();

                if (ValidationHelper.GetInteger(pti.LayoutID, 0) > 0)
                {
                    plcCheck.Visible = false;
                    pnlCheckOutInfo.Visible = false;
                    
                    radShared.Checked = true;
                    txtCustom.Enabled = false;
                    drpShared.Enabled = true;
                    try
                    {
                        txtCustom.Text = pti.PageTemplateLayout;
                        drpShared.SelectedValue = pti.LayoutID.ToString();

                        if (ValidationHelper.GetString(pti.PageTemplateLayout, "") == "")
                        {
                            LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(pti.LayoutID);
                            if (li != null)
                            {
                                txtCustom.Text = li.LayoutCode;
                            }
                        }
                    }
                    catch
                    {
                    }

                }
                else
                {
                    radCustom.Checked = true;
                    txtCustom.Text = pti.PageTemplateLayout;
                    txtCustom.Enabled = true;
                    drpShared.Enabled = false;
                }

            }
        }
    }


    /// <summary>
    /// Fill dropdown list
    /// </summary>
    public void FillDropDownList()
    {
        DataSet ds = LayoutInfoProvider.GetAllLayouts();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            drpShared.DataTextField = "LayoutDisplayName";
            drpShared.DataValueField = "LayoutID";
            drpShared.DataSource = ds;
            drpShared.DataBind();
        }
    }


    /// <summary>
    /// Save layout
    /// </summary>
    /// <returns></returns>
    public bool SaveLayout()
    {
        PageTemplateInfo pti = PageTemplateInfoProvider.GetPageTemplateInfo(templateId);

        if (pti != null)
        {
            //Shared layout
            if (radShared.Checked)
            {
                plcCheck.Visible = false;
                pnlCheckOutInfo.Visible = false;
                pti.LayoutID = ValidationHelper.GetInteger(drpShared.SelectedValue, 0);
                pti.PageTemplateLayout = txtCustom.Text;
            }
            else //Custom layout
            {
                plcCheck.Visible = true;
                pnlCheckOutInfo.Visible = true;
                pti.LayoutID = 0;
                pti.PageTemplateLayout = txtCustom.Text;
            }

            PageTemplateInfoProvider.SetPageTemplateInfo(pti);

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");

            return true;
        }

        return false;
    }


    /// <summary>
    /// Handles btnOK's OnClick event - Update layout info
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSave_Click(object sender, EventArgs e)
    {
        SaveLayout();
    }


    /// <summary>
    /// Check out
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        // Save first
        if (!SaveLayout())
        {
            return;
        }

        try
        {
            SiteManagerFunctions.CheckOutTemplateLayout(templateId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    /// <summary>
    /// Undo check out
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnUndoCheckOut_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.UndoCheckOutTemplateLayout(templateId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorUndoCheckout") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    /// <summary>
    /// CheckIn
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        try
        {
            SiteManagerFunctions.CheckInTemplateLayout(templateId);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Layout.ErrorCheckin") + ": " + ex.Message;
            this.lblError.Visible = true;
            return;
        }

        Response.Redirect(Request.Url.AbsoluteUri);
    }


    /// <summary>
    /// Radio button changed
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radShared_CheckedChanged(object sender, EventArgs e)
    {
        if (radCustom.Checked)
        {
            txtCustom.Enabled = true;
            drpShared.Enabled = false;
        }
        else
        {
            txtCustom.Enabled = false;
            drpShared.Enabled = true;

            LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(ValidationHelper.GetInteger(drpShared.SelectedValue, 0));
            if (li != null)
            {
                txtCustom.Text = li.LayoutCode;
            }
        }

    }


    /// <summary>
    /// DropDownlist change
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void drpShared_SelectedIndexChanged(object sender, EventArgs e)
    {
        LayoutInfo li = LayoutInfoProvider.GetLayoutInfo(ValidationHelper.GetInteger(drpShared.SelectedValue, 0));
        if (li != null)
        {
            txtCustom.Text = li.LayoutCode;
        }
    }
}
