using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSSiteManager_Development_RelationshipNames_RelationshipName_New : SiteManagerPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // initializes labels
        lblRelationshipNameCodeName.Text = ResHelper.GetString("RelationshipNames.CodeName");
        lblRelationshipNameDisplayName.Text = ResHelper.GetString("RelationshipNames.DisplayName");
        ButtonOK.Text = ResHelper.GetString("General.OK");
        // check 'Assign with current web site' check box
        if ((CMSContext.CurrentSite != null) && (!IsPostBack))
        {
            chkAssign.Text = ResHelper.GetString("General.AssignWithWebSite") + " " + CMSContext.CurrentSite.DisplayName;
            chkAssign.Checked = true;
            chkAssign.Visible = true;
        }

        string relationshipNames = ResHelper.GetString("RelationshipNames.RelationshipNames");
        string currentRelationshipName = ResHelper.GetString("RelationshipNames.NewRelationshipName");
        string title = ResHelper.GetString("RelationshipNames.TitleNew");
        
        // initializes validators
        RequiredFieldValidatorCodeName.ErrorMessage = ResHelper.GetString("General.RequiresCodeName");
        RequiredFieldValidatorDisplayName.ErrorMessage = ResHelper.GetString("General.RequiresDisplayName");

        string relationshipNamesUrl = "~/CMSSiteManager/Development/RelationshipNames/RelationshipName_List.aspx";

        // initializes page title
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = relationshipNames;
        pageTitleTabs[0, 1] = relationshipNamesUrl;
        pageTitleTabs[0, 2] = "devmain";
        pageTitleTabs[1, 0] = currentRelationshipName;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitleNew.Breadcrumbs = pageTitleTabs;
        PageTitleNew.TitleText = title;
        PageTitleNew.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/RelationshipNames/newRelationshipName.gif";
    }

    /// <summary>
    /// Saves new relationship name's data and redirects to RelationshipName_Edit.aspx.
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event arguments</param>
    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty
        string result = new Validator().NotEmpty(txtRelationshipNameDisplayName.Text, ResHelper.GetString("General.RequiresDisplayName")).NotEmpty(txtRelationshipNameCodeName.Text, ResHelper.GetString("General.RequiresCodeName")).Result;

        if (result == "")
        {
            RelationshipNameInfo rni = RelationshipNameInfoProvider.GetRelationshipNameInfo(txtRelationshipNameCodeName.Text);
            if (rni == null)
            {
                int relationshipNameId = SaveNewRelationshipName();

                if (relationshipNameId > 0)
                {
                    Response.Redirect("RelationshipName_Edit.aspx?relationshipnameid=" + relationshipNameId + "&saved=1");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("RelationshipNames.RelationshipNameAlreadyExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }

    /// <summary>
    /// Saves new relationship name's data into DB
    /// </summary>
    /// <returns>Returns ID of created relationship name</returns>
    protected int SaveNewRelationshipName()
    {

        RelationshipNameInfo rni = new RelationshipNameInfo();
        rni.RelationshipDisplayName = txtRelationshipNameDisplayName.Text;
        rni.RelationshipName = txtRelationshipNameCodeName.Text;
        RelationshipNameInfoProvider.SetRelationshipNameInfo(rni);
        if ((chkAssign.Visible) && (chkAssign.Checked) && (CMSContext.CurrentSite != null) && (rni.RelationshipNameId > 0))
        {
            // Add new relationship name to the actual site
            RelationshipNameInfoProvider.AddRelationshipNameToSite(rni.RelationshipNameId, CMSContext.CurrentSite.SiteID);
        }
        return rni.RelationshipNameId;
    }
}
