using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.LicenseProvider;
using CMS.TreeEngine;

public partial class SiteManager_Development_Workflows_Workflow_List : SiteManagerPage
{

    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.WorkflowVersioning);
        }

        // control initialization
        lnkNewWorkflow.Text = ResHelper.GetString("Development-Workflow_List.NewWorkflow");

        UniGridWorkflows.GridView.GridLines = GridLines.Horizontal;
        UniGridWorkflows.OnAction += new OnActionEventHandler(UniGridRoles_OnAction);

        PageTitleWorkflowList.TitleText = ResHelper.GetString("Development-Workflow_List.Title");
        PageTitleWorkflowList.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/Workflows/workflow.gif";
        imgNewWorkflow.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/Workflows/addworkflow.gif";

        lnkNewWorkflow.NavigateUrl = "Workflow_New.aspx";
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that threw event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void UniGridRoles_OnAction(string actionName, object actionArgument)
    {
        int workflowid = Convert.ToInt32(actionArgument);

        if (actionName == "edit")
        {
            Response.Redirect("Workflow_Edit.aspx?workflowid=" + workflowid.ToString());
        }
        else if (actionName == "delete")
        {
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.administration", "Delete"))
            {
                RedirectToAccessDenied("cms.administration", "Delete");
            }

            // Check if documents use the workflow
            string where = "DocumentWorkflowStepID IN (SELECT StepID FROM CMS_WorkflowStep WHERE StepWorkflowID = " + workflowid.ToString() + " AND StepName NOT IN ('edit', 'published'))";

            TreeProvider tree = new TreeProvider();
            DataSet ds = tree.SelectNodes(TreeProvider.ALL_SITES, "/%", TreeProvider.ALL_CULTURES, false, null, where, "SiteName, NodeAliasPath", -1, false);
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                this.lblError.Text = ResHelper.GetString("Workflow.CannotDeleteUsed") + "<br />";
                this.lblError.Visible = true;

                int index = 0;
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    if (index > 10)
                    {
                        this.lblError.Text += "<br />&nbsp;...";
                        break;
                    }
                    this.lblError.Text += "<br />&nbsp;" + dr["SiteName"] + " - " + dr["DocumentNamePath"];
                    index++;
                }
            }
            else
            {
                // Delete the workflow
                WorkflowInfoProvider.DeleteWorkflowInfo(workflowid);
            }
        }
    }
}
