using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SiteProvider;

public partial class SiteManager_Development_Workflows_Workflow_Scope_Edit : SiteManagerPage
{
    protected int workflowScopeId = 0;
    protected int workflowId = 0;
    protected int siteId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.administration", "Modify"))
        {
            RedirectToAccessDenied("cms.administration", "Modify");
        }

        lblDocumentTypes.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.DocumentType");
        lblStartingAliasPath.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.StartingAliasPath");
        ButtonOK.Text = ResHelper.GetString("General.OK");

        rfvStartingAliasPath.ErrorMessage = ResHelper.GetString("Development-Workflow_Scope_Edit.RequiresStartingAliasPath");


        string startingAliasPath = "";
        int classId = 0;

        if ((Request.QueryString["scopeid"] != null) && (Request.QueryString["scopeid"].ToString() != ""))
        {
            workflowScopeId = Convert.ToInt32(Request.QueryString["scopeid"]);

            if (workflowScopeId > 0)
            {
                WorkflowScopeInfo wsi = WorkflowInfoProvider.GetWorkflowScopeInfo(workflowScopeId);
                if (wsi != null)
                {
                    workflowId = wsi.ScopeWorkflowID;
                    siteId = wsi.ScopeSiteID;
                    startingAliasPath = wsi.ScopeStartingPath;
                    classId = wsi.ScopeClassID;
                }
            }
        }
        else
        {
            if (((Request.QueryString["workflowid"] != null) && (Request.QueryString["workflowid"].ToString() != "")))
            {
                workflowId = Convert.ToInt32(Request.QueryString["workflowid"]);
            }
            if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"].ToString() != ""))
            {
                siteId = Convert.ToInt32(Request.QueryString["siteid"]);
            }
        }

        if (!IsPostBack)
        {
            txtStartingAliasPath.Text = startingAliasPath;

            this.drpDocumentTypes.DataSource = SiteInfoProvider.GetDocumentTypeClassPerSite(siteId);
            this.drpDocumentTypes.DataBind();

            // Add all documents record
            drpDocumentTypes.Items.Insert(0, new ListItem(ResHelper.GetString("DocumentTypes.All"), "0"));

            if ((classId > 0) && (drpDocumentTypes.Items.Count > 0))
            {
                drpDocumentTypes.SelectedValue = classId.ToString();
            }
        }

        string workflowScopes = ResHelper.GetString("Development-Workflow_Scope_New.Scopes");
        string workflowScopesUrl = "~/CMSSiteManager/Development/Workflows/Workflow_Scopes.aspx?workflowid=" + workflowId.ToString() + "&siteid=" + siteId.ToString();
        string currentScope = "";
        if (workflowScopeId > 0)
        {
            currentScope = ResHelper.GetString("Development-Workflow_Scope_New.ScopeID") + workflowScopeId.ToString();
        }
        else
        {
            currentScope = ResHelper.GetString("Development-Workflow_Scope_New.Scope");
        }

        // initializes page title
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = workflowScopes;
        pageTitleTabs[0, 1] = workflowScopesUrl;
        pageTitleTabs[0, 2] = "workflowsContent";
        pageTitleTabs[1, 0] = currentScope;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitleWorkflowScopes.Breadcrumbs = pageTitleTabs;
    }

    /// <summary>
    /// Saves data of edited workflow scope from TextBoxes into DB.
    /// </summary>
    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty
        string result = new Validator().NotEmpty(txtStartingAliasPath.Text, ResHelper.GetString("Development-Workflow_Scope_Edit.RequiresStartingAliasPath")).Result;

        if (result == "")
        {
            if (workflowScopeId > 0)
            {
                if (drpDocumentTypes.SelectedIndex > -1)
                {
                    WorkflowScopeInfo wsi = WorkflowInfoProvider.GetWorkflowScopeInfo(workflowScopeId);
                    if (wsi != null)
                    {
                        if (!txtStartingAliasPath.Text.StartsWith("/")) txtStartingAliasPath.Text = "/" + txtStartingAliasPath.Text;
                        wsi.ScopeStartingPath = txtStartingAliasPath.Text.Trim();
                        wsi.ScopeClassID = Convert.ToInt32(drpDocumentTypes.SelectedValue);
                        wsi.ScopeID = workflowScopeId;
                        WorkflowInfoProvider.SetWorkflowScopeInfo(wsi);
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.NoDocumentTypeGiven");
                }
            }
            else
            {
                if (workflowId > 0)
                {
                    if (siteId > 0)
                    {
                        if (drpDocumentTypes.SelectedIndex > -1)
                        {
                            if (!txtStartingAliasPath.Text.StartsWith("/")) txtStartingAliasPath.Text = "/" + txtStartingAliasPath.Text;
                            WorkflowScopeInfo wsi = new WorkflowScopeInfo();
                            wsi.ScopeStartingPath = txtStartingAliasPath.Text.Trim();
                            wsi.ScopeClassID = Convert.ToInt32(drpDocumentTypes.SelectedValue);
                            wsi.ScopeSiteID = Convert.ToInt32(Request.QueryString["siteid"]);
                            wsi.ScopeWorkflowID = Convert.ToInt32(Request.QueryString["workflowid"]);
                            WorkflowInfoProvider.SetWorkflowScopeInfo(wsi);
                            Response.Redirect("Workflow_Scope_Edit.aspx?scopeid=" + wsi.ScopeID);
                            /*lblError.Visible = true;
                            lblError.Text = ResHelper.GetString("General.ChangesSaved");*/
                        }
                        else
                        {
                            lblError.Visible = true;
                            lblError.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.NoDocumentTypeGiven");
                        }
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.NoSiteIdGiven");
                    }
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Development-Workflow_Scope_Edit.NoDocumentTypeGiven");
                }
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }



}
