using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.TreeEngine;

public partial class SiteManager_Development_Workflows_Workflow_Steps : SiteManagerPage
{
    protected int workflowId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // control initialization
        lnkNewStep.Text = ResHelper.GetString("Development-Workflow_Steps.NewStep");

        UniGridWorkflowSteps.GridView.GridLines = GridLines.Horizontal;
        UniGridWorkflowSteps.OnAction += new OnActionEventHandler(UniGridRoles_OnAction);
        UniGridWorkflowSteps.DataBinding += new EventHandler(UniGridWorkflowSteps_DataBinding);

        //PageTitleWorkflowSteps.TitleText = ResHelper.GetString("Development-Workflow_Steps.Title");
        //PageTitleWorkflowSteps.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/Workflows/step.gif";
        imgNewStep.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/Workflows/addstep.gif";

        if ((Request.QueryString["workflowid"] != null) && (Request.QueryString["workflowid"].ToString() != ""))
        {
            workflowId = Convert.ToInt32(Request.QueryString["workflowid"]);
        }
        lnkNewStep.NavigateUrl = "Workflow_Step_New.aspx?workflowid=" + workflowId.ToString();

        // Prepare the steps query parameters
        object[,] stepsParameters = new object[1, 3];
        stepsParameters[0, 0] = "@StepWorkflowID";
        stepsParameters[0, 1] = workflowId;
        UniGridWorkflowSteps.QueryParameters = stepsParameters;

        UniGridWorkflowSteps.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGridWorkflowSteps_OnExternalDataBound);
    }


    object UniGridWorkflowSteps_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            case "allowaction":
                GridViewRow container = (GridViewRow)parameter;
                switch (((DataRowView)container.DataItem)["StepName"].ToString().ToLower())
                {
                    case "edit":
                    case "published":
                    case "archived":
                        ((Control)sender).Visible = false;
                        break;
                }
                break;
        }
        return parameter;
    }


    void UniGridWorkflowSteps_DataBinding(object sender, EventArgs e)
    {
        UniGridWorkflowSteps.GridView.Sort("StepOrder", SortDirection.Ascending);
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that threw event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void UniGridRoles_OnAction(string actionName, object actionArgument)
    {
        int workflowstepid = Convert.ToInt32(actionArgument);
        if (actionName == "edit")
        {
            /*LabelScript.Text = "<script type=\"text/javascript\" language=\"javascript\">";
            LabelScript.Text += "parent.parentframes['devmain'].location.href=";
            LabelScript.Text += "'Workflow_Step_Edit.aspx?workflowstepid=" + workflowstepid.ToString() + "'";
            LabelScript.Text += "</script>";*/
            Response.Redirect("Workflow_Step_Edit.aspx?workflowstepid=" + workflowstepid.ToString());
        }

        else if (actionName == "delete")
        {
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.administration", "Delete"))
            {
                RedirectToAccessDenied("cms.administration", "Delete");
            }

            // Check if documents use the workflow
            WorkflowStepInfo si = WorkflowInfoProvider.GetWorkflowStepInfo(workflowstepid);
            if (si != null)
            {
                switch (si.StepName.ToLower())
                {
                    case "edit":
                    case "published":
                        // Delete the workflow step
                        WorkflowInfoProvider.DeleteWorkflowStepInfo(workflowstepid);
                        break;

                    default:
                        string where = "DocumentWorkflowStepID = " + workflowstepid.ToString();

                        TreeProvider tree = new TreeProvider();
                        DataSet ds = tree.SelectNodes(TreeProvider.ALL_SITES, "/%", TreeProvider.ALL_CULTURES, false, null, where, "SiteName, NodeAliasPath", -1, false);
                        if (!DataHelper.DataSourceIsEmpty(ds))
                        {
                            this.lblError.Text = ResHelper.GetString("Workflow.CannotDeleteStepUsed") + "<br />";
                            this.lblError.Visible = true;

                            int index = 0;
                            foreach (DataRow dr in ds.Tables[0].Rows)
                            {
                                if (index > 10)
                                {
                                    this.lblError.Text += "<br />&nbsp;...";
                                    break;
                                }
                                this.lblError.Text += "<br />&nbsp;" + dr["SiteName"] + " - " + dr["DocumentNamePath"];
                                index++;
                            }
                        }
                        else
                        {
                            // Delete the workflow step
                            WorkflowInfoProvider.DeleteWorkflowStepInfo(workflowstepid);
                        }
                        break;
                }
            }
        }

        else if (actionName == "moveup")
        {
            WorkflowInfoProvider.MoveStepUp(WorkflowInfoProvider.GetWorkflowStepInfo(workflowstepid));
        }

        else if (actionName == "movedown")
        {
            WorkflowInfoProvider.MoveStepDown(WorkflowInfoProvider.GetWorkflowStepInfo(workflowstepid));
        }

        this.UniGridWorkflowSteps.ReloadData();
    }
}
