using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.Forums;

public partial class CMSWebParts_Forum_ForumSearchResults : CMSAbstractWebPart
{
    private string searchText = "";
    private string selectedGroups = "";
    private bool mAuthneticated = true;
    private Hashtable allowedGroups = null;
    private string mNoResults = "";

    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }

    #region "Public properties"

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("EnableSubscription"), this.ForumFlatView1.EnableSubscription);
        }
        set
        {
            this.SetValue("EnableSubscription", value);
            this.ForumFlatView1.EnableSubscription = value;
        }
    }

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("EnablePicture"), this.ForumFlatView1.EnablePicture); }
        set
        {
            this.SetValue("EnablePicture", value);
            this.ForumFlatView1.EnablePicture = ValidationHelper.GetBoolean(value, this.ForumFlatView1.EnablePicture);
        }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxImageWidth"), this.ForumFlatView1.MaxPictureWidth); }
        set
        {
            this.SetValue("MaxImageWidth", value);
            this.ForumFlatView1.MaxPictureWidth = ValidationHelper.GetInteger(value, this.ForumFlatView1.MaxPictureWidth);
        }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxImageHeight"), this.ForumFlatView1.MaxPictureHeight); }
        set
        {
            this.SetValue("MaxImageHeight", value);
            this.ForumFlatView1.MaxPictureHeight = ValidationHelper.GetInteger(value, this.ForumFlatView1.MaxPictureHeight);
        }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("EnableSignature"), this.ForumFlatView1.EnableSignature); }
        set
        {
            this.SetValue("EnableSignature", value);
            this.ForumFlatView1.EnableSignature = ValidationHelper.GetBoolean(value, this.ForumFlatView1.EnableSignature);
        }
    }

    /// <summary>
    /// Selected groups where is search enabled, if empty => search in all avaliable groups.
    /// </summary>
    public string Groups
    {
        get { return DataHelper.GetNotEmpty(this.GetValue("Groups"), "").Trim(); }
        set
        {
            this.SetValue("Groups", value);
            selectedGroups = value;
        }
    }
    

    /// <summary>
    /// Thread query string property.
    /// </summary>
    public string ThreadQueryString
    {
        get { return DataHelper.GetNotEmpty(this.GetValue("ThreadQueryString"), "SearchThread").Trim(); }
        set
        {
            this.SetValue("ThreadQueryString", value);
            ForumFlatView1.mForumProperties.QueryStringThread = DataHelper.GetNotEmpty(value, "SearchThread").Trim();
        }
    }

    /// <summary>
    /// Forum query string property.
    /// </summary>
    public string ForumQueryString
    {
        get { return DataHelper.GetNotEmpty(this.GetValue("ForumQueryString"), "SearchForumID").Trim(); }
        set
        {
            this.SetValue("ForumQueryString", value);
            ForumFlatView1.mForumProperties.QueryStringForumID = DataHelper.GetNotEmpty(value, "SearchForumID").Trim();
        }
    }

    /// <summary>
    /// Non authenticated user can read, is useable only if permissions of forum are set.
    /// </summary>
    public bool AnonymousRead
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("AnonymousRead"), true); }
        set
        {
            this.SetValue("AnonymousRead", value);
            mAuthneticated = value;
        }
    }

    /// <summary>
    /// Message to be displayed when no results have been found
    /// </summary>
    public string NoResults
    {
        get { return ValidationHelper.GetString(this.GetValue("NoResults"), this.mNoResults); }
        set
        {
            this.SetValue("NoResults", value);
            this.mNoResults = value;
        }
    }

    #endregion

    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.ForumFlatView1.StopProcessing = true;  // Do nothing
        }
        else
        {

            // Get selected groups
            selectedGroups = this.Groups;
            ForumFlatView1.mForumProperties.QueryStringThread = this.ThreadQueryString;
            ForumFlatView1.mForumProperties.QueryStringForumID = this.ForumQueryString;
            mAuthneticated = this.AnonymousRead;

            this.ForumFlatView1.EnablePicture = this.EnablePicture;
            this.ForumFlatView1.EnableSignature = this.EnableSignature;
            this.ForumFlatView1.MaxPictureHeight = this.MaxPictureHeight;
            this.ForumFlatView1.MaxPictureWidth = this.MaxPictureWidth;

            this.ForumFlatView1.EnableSubscription = this.EnableSubscription;

            // Get search word from query string
            if (ValidationHelper.GetString(Request.QueryString["SearchForum"], "") != "")
            {
                searchText = ValidationHelper.GetString(Request.QueryString["SearchForum"], "");
            }

            //If is search text defined
            if (searchText != null && searchText.Trim() != "")
            {

                // Show detail
                if (ValidationHelper.GetString(Request.QueryString[ForumFlatView1.mForumProperties.QueryStringThread], "") != "")
                {
                    pnlFlat.Visible = false;
                    ForumFlatView1.Visible = true;
                    ForumFlatView1.SearchResults = true;
                    ForumFlatView1.NoAuthenticatedRead = mAuthneticated;

                    ForumFlatView1.mForumProperties.IsSearchResult = true;
                }
                else
                {
                    ForumFlatView1.StopProcessing = true;

                    dtgSearchResults.ItemDataBound += new DataGridItemEventHandler(dtgSearchResults_ItemDataBound);

                    // Get all groups
                    DataSet groupSet = ForumGroupInfoProvider.GetAllGroups();
                    // DataSet where will be search results
                    DataSet finalData = null;

                    if (!DataHelper.DataSourceIsEmpty(groupSet))
                    {

                        // Set groups to hash table for check it
                        if (selectedGroups != "")
                        {
                            string[] groupNames = selectedGroups.Split(';');
                            if (groupNames != null)
                            {
                                for (int j = 0; j < groupNames.Length; j++)
                                {
                                    if (ValidationHelper.GetString(groupNames[j], "").Trim() != "")
                                    {
                                        if (allowedGroups == null)
                                        {
                                            allowedGroups = new Hashtable();
                                        }

                                        allowedGroups[groupNames[j].ToLower()] = "group";
                                    }
                                }

                            }
                        }


                        // Get all forums
                        DataSet forumsDataSet = ForumInfoProvider.GetAllForums();

                        foreach (DataRow gDr in groupSet.Tables[0].Rows)
                        {
                            if (ValidationHelper.GetInteger(gDr["GroupSiteID"], 0) == CMSContext.CurrentSite.SiteID)
                            {
                                // if group is selected allowed = true
                                bool allowed = true;

                                // Selection
                                if (allowedGroups != null)
                                {
                                    if (allowedGroups[ValidationHelper.GetString(gDr["GroupName"], "").ToLower()] == null)
                                    {
                                        allowed = false;
                                    }
                                }


                                if ((!DataHelper.DataSourceIsEmpty(forumsDataSet)) && (allowed))
                                {
                                    foreach (DataRow fDr in forumsDataSet.Tables[0].Rows)
                                    {
                                        // Check if actaul forum is in actual group
                                        if (ValidationHelper.GetInteger(fDr["ForumGroupID"], 0) == ValidationHelper.GetInteger(gDr["GroupID"], 0))
                                        {

                                            // Access rights, for forum access or non authenticated user can read
                                            ForumProperties fp = new ForumProperties();
                                            if (fp.CheckPermission(ValidationHelper.GetInteger(fDr["ForumID"], 0)) || (mAuthneticated))
                                            {
                                                string mWhere = "(PostSubject LIKE '%" + searchText + "%')OR(PostText LIKE '%" + searchText + "%')";

                                                // Search posts Posts
                                                DataSet dsPosts = ForumPostInfoProvider.SelectForumPosts(ValidationHelper.GetInteger(fDr["ForumID"], 0), "/%", mWhere, "PostTime DESC", -1, true);

                                                if (!DataHelper.DataSourceIsEmpty(dsPosts))
                                                {
                                                    // Create final table if doesn't exists
                                                    if (finalData == null)
                                                    {
                                                        finalData = new DataSet();
                                                        finalData = dsPosts.Copy();
                                                        finalData.Tables[0].Rows.Clear();
                                                        finalData.AcceptChanges();
                                                    }

                                                    // Add posts to DataSet final DataSet
                                                    if (!DataHelper.DataSourceIsEmpty(dsPosts))
                                                    {
                                                        foreach (DataRow finalDr in dsPosts.Tables[0].Rows)
                                                        {
                                                            finalData.Tables[0].Rows.Add(finalDr.ItemArray);
                                                            finalData.AcceptChanges();
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        // Add to DataGrid
                        if (!DataHelper.DataSourceIsEmpty(finalData))
                        {
                            dtgSearchResults.DataSource = finalData;
                            dtgSearchResults.AllowPaging = true;
                            dtgSearchResults.Enabled = true;
                            dtgSearchResults.PageIndexChanged += new DataGridPageChangedEventHandler(dtgSearchResults_PageIndexChanged);
                            dtgSearchResults.DataBind();
                        }
                        else
                        {
                            lblNoResults.Visible = true;
                            lblNoResults.Text = this.NoResults;
                        }

                    }
                }
            }
        }
    }

    void dtgSearchResults_PageIndexChanged(object source, DataGridPageChangedEventArgs e)
    {
        dtgSearchResults.CurrentPageIndex = e.NewPageIndex;
        dtgSearchResults.DataBind();
    }


    /// <summary>
    /// Item databound
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void dtgSearchResults_ItemDataBound(object sender, DataGridItemEventArgs e)
    {
        ForumPostControl mForumPost = (ForumPostControl)this.LoadControl("~/CMSForum/ForumPost.ascx");

        string mAliasPath = "";

        mForumPost.EnableSubscription = false;
        mForumPost.AllowReply = false;

        if (e.Item.DataItem != null)
        {
            mForumPost.PostSrcDataRow = ((DataRowView)e.Item.DataItem).Row;
        }

        string link = "";
        if (!DataHelper.DataSourceIsEmpty(mForumPost.PostSrcDataRow))
        {
            string threadId = GetRootParent(ValidationHelper.GetString(mForumPost.PostSrcDataRow["PostIDPath"], "")).TrimStart('/');

            string query = HttpContext.Current.Request.Url.Query;
            string url = HttpContext.Current.Request.RawUrl;
            if (url.Contains("?"))
            {
                url = url.Remove(url.IndexOf('?'));
            }


            if (ValidationHelper.GetString(Request.QueryString["AliasPath"], "") != "")
            {
                mAliasPath = ValidationHelper.GetString(Request.QueryString["AliasPath"], "");
            }

            if (mAliasPath != "")
            {
                url = ResolveUrl(CMSContext.GetUrl(mAliasPath));
            }


            query = UrlHelper.RemoveUrlParameter(query, "AliasPath");
            query = UrlHelper.RemoveUrlParameter(query, ForumFlatView1.mForumProperties.QueryStringThread);
            query = UrlHelper.AddUrlParameter(query, ForumFlatView1.mForumProperties.QueryStringThread, threadId);

            query = UrlHelper.AddUrlParameter(query, ForumFlatView1.mForumProperties.QueryStringForumID, ValidationHelper.GetString(mForumPost.PostSrcDataRow["PostForumID"], ""));


            link = url + query;

        }

        Literal div = new Literal();
        div.Text = "<div class=\"Result\"><div class=\"ResultThread\">" +
        "<a href=\"" + link + "\">" + ResHelper.GetString("ForumSearchResults.ViewThread") + "</a>";
        e.Item.Cells[0].Controls.Add(div);
        e.Item.Cells[0].Controls.Add(mForumPost);
        Literal div2 = new Literal();
        div2.Text = "</div></div>";
        e.Item.Cells[0].Controls.Add(div2);

    }

    /// <summary>
    /// Return root thread path
    /// </summary>
    /// <param name="mPath"></param>
    /// <returns></returns>
    public string GetRootParent(string mPath)
    {
        if ((mPath == null) || (mPath.Trim() == ""))
        {
            return "";
        }

        return mPath.Substring(0, 9);
    }
}
