using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.Forums;

public partial class CMSWebParts_Forum_ForumTree : CMSAbstractWebPart
{
    private string mForumName = "";


    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("EnableImages"), this.ForumTreeView1.EnablePicture); }
        set
        {
            this.SetValue("EnableImages", value);
            this.ForumTreeView1.EnablePicture = ValidationHelper.GetBoolean(value, this.ForumTreeView1.EnablePicture);
        }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxImageWidth"), this.ForumTreeView1.MaxPictureWidth); }
        set
        {
            this.SetValue("MaxImageWidth", value);
            this.ForumTreeView1.MaxPictureWidth = ValidationHelper.GetInteger(value, this.ForumTreeView1.MaxPictureWidth);
        }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxImageHeight"), this.ForumTreeView1.MaxPictureHeight); }
        set
        {
            this.SetValue("MaxImageHeight", value);
            this.ForumTreeView1.MaxPictureHeight = ValidationHelper.GetInteger(value, this.ForumTreeView1.MaxPictureHeight);
        }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("EnableSignature"), this.ForumTreeView1.EnableSignature); }
        set
        {
            this.SetValue("EnableSignature", value);
            this.ForumTreeView1.EnableSignature = ValidationHelper.GetBoolean(value, this.ForumTreeView1.EnableSignature);
        }
    }


    /// <summary>
    /// Maximal relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("MaxRelativeLevel"), this.ForumTreeView1.MaxRelativeLevel);
        }
        set
        {
            this.SetValue("MaxRelativeLevel", value);
            this.ForumTreeView1.MaxRelativeLevel = value;
        }
    }


    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WhereCondition"), this.ForumTreeView1.WhereCondition);
        }
        set
        {
            this.SetValue("WhereCondition", value);
            this.ForumTreeView1.WhereCondition = value;
        }
    }


    /// <summary>
    /// Forum name
    /// </summary>
    public string ForumName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ForumName"), this.mForumName);
        }
        set
        {
            this.SetValue("ForumName", value);
            this.mForumName = value;
        }
    }


    /// <summary>
    /// True if should be selected only approved posts
    /// </summary>
    public bool SelectOnlyApproved
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("SelectOnlyApproved"), this.ForumTreeView1.SelectOnlyApproved);
        }
        set
        {
            this.SetValue("SelectOnlyApproved", value);
            this.ForumTreeView1.SelectOnlyApproved = value;
        }
    }


    /// <summary>
    /// Starting path simillar to alias path (to be able to display only part of the thread)
    /// </summary>
    public string PostPath
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("PostPath"), this.ForumTreeView1.PostPath);
        }
        set
        {
            this.SetValue("PostPath", value);
            this.ForumTreeView1.PostPath = value;
        }
    }


    /// <summary>
    /// Show mode
    /// </summary>
    public ShowModeEnum ShowMode
    {
        get
        {
            return ForumModes.GetShowMode(ValidationHelper.GetString(this.GetValue("ShowMode"), this.ForumTreeView1.ShowMode.ToString()));
        }
        set
        {
            this.SetValue("ShowMode", value);
            this.ForumTreeView1.ShowMode = value;
        }
    }


    /// <summary>
    /// True if the permissions should be checked
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), this.ForumTreeView1.CheckPermissions);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
            this.ForumTreeView1.CheckPermissions = value;
        }
    }


    /// <summary>
    /// True if the subscription should be enabled
    /// </summary>
    public bool EnableSubscription
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("EnableSubscription"), this.ForumTreeView1.EnableSubscription);
        }
        set
        {
            this.SetValue("EnableSubscription", value);
            this.ForumTreeView1.EnableSubscription = value;
        }
    }


    /// <summary>
    /// If true, only authenticated users should read the forum
    /// </summary>
    public bool AnonymousRead
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("AnonymousRead"), this.ForumTreeView1.NoAuthenticatedRead);
        }
        set
        {
            this.SetValue("AnonymousRead", value);
            this.ForumTreeView1.NoAuthenticatedRead = value;
        }
    }


    /// <summary>
    /// True if the tree should be expanded
    /// </summary>
    public bool ExpandTree
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ExpandTree"), this.ForumTreeView1.ExpandTree);
        }
        set
        {
            this.SetValue("ExpandTree", value);
            this.ForumTreeView1.ExpandTree = value;
        }
    }


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.ForumTreeView1.StopProcessing = true;  // Do nothing
        }
        else
        {
            if (CMSContext.CurrentSite != null)
            {
                ForumInfo fi = ForumInfoProvider.GetForumInfo(this.ForumName, CMSContext.CurrentSite.SiteID);

                if (fi != null)
                {
                    this.ForumTreeView1.ForumID = fi.ForumID;
                    this.ForumTreeView1.ExpandTree = this.ExpandTree;
                }
                else
                {
                    this.ForumTreeView1.AdHocForum = true;
                }
            }

            this.ForumTreeView1.MaxRelativeLevel = this.MaxRelativeLevel;
            this.ForumTreeView1.WhereCondition = this.WhereCondition;
            this.ForumTreeView1.SelectOnlyApproved = this.SelectOnlyApproved;
            this.ForumTreeView1.PostPath = this.PostPath;
            this.ForumTreeView1.ShowMode = this.ShowMode;

            this.ForumTreeView1.EnableSubscription = this.EnableSubscription;
            this.ForumTreeView1.CheckPermissions = this.CheckPermissions;

            this.ForumTreeView1.NoAuthenticatedRead = this.AnonymousRead;

            this.ForumTreeView1.EnablePicture = this.EnablePicture;
            this.ForumTreeView1.EnableSignature = this.EnableSignature;
            this.ForumTreeView1.MaxPictureWidth = this.MaxPictureWidth;
            this.ForumTreeView1.MaxPictureHeight = this.MaxPictureHeight;
        }
    }
}
