using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.DirectoryUtilities;
using CMS.FileManager;

public partial class CMSWebParts_Membership_MyProfile : CMSAbstractWebPart
{
    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }

    /// <summary>
    /// Max picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxPictureWidth"), 0); }
        set
        {
            this.SetValue("MaxPictureWidth", value);
            UserPicture1.Width = ValidationHelper.GetInteger(value, 0);
        }
    }

    public int MaxPictureHeight
    {
        get { return ValidationHelper.GetInteger(this.GetValue("MaxPictureHeight"), 0); }
        set
        {
            this.SetValue("MaxPictureHeight", value);
            UserPicture1.Height = ValidationHelper.GetInteger(value, 0);
        }
    }

    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            // Do not process
            rfvEmail.Enabled = false;
            rfvFirstName.Enabled = false;
            rfvLastName.Enabled = false;
        }
        else
        {
            lblFirstName.Text = ResHelper.GetString("MyProfile.FirstName");
            rfvFirstName.ErrorMessage = ResHelper.GetString("MyProfile.FirstNameError");
            lblLastName.Text = ResHelper.GetString("MyProfile.LastName");
            rfvLastName.ErrorMessage = ResHelper.GetString("MyProfile.LastNameError");
            lblEmail.Text = ResHelper.GetString("MyProfile.Email");
            rfvEmail.ErrorMessage = ResHelper.GetString("MyProfile.EmailError");
            lblLanguage.Text = ResHelper.GetString("MyProfile.Language");
            btnOK.Text = ResHelper.GetString("MyProfile.btnOK");
            lblNickName.Text = ResHelper.GetString("MyProfile.NickName");
            lblUserPicture.Text = ResHelper.GetString("MyProfile.UserPicture");
            lblUserSignature.Text = ResHelper.GetString("MyProfile.UserSignature");

            this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "PictDelConfirm", ScriptHelper.GetScript("" +
                "function DeleteConfirmation(){ return confirm('" + ResHelper.GetString("MyProfile.PictDeleteConfirm") + "');}"));

            btnDeleteImage.ImageUrl = ResolveUrl("~/App_Themes/Default/Images/Controls/Uploader/delete.gif");
            btnDeleteImage.OnClientClick = "return DeleteConfirmation();";

            rfvEmail.ValidationExpression = @"\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*";

            // get UserInfo
            UserInfo ui = null;
            if (CMSContext.CurrentUser != null)
            {
                ui = UserInfoProvider.GetUserInfo(CMSContext.CurrentUser.UserName);
            }



            if (ui != null)
            {
                if (!IsPostBack)
                {
                    // fill textboxes
                    txtFirstName.Text = ui.FirstName;
                    txtLastName.Text = ui.LastName;
                    txtEmail.Text = ui.Email;
                    txtNickName.Text = ui.UserNickName;
                    txtUserSignature.Text = ui.UserSignature;
                }

                SetUserPictureArea(ui);

                if (drpLanguages.Items.Count == 0)
                {
                    ListItem li = null;

                    // fill drop down list
                    if (CMSContext.CurrentSite != null)
                    {
                        DataSet ds = CultureInfoProvider.GetSiteCultures(CMSContext.CurrentSite.SiteName);
                        if (!DataHelper.DataSourceIsEmpty(ds))
                        {
                            foreach (DataRow dr in ds.Tables[0].Rows)
                            {
                                li = new ListItem(dr["CultureName"].ToString(), dr["CultureCode"].ToString());
                                drpLanguages.Items.Add(li);
                            }
                        }
                    }
                    // select preferred culture from drop down list
                    li = drpLanguages.Items.FindByValue(ui.PreferredCultureCode);
                    if (li != null)
                    {
                        li.Selected = true;
                    }
                }
            }
        }
    }

    protected void SetUserPictureArea(UserInfo ui)
    {
        if (ui.UserPicture != "")
        {
            plcImageActions.Visible = true;
            UserPicture1.UserID = ui.UserID;
            UserPicture1.Width = this.MaxPictureWidth;
            UserPicture1.Height = this.MaxPictureHeight;
        }
    }

    protected void DeleteImage_Click(object sender, EventArgs e)
    {
        UserInfo ui = UserInfoProvider.GetUserInfo(CMSContext.CurrentUser.UserID);
        if (ui != null)
        {

            try
            {
                // Remove from HDD
                string mDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");
                string filename = ui.UserPicture.Remove(ui.UserPicture.IndexOf('/'));
                if (File.Exists(mDirectory + filename))
                {
                    File.Delete(mDirectory + filename);
                }
            }
            catch
            {
            }


            ui.UserPicture = "";
            UserInfoProvider.SetUserInfo(ui);
            CMSContext.CurrentUser.UserPicture = "";

            plcImageActions.Visible = false;
        }
    }

    protected void btnOK_Click(object sender, EventArgs e)
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            // Do not process
        }
        else
        {
            string result = new Validator().NotEmpty(txtFirstName.Text, rfvFirstName.ErrorMessage).NotEmpty(txtLastName.Text, rfvLastName.ErrorMessage).Result;
            if (result == "")
            {
                if (CMSContext.CurrentUser != null)
                {
                    UserInfo ui = UserInfoProvider.GetUserInfo(CMSContext.CurrentUser.UserName);
                    if (ui != null)
                    {

                        if (uplFilePicture.HasFile)
                        {
                            try
                            {


                                string mgui = Guid.NewGuid().ToString();
                                string extension = "";
                                if (uplFilePicture.FileName.Contains("."))
                                {
                                    extension = uplFilePicture.FileName.Remove(0, uplFilePicture.FileName.LastIndexOf('.') + 1);
                                }

                                if (ImageHelper.IsImage(extension))
                                {

                                    string mGuid = Guid.NewGuid().ToString();

                                    // Remove old picture
                                    if (ui.UserPicture != "")
                                    {
                                        try
                                        {
                                            // Remove from HDD
                                            string jDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");
                                            string filename = ui.UserPicture.Remove(ui.UserPicture.IndexOf('/'));
                                            if (File.Exists(jDirectory + filename))
                                            {
                                                File.Delete(jDirectory + filename);
                                            }
                                        }
                                        catch
                                        {
                                        }

                                        ui.UserPicture = "";
                                        UserInfoProvider.SetUserInfo(ui);
                                        CMSContext.CurrentUser.UserPicture = "";
                                    }

                                    string name = mGuid + "." + extension + "/" + uplFilePicture.FileName;

                                    string mDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");

                                    if (!Directory.Exists(mDirectory))
                                    {
                                        DirectoryHelper.CreateDirectory(mDirectory);
                                    }

                                    uplFilePicture.SaveAs(mDirectory + mGuid + "." + extension);

                                    ui.UserPicture = name;
                                    CMSContext.CurrentUser.UserPicture = name;
                                }
                                else
                                {
                                    lblPictureError.Visible = true;
                                    lblPictureError.Text = ResHelper.GetString("User.UserPictureExtensionError");
                                }
                            }
                            catch
                            {
                            }


                        }

                        // update user info
                        ui.FirstName = txtFirstName.Text.Trim();
                        ui.LastName = txtLastName.Text.Trim();
                        ui.FullName = ui.FirstName + " " + ui.LastName;
                        ui.Email = txtEmail.Text;
                        ui.UserNickName = txtNickName.Text.Trim();
                        ui.PreferredCultureCode = drpLanguages.SelectedValue;
                        ui.UserSignature = txtUserSignature.Text;
                        UserInfoProvider.SetUserInfo(ui);
                        CMSContext.CurrentUser.UserNickName = ui.UserNickName;
                        CMSContext.CurrentUser.UserSignature = ui.UserSignature;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                        lblInfo.Visible = true;

                        SetUserPictureArea(ui);
                    }
                }
            }
        }

    }
}
