using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.ISearchEngine;
using CMS.Controls;
using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;

public partial class CMSWebParts_Search_cmscompletesearchdialog : CMSAbstractWebPart
{
    #region "Search dialog properties"

    /// <summary>
    /// Label search for text
    /// </summary>
    public string SearchForLabel
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchForLabel"), ResHelper.LocalizeString("{$CMSSearchDialog.SearchFor$}"));
        }
        set
        {
            this.SetValue("SearchForLabel", value);
            this.srchDialog.SearchForLabel.Text = value;
        }
    }


    /// <summary>
    /// Indicates if search mode settings should be displayed.
    /// </summary>
    public bool ShowSearchMode
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowSearchMode"), this.srchDialog.ShowSearchMode);
        }
        set
        {
            this.SetValue("ShowSearchMode", value);
            this.srchDialog.ShowSearchMode = value;
        }
    }


    /// <summary>
    /// Search button text
    /// </summary>
    public string SearchButtonText
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchButtonText"), ResHelper.LocalizeString("{$CMSSearchDialog.Go$}"));
        }
        set
        {
            this.SetValue("SearchButtonText", value);
            this.srchDialog.SearchButton.Text = value;
        }
    }


    /// <summary>
    ///  Search mode
    /// </summary>
    public SearchModeEnum SearchMode
    {
        get
        {
            return srchDialog.GetSearchMode(DataHelper.GetNotEmpty(this.GetValue("SearchMode"), this.srchDialog.SearchMode.ToString()));
        }
        set
        {
            this.SetValue("SearchMode", value.ToString());
            this.srchDialog.SearchMode = value;
        }
    }


    /// <summary>
    /// Search mode label
    /// </summary>
    public string SearchModeLabel
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchModeLabel"), ResHelper.LocalizeString("{$CMSSearchDialog.SearchMode$}"));
        }
        set
        {
            this.SetValue("SearchModeLabel", value);
            this.srchDialog.SearchModeLabel.Text = value;
        }
    }


    /// <summary>
    /// Show search scope
    /// </summary>
    public bool ShowSearchScope
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowSearchScope"), this.srchDialog.ShowSearchScope);
        }
        set
        {
            this.SetValue("ShowSearchScope", value);
            this.srchDialog.ShowSearchScope = value;
        }
    }


    /// <summary>
    /// Search scope
    /// </summary>
    public SearchScopeEnum SearchScope
    {
        get
        {
            return srchDialog.GetSearchScope(DataHelper.GetNotEmpty(this.GetValue("SearchScope"), this.srchDialog.SearchScope.ToString()));
        }
        set
        {
            this.SetValue("SearchScope", value.ToString());
            this.srchDialog.SearchScope = value;
        }
    }


    /// <summary>
    /// Search scope label
    /// </summary>
    public string SearchScopeLabel
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchScopeLabel"), ResHelper.LocalizeString("{$CMSSearchDialog.SearchScope$}"));
        }
        set
        {
            this.SetValue("SearchScopeLabel", value);
            this.srchDialog.SearchScopeLabel.Text = value;
        }
    }


    /// <summary>
    /// Skin ID
    /// </summary>
    public override string SkinID
    {
        get
        {
            return base.SkinID;
        }
        set
        {
            base.SkinID = value;
            this.srchDialog.SkinID = value;
        }
    }

    #endregion


    #region "Document properties"


    /// <summary>
    /// Cache minutes
    /// </summary>
    public override int CacheMinutes
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("CacheMinutes"), this.srchResults.CacheMinutes);
        }
        set
        {
            this.SetValue("CacheMinutes", value);
            this.srchResults.CacheMinutes = value;
        }
    }


    /// <summary>
    /// Check permissions
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), this.srchResults.CheckPermissions);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
        }
    }


    /// <summary>
    /// Class names
    /// </summary>
    public string ClassNames
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("Classnames"), this.srchResults.ClassNames), this.srchResults.ClassNames);
        }
        set
        {
            this.SetValue("ClassNames", value);
            this.srchResults.ClassNames = value;
        }
    }


    /// <summary>
    /// Combine with default culture
    /// </summary>
    public bool CombineWithDefaultCulture
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CombineWithDefaultCulture"), this.srchResults.CombineWithDefaultCulture);
        }
        set
        {
            this.SetValue("CombineWithDefaultCulture", value);
            this.srchResults.CombineWithDefaultCulture = value;
        }
    }


    /// <summary>
    /// Culture code
    /// </summary>
    public string CultureCode
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("CultureCode"), this.srchResults.CultureCode), this.srchResults.CultureCode);
        }
        set
        {
            this.SetValue("CultureCode", value);
            this.srchResults.CultureCode = value;
        }
    }


    /// <summary>
    /// Maximal relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("MaxRelativeLevel"), this.srchResults.MaxRelativeLevel);
        }
        set
        {
            this.SetValue("MaxRelativeLevel", value);
            this.srchResults.MaxRelativeLevel = value;
        }
    }


    /// <summary>
    /// Nodes path 
    /// </summary>
    public string Path
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("Path"), this.srchResults.Path), this.srchResults.Path);
        }
        set
        {
            this.SetValue("Path", value);
            this.srchResults.Path = value;
        }
    }


    /// <summary>
    /// Select only published nodes
    /// </summary>
    public bool SelectOnlyPublished
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("SelectOnlyPublished"), this.srchResults.SelectOnlyPublished);
        }
        set
        {
            this.SetValue("SelctOnlyPublished", value);
            this.srchResults.SelectOnlyPublished = value;
        }
    }


    /// <summary>
    /// Site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("SiteName"), this.srchResults.SiteName), this.srchResults.SiteName);
        }
        set
        {
            this.SetValue("SiteName", value);
            this.srchResults.SiteName = value;
        }
    }

    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("WhereCondition"), this.srchResults.WhereCondition), this.srchResults.WhereCondition);
        }
        set
        {
            this.SetValue("WhereCondition", value);
            this.srchResults.WhereCondition = value;
        }
    }

    /// <summary>
    /// Order by
    /// </summary>
    public string OrderBy
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("OrderBy"), this.srchResults.OrderBy), this.srchResults.OrderBy);
        }
        set
        {
            this.SetValue("OrderBy", value);
            this.srchResults.OrderBy = value;
        }
    }

    #endregion


    #region "Pager properties"

    /// <summary>
    /// Pager position
    /// </summary>
    public PagingPlaceTypeEnum PagerPosition
    {
        get
        {
            return this.srchResults.PagerControl.GetPagerPosition(DataHelper.GetNotEmpty(this.GetValue("PagerPosition"), this.srchResults.PagerControl.PagerPosition.ToString()));
        }
        set
        {
            this.SetValue("PagerPosition", value.ToString());
            this.srchResults.PagerControl.PagerPosition = value;
        }
    }


    /// <summary>
    /// Page size
    /// </summary>
    public int PageSize
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("PageSize"), this.srchResults.PagerControl.PageSize);
        }
        set
        {
            this.SetValue("PageSize", value);
            this.srchResults.PagerControl.PageSize = value;
        }
    }


    /// <summary>
    /// Pager query string key
    /// </summary>
    public string QueryStringKey
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("QueryStringKey"), this.srchResults.PagerControl.QueryStringKey), this.srchResults.PagerControl.QueryStringKey);
        }
        set
        {
            this.SetValue("QueryStringKey", value);
            this.srchResults.PagerControl.QueryStringKey = value;
        }
    }


    /// <summary>
    /// Paging mode
    /// </summary>
    public PagingModeTypeEnum PagingMode
    {
        get
        {
            return this.srchResults.PagerControl.GetPagingMode(DataHelper.GetNotEmpty(this.GetValue("PagingMode"), this.srchResults.PagerControl.PagingMode.ToString()));
        }
        set
        {
            this.SetValue("PagingMode", value.ToString());
            this.srchResults.PagerControl.PagingMode = value;
        }
    }


    /// <summary>
    /// Show first / last links
    /// </summary>
    public bool ShowFirstLast
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowFirstLast"), this.srchResults.PagerControl.ShowFirstLast);
        }
        set
        {
            this.SetValue("ShowFirstLast", value);
            this.srchResults.PagerControl.ShowFirstLast = value;
        }
    }

    #endregion


    #region "Public properties"

    /// <summary>
    /// Transformation name
    /// </summary>
    public string TransformationName
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("TransformationName"), this.srchResults.TransformationName), this.srchResults.TransformationName);
        }
        set
        {
            this.SetValue("TransformationName", value);
            this.srchResults.TransformationName = value;
        }
    }


    /// <summary>
    /// No results label
    /// </summary>
    public string NoResultsLabel
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("NoResults"), ResHelper.LocalizeString("{$CMSSearchResults.NoDocumentFound$}"));
        }
        set
        {
            this.SetValue("NoResults", value);
            this.srchResults.NoResultsLabel.Text = value;
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }

    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == CMS.CMSHelper.ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.srchDialog.StopProcessing = true;
            this.srchResults.StopProcessing = true;
        }
        else
        {
            //Search dialog
            this.srchDialog.ID = this.ID + "_CMSSearchDialog";

            this.srchDialog.SearchForLabel.Text = this.SearchForLabel;
            this.srchDialog.SearchButton.Text = this.SearchButtonText;

            this.srchDialog.ShowSearchMode = this.ShowSearchMode;
            this.srchDialog.SearchMode = this.SearchMode;
            this.srchDialog.SearchModeLabel.Text = this.SearchModeLabel;

            this.srchDialog.ShowSearchScope = this.ShowSearchScope;
            this.srchDialog.SearchScope = this.SearchScope;
            this.srchDialog.SearchScopeLabel.Text = this.SearchScopeLabel;

            // Set SkinID property
            if (!this.StandAlone && (this.PageCycle < PageCycleEnum.Loaded))
            {
                this.srchDialog.SkinID = this.SkinID;
                this.srchResults.SkinID = this.SkinID;
            }


            // Document properties
            this.srchResults.CacheItemName = this.CacheItemName;
            this.srchResults.CacheMinutes = this.CacheMinutes;
            this.srchResults.CheckPermissions = this.CheckPermissions;
            this.srchResults.ClassNames = this.ClassNames;
            this.srchResults.CombineWithDefaultCulture = this.CombineWithDefaultCulture;
            this.srchResults.CultureCode = this.CultureCode;
            this.srchResults.MaxRelativeLevel = this.MaxRelativeLevel;
            this.srchResults.Path = this.Path;
            this.srchResults.SelectOnlyPublished = this.SelectOnlyPublished;
            this.srchResults.SiteName = this.SiteName;

            this.srchResults.CMSSearchDialogID = this.ID + "_CMSSearchDialog";

            this.srchResults.SearchMode = this.SearchMode;
            this.srchResults.TransformationName = this.TransformationName;
            this.srchResults.NoResultsLabel.Text = this.NoResultsLabel;

            // Pager
            this.srchResults.QueryStringKey = this.QueryStringKey;
            this.srchResults.PagerControl.PageSize = this.PageSize;
            this.srchResults.PagerControl.PagerPosition = this.PagerPosition;
            this.srchResults.PagerControl.PagingMode = this.PagingMode;
            this.srchResults.PagerControl.ShowFirstLast = this.ShowFirstLast;

            this.srchResults.WhereCondition = this.WhereCondition;
            this.srchResults.OrderBy = this.OrderBy;
        }

    }

    protected override void OnPreRender(EventArgs e)
    {

        if ((CMSContext.CurrentPageInfo != null) && (!CMSContext.CurrentPageInfo.PageTemplateInfo.IsPortal))
        {

            srchResults.ReloadData(true);

            srchResults.DataBind();
        }

        base.OnPreRender(e);
    }
}
