using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.ComponentModel;
using System.Text.RegularExpressions;
using System.Xml;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.FCKeditorV2;
using CMS.Controls;
using CMS.ExtendedControls;
using CMS.SiteProvider;

public partial class CMSWebParts_Text_editableimage : CMSAbstractEditableWebPart
{
    protected Image imgImage = null;
    protected Label lblTitle = null;
    protected Label lblError = null;
    protected Panel pnlEditor = null;
    protected ImageSelector selPath = null;

    #region "Public properties"

    /// <summary>
    /// Control title which is displayed in the editable mode.
    /// </summary>
    public string ImageTitle
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ImageTitle"), this.ID);
        }
        set
        {
            this.SetValue("ImageTitle", value);
        }
    }


    /// <summary>
    /// Image width
    /// </summary>
    public int ImageWidth
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("ImageWidth"), 0);
        }
        set
        {
            this.SetValue("ImageWidth", value);
        }
    }


    /// <summary>
    /// Image height
    /// </summary>
    public int ImageHeight
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("ImageHeight"), 0);
        }
        set
        {
            this.SetValue("ImageHeight", value);
        }
    }


    /// <summary>
    /// Alternative image text
    /// </summary>
    public string AlternateText
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("AlternateText"), "");
        }
        set
        {
            this.SetValue("AlternateText", value);
        }
    }


    /// <summary>
    /// Display selector text box
    /// </summary>
    public bool DisplaySelectorTextBox
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("DisplaySelectorTextBox"), this.selPath.ImagePathTextBox.Visible);
        }
        set
        {
            this.SetValue("DisplaySelectorTextBox", value);
            SetTextBoxVisibility();
        }
    }

    #endregion

    private void SetTextBoxVisibility()
    {
        if (this.DisplaySelectorTextBox)
        {
            this.selPath.ImagePathTextBox.Attributes.Remove("style");
        }
        else
        {
            this.selPath.ImagePathTextBox.Attributes.Add("style", "display: none;");
        }
    }


    /// <summary>
    /// Constructor
    /// </summary>
    public CMSWebParts_Text_editableimage()
    {
        /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
         {*/
        this.PreRender += new EventHandler(Page_PreRender);
        this.Load += new EventHandler(Page_Load);
        // }
    }


    protected override void CreateChildControls()
    {
        /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
         {*/
        this.Controls.Clear();
        base.CreateChildControls();

        // Create controls by actual page mode
        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:
                // Main editor panel
                this.pnlEditor = new Panel();
                this.pnlEditor.ID = "pnlEditor";
                this.pnlEditor.CssClass = "EditableTextEdit";
                if (this.ImageWidth > 0)
                {
                    this.pnlEditor.Style.Add(HtmlTextWriterStyle.Width, this.ImageWidth.ToString() + "px;");
                    //this.pnlEditor.Width = new Unit(this.DialogWidth); // Causes Invalid cast on Render
                }
                this.Controls.Add(pnlEditor);

                // Title label
                this.lblTitle = new Label();
                this.lblTitle.EnableViewState = false;
                this.lblTitle.CssClass = "EditableTextTitle";
                this.pnlEditor.Controls.Add(this.lblTitle);

                // Error label
                this.lblError = new Label();
                this.lblError.EnableViewState = false;
                this.lblError.CssClass = "EditableTextError";
                this.pnlEditor.Controls.Add(this.lblError);

                // Add image selector
                this.selPath = new ImageSelector();
                this.selPath.ID = "selPath";
                this.selPath.UseImagePath = true;
                this.pnlEditor.Controls.Add(this.selPath);

                SetTextBoxVisibility();

                break;

            default:
                // Display content in non editing modes
                this.imgImage = new Image();
                this.imgImage.ID = "imgImage";
                this.imgImage.EnableViewState = false;
                this.Controls.Add(this.imgImage);
                break;
        }
        //  }
    }


    /// <summary>
    /// Loads the control content
    /// </summary>
    /// <param name="content">Content to load</param>
    public override void LoadContent(string content)
    {
        /*  if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
          {*/

        // Load the properties
        this.EnsureChildControls();

        string path = null;
        // Load the image data
        if ( (content != "") && (content != null) )
        {
            XmlDocument xml = new XmlDocument();
            xml.LoadXml(content);

            XmlNodeList properties = xml.SelectNodes("image/property");
            foreach (XmlNode node in properties)
            {
                if (node.Attributes["name"] != null)
                {
                    switch (node.Attributes["name"].Value.ToLower())
                    {
                        case "imagepath":
                            path = node.InnerText.Trim();
                            break;
                    }
                }
            }
        }

        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:

                if (this.ImageWidth > 0)
                {
                    selPath.ImageWidth = this.ImageWidth;
                }
                if (this.ImageHeight > 0)
                {
                    selPath.ImageHeight = this.ImageHeight;
                }
                this.selPath.Value = path;

                this.lblTitle.Text = this.ImageTitle;

                break;

            default:
                if (this.ImageWidth > 0)
                {
                    path = UrlHelper.AddParameterToUrl(path, "width", this.ImageWidth.ToString());
                }
                if (this.ImageHeight > 0)
                {
                    path = UrlHelper.AddParameterToUrl(path, "height", this.ImageHeight.ToString());
                }
                imgImage.AlternateText = this.AlternateText;

                bool isAuthorized = true;
                bool checkPermissions = ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), false);

                if (checkPermissions)
                {
                    if (this.PageManager.ViewMode == ViewModeEnum.LiveSiteNotAuthorized)
                    {
                        isAuthorized = false;
                    }
                }

                if (isAuthorized)
                {
                    imgImage.ImageUrl = path;
                }
                else
                {
                    imgImage.Visible = false;
                }
                break;
        }
        // }
    }


    /// <summary>
    /// Gets the current control content
    /// </summary>
    public override string GetContent()
    {
        /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
         {*/
        this.EnsureChildControls();

        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:
                XmlDocument xml = new XmlDocument();
                xml.LoadXml("<image></image>");

                // Add path
                XmlNode newNode = xml.CreateElement("property");

                XmlAttribute attr = xml.CreateAttribute("name");
                attr.Value = "imagepath";
                newNode.Attributes.Append(attr);

                newNode.InnerText = this.selPath.Value.Trim();
                xml.DocumentElement.AppendChild(newNode);
                return xml.OuterXml;
        }
        //}

        return null;
    }


    /// <summary>
    /// Load event handler
    /// </summary>
    void Page_Load(object sender, EventArgs e)
    {
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    void Page_PreRender(object sender, EventArgs e)
    {
        /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
         {*/
        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:
                this.lblTitle.Text = this.ImageTitle;
                break;
        }
        // }
    }


    /// <summary>
    /// Renders the control
    /// </summary>
    protected override void Render(HtmlTextWriter writer)
    {
        /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
         {*/
        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:
                writer.Write(this.mPartInstance.ContainerBefore);
                writer.Write(this.mPartInstance.ContentBefore);

                this.pnlEditor.RenderControl(writer);

                writer.Write(this.mPartInstance.ContentAfter);
                writer.Write(this.mPartInstance.ContainerAfter);
                break;

            default:
                base.Render(writer);
                break;
        }
    }
    //}

}
