using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.ComponentModel;
using System.Text.RegularExpressions;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.FCKeditorV2;
using CMS.Controls;
using CMS.ExtendedControls;
using CMS.SiteProvider;

public partial class CMSWebParts_Text_editabletext : CMSAbstractEditableWebPart
{
    protected string mHtmlAreaToolbar = "";
    protected string mHtmlAreaToolbarLocation = "";
    protected bool mShowToolbar = false;

    protected Panel pnlEditor = null;
    protected Label lblError = null;
    protected FCKeditor fckValue = null;
    protected TextBox txtValue = null;
    //protected Label lblTitle = null;

    protected Literal ltlContent = null;


    #region "Public properties"

    /// <summary>
    /// Type of server control which is displayed in the editable region.
    /// </summary>
    [Category("Appearence"), Description("The type of server control which is displayed in the editable region.")]
    public virtual CMSEditableRegionTypeEnum RegionType
    {
        get
        {
            if (ViewState["RegionType"] == null)
            {
                ViewState["RegionType"] = CMSEditableRegionTypeEnum.TextBox;
            }
            return ((CMSEditableRegionTypeEnum)(ViewState["RegionType"]));
        }
        set
        {
            ViewState["RegionType"] = value;
        }
    }


    /// <summary>
    /// HTML editor toolbar set name.
    /// </summary>
    [Category("Appearence"), Description("HTML editor toolbar set name.")]
    public string HtmlToolbarSet
    {
        get
        {
            return ValidationHelper.GetString(ViewState["HtmlToolbarSet"], "");
        }
        set
        {
            ViewState["HtmlToolbarSet"] = value;
        }
    }


    /// <summary>
    /// Control title which is displayed in the editable mode.
    /// </summary>
    [Category("Appearence"), Description("Control title which is displayed in the editable mode.")]
    public string RegionTitle
    {
        get
        {
            if (ViewState["RegionTitle"] == null)
            {
                ViewState["RegionTitle"] = this.ID;
            }
            return System.Convert.ToString(ViewState["RegionTitle"]);
        }
        set
        {
            ViewState["RegionTitle"] = value;
        }
    }


    /// <summary>
    /// Maximum length of the content.
    /// </summary>
    [Category("Behavior"), Description("Maximum length of the content.")]
    public int MaxLength
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["MaxLength"], 0);
        }
        set
        {
            ViewState["MaxLength"] = value;
        }
    }


    /// <summary>
    /// Minimum length of the content.
    /// </summary>
    [Category("Behavior"), Description("Minimum length of the content.")]
    public int MinLength
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["MinLength"], 0);
        }
        set
        {
            ViewState["MinLength"] = value;
        }
    }


    /// <summary>
    /// Height of the control.
    /// </summary>
    [Category("Appearance"), Description("The height of the control.")]
    public int DialogHeight
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["Height"], 0);
        }
        set
        {
            ViewState["Height"] = value;
        }
    }


    /// <summary>
    /// Width of the control.
    /// </summary>
    [Category("Appearance"), Description("The width of the control.")]
    public int DialogWidth
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["Width"], 0);
        }
        set
        {
            ViewState["Width"] = value;
        }
    }


    /// <summary>
    /// Wrap the text if using text area field
    /// </summary>
    [Category("Appearance"), Description("Wrap the text if using text area field.")]
    public bool WordWrap
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["Wrap"], true);
        }
        set
        {
            ViewState["Wrap"] = value;
        }
    }


    /// <summary>
    /// HTML editor toolbar set name
    /// </summary>
    public string HtmlAreaToolbar
    {
        get
        {
            return this.mHtmlAreaToolbar;
        }
        set
        {
            if (value == null)
            {
                this.mHtmlAreaToolbar = "";
            }
            else
            {
                this.mHtmlAreaToolbar = value;
            }
        }
    }


    /// <summary>
    /// HTML editor toolbar location (support since FCKEditor 2.3)
    /// </summary>
    public string HtmlAreaToolbarLocation
    {
        get
        {
            return this.mHtmlAreaToolbarLocation;
        }
        set
        {
            if (value == null)
            {
                this.mHtmlAreaToolbarLocation = "";
            }
            else
            {
                this.mHtmlAreaToolbarLocation = value;
            }
        }
    }

    #endregion


    /// <summary>
    /// Constructor
    /// </summary>
    public CMSWebParts_Text_editabletext()
    {
       /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/
            this.PreRender += new EventHandler(Page_PreRender);
            this.Load += new EventHandler(Page_Load);
       // }
    }


    protected override void CreateChildControls()
    {
       /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/
            this.Controls.Clear();
            base.CreateChildControls();

            // Create controls by actual page mode
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:

                    // Main editor panel
                    this.pnlEditor = new Panel();
                    this.pnlEditor.ID = "pnlEditor";
                    this.pnlEditor.CssClass = "EditableTextEdit";
                    if (this.DialogWidth > 0)
                    {
                        this.pnlEditor.Style.Add(HtmlTextWriterStyle.Width, this.DialogWidth.ToString() + "px;");
                        //this.pnlEditor.Width = new Unit(this.DialogWidth); // Causes Invalid cast on Render
                    }
                    this.Controls.Add(pnlEditor);

                    // Title label
                    this.lblTitle = new Label();
                    this.lblTitle.EnableViewState = false;
                    this.lblTitle.CssClass = "EditableTextTitle";
                    this.pnlEditor.Controls.Add(this.lblTitle);

                    // Error label
                    this.lblError = new Label();
                    this.lblError.EnableViewState = false;
                    this.lblError.CssClass = "EditableTextError";
                    this.pnlEditor.Controls.Add(this.lblError);

                    // Display the region control based on the region type
                    switch (this.RegionType)
                    {
                        case CMSEditableRegionTypeEnum.HtmlEditor:
                            // FCKEditor
                            this.fckValue = new FCKeditor();
                            this.fckValue.ID = "fckValue";
                            this.fckValue.AutoDetectLanguage = false;
                            this.fckValue.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
                            if (this.DialogWidth > 0)
                            {
                                this.fckValue.Width = new Unit(this.DialogWidth);
                            }
                            if (this.DialogHeight > 0)
                            {
                                this.fckValue.Height = new Unit(this.DialogHeight);
                            }
                            this.fckValue.Config["LinkBrowserWindowHeight"] = "500";
                            this.fckValue.BasePath = "~/CMSAdminControls/FCKeditor/";
                            
                            // Set direction
                            this.fckValue.Config["ContentLangDirection"] = "ltr";

                            if (CultureHelper.IsPreferredCultureRTL())
                            {
                                this.fckValue.Config["ContentLangDirection"] = "rtl";
                            }
                        
                            // Set toolbar location
                            if (this.HtmlAreaToolbarLocation != "")
                            {
                                // Show the toolbar
                                if (FCKeditor.UseFrameForToolbar || FCKeditor.UseIFrameForToolbar)
                                {
                                    if (this.HtmlAreaToolbarLocation.ToLower() == "out:fcktoolbar")
                                    {
                                        mShowToolbar = true;
                                        if (FCKeditor.UseIFrameForToolbar)
                                        {
                                            this.HtmlAreaToolbarLocation = "Out:parent(FCKToolbar)";
                                        }
                                        else
                                        {
                                            this.HtmlAreaToolbarLocation = "Out:parent.frames['edittoolbar'](FCKToolbar)";
                                        }
                                    }
                                }

                                this.fckValue.Config["ToolbarLocation"] = this.HtmlAreaToolbarLocation;
                            }
                            // Set the visual appearrance
                            if (this.HtmlAreaToolbar != "")
                            {
                                this.fckValue.ToolbarSet = HtmlAreaToolbar;
                            }
                            // get editor area css file
                            if (CMSContext.CurrentSite != null)
                            {
                                SiteInfo si = SiteInfoProvider.GetSiteInfo(CMSContext.CurrentSite.SiteName);
                                if (si != null)
                                {
                                    int styleSheetId = (si.SiteDefaultEditorStylesheet > 0) ? si.SiteDefaultEditorStylesheet : si.SiteDefaultStylesheetID;

                                    CssStylesheetInfo cssInfo = CssStylesheetInfoProvider.GetCssStylesheetInfo(styleSheetId);
                                    if (cssInfo != null)
                                    {
                                        fckValue.EditorAreaCSS = CssStylesheetInfoProvider.GetStylesheetUrl(cssInfo.StylesheetName);
                                    }
                                }
                            }
                            this.fckValue.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
                            this.pnlEditor.Controls.Add(this.fckValue);
                            break;

                        case CMSEditableRegionTypeEnum.TextArea:
                        case CMSEditableRegionTypeEnum.TextBox:
                            // TextBox
                            this.txtValue = new TextBox();
                            this.txtValue.ID = "txtValue";
                            this.txtValue.CssClass = "EditableTextTextBox";
                            if (this.RegionType == CMSEditableRegionTypeEnum.TextArea)
                            {
                                this.txtValue.TextMode = TextBoxMode.MultiLine;
                            }
                            else
                            {
                                this.txtValue.TextMode = TextBoxMode.SingleLine;
                            }
                            if (this.DialogWidth > 0)
                            {
                                this.txtValue.Width = new Unit(this.DialogWidth - 8);
                            }
                            else
                            {
                                // Default width is 100%
                                this.txtValue.Width = new Unit(100, UnitType.Percentage);
                            } 
                            if (this.DialogHeight > 0)
                            {
                                this.txtValue.Height = new Unit(this.DialogHeight);
                            }
                            this.txtValue.Wrap = this.WordWrap;
                            this.txtValue.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
                            this.pnlEditor.Controls.Add(this.txtValue);
                            break;
                    }
                    break;

                default:
                    // Display content in non editing modes
                    this.ltlContent = new Literal();
                    this.ltlContent.ID = "ltlContent";
                    this.ltlContent.EnableViewState = false;
                    this.Controls.Add(this.ltlContent);
                    break;
            }
      //  }
    }


    /// <summary>
    /// Loads the control content
    /// </summary>
    /// <param name="content">Content to load</param>
    /// <param name="forceReload">If true, the content is forced to reload</param>
    public override void LoadContent(string content, bool forceReload)
    {
      /*  if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/

            // Load the properties
            this.RegionTitle = DataHelper.GetNotEmpty(this.GetValue("RegionTitle"), this.RegionTitle);
            this.RegionType = CMSEditableRegion.GetRegionType(DataHelper.GetNotEmpty(this.GetValue("RegionType"), this.RegionType.ToString()));
            this.DialogWidth = DataHelper.GetNotZero(this.GetValue("DialogWidth"), this.DialogWidth);
            this.DialogHeight = DataHelper.GetNotZero(this.GetValue("DialogHeight"), this.DialogHeight);
            this.WordWrap = ValidationHelper.GetBoolean(this.GetValue("WordWrap"), this.WordWrap);
            this.MinLength = DataHelper.GetNotZero(this.GetValue("MinLength"), this.MinLength);
            this.MaxLength = DataHelper.GetNotZero(this.GetValue("MaxLength"), this.MaxLength);
            this.HtmlAreaToolbar = DataHelper.GetNotEmpty(this.GetValue("HtmlAreaToolbar"), this.HtmlAreaToolbar);
            this.HtmlAreaToolbarLocation = DataHelper.GetNotEmpty(this.GetValue("HtmlAreaToolbarLocation"), this.HtmlAreaToolbarLocation);

            this.EnsureChildControls();

            content = ValidationHelper.GetString(content, "");
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    switch (this.RegionType)
                    {
                        case CMSEditableRegionTypeEnum.HtmlEditor:
                            // FCK editor
                            if (forceReload || (!this.Page.IsPostBack) || (this.PageManager.ViewMode != ViewModeEnum.Edit))
                            {
                                this.fckValue.ResolvedValue = content;
                            }
                            break;

                        case CMSEditableRegionTypeEnum.TextArea:
                        case CMSEditableRegionTypeEnum.TextBox:
                            // TextBox
                            if (forceReload || !this.Page.IsPostBack)
                            {
                                this.txtValue.Text = content;
                            }
                            break;
                    }
                    break;

                
                default:

                    bool isAuthorized = true;
                    bool checkPermissions = ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), false);

                    if (checkPermissions)
                    {
                        if (this.PageManager.ViewMode == ViewModeEnum.LiveSiteNotAuthorized)
                        {
                            isAuthorized = false;
                        }
                    }

                    if (isAuthorized)
                    {
                        this.ltlContent.Text = ResHelper.LocalizeString(content);
                        ControlsHelper.ResolveDynamicControls(this);
                    }
                    break;
            }
       // }
    }


    /// <summary>
    /// Returns true if the control uses HTML editor
    /// </summary>
    /// <param name="toolbarLocation">Toolbar location to check</param>
    public override bool UsesHtmlEditor(string toolbarLocation)
    {
        if ( (this.RegionType == CMSEditableRegionTypeEnum.HtmlEditor) && (this.PageManager.ViewMode == ViewModeEnum.Edit) )
        {
            return (toolbarLocation == null) || (toolbarLocation == this.HtmlAreaToolbarLocation);
        }
        return false;
    }


    /// <summary>
    /// Returns true if entered data is valid. If data is invalid, it returns false and displays an error message.
    /// </summary>
    /// <returns></returns>
    public override bool  IsValid()
    {
        string textWithOut = "";
        bool mIsValid = true;
        string mError = "";

        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
            case ViewModeEnum.EditDisabled:
                switch (this.RegionType)
                {
                    case CMSEditableRegionTypeEnum.HtmlEditor:

                        // FCK editor
                        textWithOut = HTMLHelper.StripTags(fckValue.ResolvedValue);
                        if ((textWithOut.Length > this.MaxLength) && (this.MaxLength > 0))
                        {
                            mError = ResHelper.GetString("EditableText.ErrorMax");
                            mIsValid = false;
                        }
                        if ((textWithOut.Length < this.MinLength) && (this.MinLength > 0))
                        {
                            mError = ResHelper.GetString("EditableText.ErrorMin");
                            mIsValid = false;
                        }
                        break;

                    case CMSEditableRegionTypeEnum.TextArea:
                    case CMSEditableRegionTypeEnum.TextBox:
                        // TextBox
                        textWithOut = HTMLHelper.StripTags(this.txtValue.Text);
                        if ((textWithOut.Length > this.MaxLength) && (this.MaxLength > 0))
                        {
                            mError = ResHelper.GetString("EditableText.ErrorMax");
                            mIsValid = false;
                        }
                        if ((textWithOut.Length < this.MinLength) && (this.MinLength > 0))
                        {
                            mError = ResHelper.GetString("EditableText.ErrorMin");
                            mIsValid = false;
                        }
                        break;
                }
                break;
        }

        if (!mIsValid)
        {
            lblError.Text = mError;
        }

        return mIsValid;
    }


    /// <summary>
    /// Gets the current control content
    /// </summary>
    public override string GetContent()
    {
       /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/
            this.EnsureChildControls();

            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    switch (this.RegionType)
                    {
                        case CMSEditableRegionTypeEnum.HtmlEditor:
                            // FCK editor
                            return fckValue.ResolvedValue;

                        case CMSEditableRegionTypeEnum.TextArea:
                        case CMSEditableRegionTypeEnum.TextBox:
                            // TextBox
                            return this.txtValue.Text;
                    }
                    break;
            }
        //}

        return null;
    }


    /// <summary>
    /// Returns the arraylist of the field IDs (Client IDs of the inner controls) that should be spell checked
    /// </summary>
    public override ArrayList GetSpellCheckFields()
    {
        switch (this.PageManager.ViewMode)
        {
            case ViewModeEnum.Edit:
                ArrayList result = new ArrayList();
                switch (this.RegionType)
                {
                    case CMSEditableRegionTypeEnum.HtmlEditor:
                        // FCK editor
                        result.Add(fckValue.ClientID);
                        break;

                    case CMSEditableRegionTypeEnum.TextArea:
                    case CMSEditableRegionTypeEnum.TextBox:
                        // TextBox
                        result.Add(txtValue.ClientID);
                        break;
                }
                return result;
        }
        return null;
    }


    /// <summary>
    /// Load event handler
    /// </summary>
    void Page_Load(object sender, EventArgs e)
    {
    }


    /// <summary>
    /// PreRender event handler
    /// </summary>
    void Page_PreRender(object sender, EventArgs e)
    {
        // Set enabled
        if (this.fckValue != null)
        {
            this.fckValue.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
        }
        if (this.txtValue != null)
        {
            this.txtValue.Enabled = (this.PageManager.ViewMode == ViewModeEnum.Edit);
        }

        if ( mShowToolbar && (this.PageManager.ViewMode == ViewModeEnum.Edit))
        {
            this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.TOOLBAR_SCRIPT_KEY, ScriptHelper.ToolbarScript);
        }
        
       /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    this.lblTitle.Text = this.RegionTitle;
                    break;
            }
       // }
    }


    /// <summary>
    /// Renders the control
    /// </summary>
    protected override void Render(HtmlTextWriter writer)
    {
       /* if ((this.PageManager.ViewMode != ViewModeEnum.Design) && (!this.HideOnCurrentPage) && (!this.IsVisible))
        {*/
            switch (this.PageManager.ViewMode)
            {
                case ViewModeEnum.Edit:
                case ViewModeEnum.EditDisabled:
                    writer.Write(this.mPartInstance.ContainerBefore);
                    writer.Write(this.mPartInstance.ContentBefore);
                        
                    this.pnlEditor.RenderControl(writer);

                    writer.Write(this.mPartInstance.ContentAfter);
                    writer.Write(this.mPartInstance.ContainerAfter);
                    break;

                default:
                    base.Render(writer);
                    break;
            }
        }
    //}

}
