using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.Controls;
using CMS.CMSHelper;
using CMS.WorkflowEngine;

public partial class CMSWebParts_pagedtext : CMSAbstractWebPart
{
    #region "Document properties"

    /// <summary>
    /// Cache item name
    /// </summary>
    public override string CacheItemName
    {
        get
        {
            return base.CacheItemName;
        }
        set
        {
            base.CacheItemName = value;
        }
    }


    /// <summary>
    /// Cache minutes
    /// </summary>
    public override int CacheMinutes
    {
        get
        {
            return base.CacheMinutes;
        }
        set
        {
            base.CacheMinutes = value;
        }
    }


    /// <summary>
    /// Check permissions
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), false);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
        }
    }


    /// <summary>
    /// Combine with default culture
    /// </summary>
    public bool CombineWithDefaultCulture
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CombineWithDefaultCulture"), true);
        }
        set
        {
            this.SetValue("CombineWithDefaultCulture", value);
        }
    }


    /// <summary>
    /// Culture code
    /// </summary>
    public string CultureCode
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("CultureCode"), CMSContext.CurrentUser.PreferredCultureCode);
        }
        set
        {
            this.SetValue("CultureCode", value);
        }
    }


    /// <summary>
    /// Nodes path 
    /// </summary>
    public string Path
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("Path"), "");
        }
        set
        {
            this.SetValue("Path", value);
        }
    }


    /// <summary>
    /// Select only published nodes
    /// </summary>
    public bool SelectOnlyPublished
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("SelectOnlyPublished"), true);
        }
        set
        {
            this.SetValue("SelctOnlyPublished", value);
        }
    }


    /// <summary>
    /// Site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SiteName"), CMSContext.CurrentSite.SiteName);
        }
        set
        {
            this.SetValue("SiteName", value);
        }
    }


    /// <summary>
    /// Text column name
    /// </summary>
    public string ColumnName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ColumnName"), "");
        }
        set
        {
            this.SetValue("ColumnName", value);
        }
    }

    #endregion


    #region "Pager properties"

    /// <summary>
    /// Pager position
    /// </summary>
    public PagingPlaceTypeEnum PagerPosition
    {
        get
        {
            return this.textPager.PagerControl.GetPagerPosition(DataHelper.GetNotEmpty(this.GetValue("PagerPosition"), this.textPager.PagerControl.PagerPosition.ToString()));
        }
        set
        {
            this.SetValue("PagerPosition", value.ToString());
            this.textPager.PagerControl.PagerPosition = value;
        }
    }


    /// <summary>
    /// Page size
    /// </summary>
    public int PageSize
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("PageSize"), this.textPager.PageSize);
        }
        set
        {
            this.SetValue("PageSize", value);
            this.textPager.PageSize = value;
        }
    }


    /// <summary>
    /// Pager query string key
    /// </summary>
    public string QueryStringKey
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("QueryStringKey"), this.textPager.PagerControl.QueryStringKey), this.textPager.PagerControl.QueryStringKey);
        }
        set
        {
            this.SetValue("QueryStringKey", value);
            this.textPager.PagerControl.QueryStringKey = value;
        }
    }


    /// <summary>
    /// Pager format string
    /// </summary>
    public string PagerFormat
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("PagerFormat"), this.textPager.PagerControl.ResultsFormat);
        }
        set
        {
            this.SetValue("PagerFormat", value);
            this.textPager.PagerControl.ResultsFormat = value;
        }
    }


    /// <summary>
    /// Paging mode
    /// </summary>
    public PagingModeTypeEnum PagingMode
    {
        get
        {
            return this.textPager.PagerControl.GetPagingMode(DataHelper.GetNotEmpty(this.GetValue("PagingMode"), this.textPager.PagerControl.PagingMode.ToString()));
        }
        set
        {
            this.SetValue("PagingMode", value.ToString());
            this.textPager.PagerControl.PagingMode = value;
        }
    }


    /// <summary>
    /// Show first / last links
    /// </summary>
    public bool ShowFirstLast
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowFirstLast"), this.textPager.PagerControl.ShowFirstLast);
        }
        set
        {
            this.SetValue("ShowFirstLast", value);
            this.textPager.PagerControl.ShowFirstLast = value;
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            // Do nothing
        }
        else
        {
            CMS.TreeEngine.TreeNode node = null;
            if (this.Path == "")
            {
                node = CMSContext.CurrentDocument;
            }
            else
            {
                CurrentUserInfo currentUser = CMSContext.CurrentUser;
                TreeProvider tree = new TreeProvider(currentUser);
                node = tree.SelectSingleNode(CMSContext.CurrentSite.SiteName, this.Path, this.CultureCode, this.CombineWithDefaultCulture, null, this.SelectOnlyPublished, this.CheckPermissions, currentUser);

                if ((node != null) && (this.PageManager.ViewMode != ViewModeEnum.LiveSite))
                {
                    node = DocumentHelper.GetDocument(node, tree);
                }
            }

            this.textPager.PagerControl.PagerPosition = this.PagerPosition;
            this.textPager.PagerControl.QueryStringKey = this.QueryStringKey;
            this.textPager.PagerControl.PagingMode = this.PagingMode;
            this.textPager.PagerControl.ShowFirstLast = this.ShowFirstLast;
            this.textPager.PagerControl.ResultsFormat = this.PagerFormat;

            this.textPager.PageSize = this.PageSize;
            if ((node != null) && (this.ColumnName != ""))
            {
                string text = ValidationHelper.GetString(node.GetValue(this.ColumnName), "");
                if (text != "")
                {
                    this.textPager.TextSource = text;
                }
            }
        }
    }


    public override void ReloadData()
    {
        base.ReloadData();
        this.SetupControl();
    }

}

